{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "0af67e19",
   "metadata": {},
   "source": [
    "## Tools to Speed Up Code"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "35e5e33b",
   "metadata": {},
   "source": [
    "This section covers some tools to speed up your code."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "52726661",
   "metadata": {},
   "source": [
    "### Fastai's df_shrink: Shrink DataFrame's Memory Usage in One Line of Code"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "01981c69",
   "metadata": {
    "tags": [
     "hide-cell"
    ]
   },
   "outputs": [],
   "source": [
    "!pip install fastai"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "1c796fbb",
   "metadata": {},
   "source": [
    "Changing data types of DataFrame columns to smaller data types can significantly reduce the memory usage of the DataFrame. Instead of manually choosing smaller data types, is there a way that you can automatically change data types in one line of code?\n",
    "\n",
    "That is when the `df_shrink` method of Fastai comes in handy. In the code below, the memory usage of the DataFrame decreases from 200 bytes to 146 bytes."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "ac80ee09",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-09-12T11:39:50.560775Z",
     "start_time": "2021-09-12T11:39:50.516924Z"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "<class 'pandas.core.frame.DataFrame'>\n",
      "RangeIndex: 3 entries, 0 to 2\n",
      "Data columns (total 2 columns):\n",
      " #   Column  Non-Null Count  Dtype  \n",
      "---  ------  --------------  -----  \n",
      " 0   col1    3 non-null      int64  \n",
      " 1   col2    3 non-null      float64\n",
      "dtypes: float64(1), int64(1)\n",
      "memory usage: 176.0 bytes\n",
      "None\n"
     ]
    },
    {
     "data": {
      "application/javascript": "\n            setTimeout(function() {\n                var nbb_cell_id = 4;\n                var nbb_unformatted_code = \"from fastai.tabular.core import df_shrink\\nimport pandas as pd \\n\\ndf = pd.DataFrame({\\\"col1\\\": [1, 2, 3], \\\"col2\\\": [1.0, 2.0, 3.0]})\\nprint(df.info())\";\n                var nbb_formatted_code = \"from fastai.tabular.core import df_shrink\\nimport pandas as pd\\n\\ndf = pd.DataFrame({\\\"col1\\\": [1, 2, 3], \\\"col2\\\": [1.0, 2.0, 3.0]})\\nprint(df.info())\";\n                var nbb_cells = Jupyter.notebook.get_cells();\n                for (var i = 0; i < nbb_cells.length; ++i) {\n                    if (nbb_cells[i].input_prompt_number == nbb_cell_id) {\n                        if (nbb_cells[i].get_text() == nbb_unformatted_code) {\n                             nbb_cells[i].set_text(nbb_formatted_code);\n                        }\n                        break;\n                    }\n                }\n            }, 500);\n            ",
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "from fastai.tabular.core import df_shrink\n",
    "import pandas as pd\n",
    "\n",
    "df = pd.DataFrame({\"col1\": [1, 2, 3], \"col2\": [1.0, 2.0, 3.0]})\n",
    "print(df.info())"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "8fd3b371",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-09-12T11:39:51.272398Z",
     "start_time": "2021-09-12T11:39:51.239231Z"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "<class 'pandas.core.frame.DataFrame'>\n",
      "RangeIndex: 3 entries, 0 to 2\n",
      "Data columns (total 2 columns):\n",
      " #   Column  Non-Null Count  Dtype  \n",
      "---  ------  --------------  -----  \n",
      " 0   col1    3 non-null      int8   \n",
      " 1   col2    3 non-null      float32\n",
      "dtypes: float32(1), int8(1)\n",
      "memory usage: 143.0 bytes\n",
      "None\n"
     ]
    },
    {
     "data": {
      "application/javascript": "\n            setTimeout(function() {\n                var nbb_cell_id = 5;\n                var nbb_unformatted_code = \"new_df = df_shrink(df)\\nprint(new_df.info())\";\n                var nbb_formatted_code = \"new_df = df_shrink(df)\\nprint(new_df.info())\";\n                var nbb_cells = Jupyter.notebook.get_cells();\n                for (var i = 0; i < nbb_cells.length; ++i) {\n                    if (nbb_cells[i].input_prompt_number == nbb_cell_id) {\n                        if (nbb_cells[i].get_text() == nbb_unformatted_code) {\n                             nbb_cells[i].set_text(nbb_formatted_code);\n                        }\n                        break;\n                    }\n                }\n            }, 500);\n            ",
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "new_df = df_shrink(df)\n",
    "print(new_df.info())"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "81b7e11b",
   "metadata": {},
   "source": [
    "[Link to Fastai](https://docs.fast.ai/)."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "66eb2ec3",
   "metadata": {},
   "source": [
    "### Swifter: Add One Word to Make Your Pandas Apply 23 Times Faster"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "6d7575d3",
   "metadata": {
    "tags": [
     "hide-cell"
    ]
   },
   "outputs": [],
   "source": [
    "!pip install swifter"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "456bbc73",
   "metadata": {},
   "source": [
    "If you want to have faster pandas apply when working with large data, try swifter. To use swifter, simply add `.swifter` before `.apply`. Everything else is the same."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "f6ffb6ab",
   "metadata": {},
   "source": [
    "In the code below, I compared the speed of Pandas' `apply` and the speed of swifter's `apply` using the California housing dataset of 20640 rows."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "c9ab2ad4",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-09-12T11:41:25.820480Z",
     "start_time": "2021-09-12T11:41:17.670791Z"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Swifter apply is 16.82 times faster than Pandas apply\n"
     ]
    },
    {
     "data": {
      "application/javascript": "\n            setTimeout(function() {\n                var nbb_cell_id = 7;\n                var nbb_unformatted_code = \"from time import time\\nfrom sklearn.datasets import fetch_california_housing\\nfrom scipy.special import boxcox1p\\nimport swifter\\nimport timeit\\n\\nX, y = fetch_california_housing(return_X_y=True, as_frame=True)\\n\\ndef pandas_apply():\\n    X[\\\"AveRooms\\\"].apply(lambda x: boxcox1p(x, 0.25))\\n\\n\\ndef swifter_apply():\\n    X[\\\"AveRooms\\\"].swifter.apply(lambda x: boxcox1p(x, 0.25))\\n\\nnum_experiments = 100\\npandas_time = timeit.timeit(pandas_apply, number=num_experiments)\\nswifter_time = timeit.timeit(swifter_apply, number=num_experiments)\\n\\npandas_vs_swifter = round(pandas_time/swifter_time, 2)\\nprint(f'Swifter apply is {pandas_vs_swifter} times faster than Pandas apply')\";\n                var nbb_formatted_code = \"from time import time\\nfrom sklearn.datasets import fetch_california_housing\\nfrom scipy.special import boxcox1p\\nimport swifter\\nimport timeit\\n\\nX, y = fetch_california_housing(return_X_y=True, as_frame=True)\\n\\n\\ndef pandas_apply():\\n    X[\\\"AveRooms\\\"].apply(lambda x: boxcox1p(x, 0.25))\\n\\n\\ndef swifter_apply():\\n    X[\\\"AveRooms\\\"].swifter.apply(lambda x: boxcox1p(x, 0.25))\\n\\n\\nnum_experiments = 100\\npandas_time = timeit.timeit(pandas_apply, number=num_experiments)\\nswifter_time = timeit.timeit(swifter_apply, number=num_experiments)\\n\\npandas_vs_swifter = round(pandas_time / swifter_time, 2)\\nprint(f\\\"Swifter apply is {pandas_vs_swifter} times faster than Pandas apply\\\")\";\n                var nbb_cells = Jupyter.notebook.get_cells();\n                for (var i = 0; i < nbb_cells.length; ++i) {\n                    if (nbb_cells[i].input_prompt_number == nbb_cell_id) {\n                        if (nbb_cells[i].get_text() == nbb_unformatted_code) {\n                             nbb_cells[i].set_text(nbb_formatted_code);\n                        }\n                        break;\n                    }\n                }\n            }, 500);\n            ",
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "from time import time\n",
    "from sklearn.datasets import fetch_california_housing\n",
    "from scipy.special import boxcox1p\n",
    "import swifter\n",
    "import timeit\n",
    "\n",
    "X, y = fetch_california_housing(return_X_y=True, as_frame=True)\n",
    "\n",
    "\n",
    "def pandas_apply():\n",
    "    X[\"AveRooms\"].apply(lambda x: boxcox1p(x, 0.25))\n",
    "\n",
    "\n",
    "def swifter_apply():\n",
    "    X[\"AveRooms\"].swifter.apply(lambda x: boxcox1p(x, 0.25))\n",
    "\n",
    "\n",
    "num_experiments = 100\n",
    "pandas_time = timeit.timeit(pandas_apply, number=num_experiments)\n",
    "swifter_time = timeit.timeit(swifter_apply, number=num_experiments)\n",
    "\n",
    "pandas_vs_swifter = round(pandas_time / swifter_time, 2)\n",
    "print(f\"Swifter apply is {pandas_vs_swifter} times faster than Pandas apply\")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "85dd3cd9",
   "metadata": {},
   "source": [
    "Using swifter apply is 23.56 times faster than Pandas apply! This ratio is calculated by taking the average run time of each method after 100 experiments."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "5ad712a6",
   "metadata": {},
   "source": [
    "[Link to swifter](https://github.com/jmcarpenter2/swifter)."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "89e73f11",
   "metadata": {},
   "source": [
    "### pyinstrument: Readable Python Profiler"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "a45e7a75",
   "metadata": {
    "tags": [
     "hide-cell"
    ]
   },
   "outputs": [],
   "source": [
    "!pip install pyinstrument "
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "61f77119",
   "metadata": {},
   "source": [
    "Have you ever wanted to get statistics of how long various parts of your code are executed to optimize your code? profile and CProfile allow you to profile your code, but the outputs are long and hard to understand, especially when using high-level libraries like pandas. \n",
    "\n",
    "For example, applying cProfile to the code using pandas will me the output like below:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "4128bb5a",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Writing cprofilers_example.py\n"
     ]
    }
   ],
   "source": [
    "%%writefile cprofilers_example.py\n",
    "import pandas as pd\n",
    "import numpy as np\n",
    "\n",
    "df = pd.DataFrame({'nums': np.random.randint(0, 100, 10000)})\n",
    "def is_even(num: int) -> int:\n",
    "    return num % 2 == 0\n",
    "\n",
    "df = df.assign(is_even=lambda df_: is_even(df_.nums))"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "51dc2026",
   "metadata": {},
   "source": [
    "On your terminal:\n",
    "```bash\n",
    "$ python -m cProfile cprofilers_example.py\n",
    "```"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "494c1dab",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-09-15T14:04:43.880993Z",
     "start_time": "2021-09-15T14:04:43.293343Z"
    },
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "         246355 function calls (240252 primitive calls) in 0.311 seconds\r\n",
      "\r\n",
      "   Ordered by: standard name\r\n",
      "\r\n",
      "   ncalls  tottime  percall  cumtime  percall filename:lineno(function)\r\n",
      "        1    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(append)\r\n",
      "        1    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(bincount)\r\n",
      "        5    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(concatenate)\r\n",
      "        4    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(copyto)\r\n",
      "        2    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(ndim)\r\n",
      "        1    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(prod)\r\n",
      "        2    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(ravel)\r\n",
      "        2    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:1002(_gcd_import)\r\n",
      "  610/353    0.001    0.000    0.144    0.000 <frozen importlib._bootstrap>:1017(_handle_fromlist)\r\n",
      "     1208    0.002    0.000    0.002    0.000 <frozen importlib._bootstrap>:103(release)\r\n",
      "      527    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:143(__init__)\r\n",
      "      527    0.000    0.000    0.004    0.000 <frozen importlib._bootstrap>:147(__enter__)\r\n",
      "      527    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap>:151(__exit__)\r\n",
      "     1208    0.002    0.000    0.003    0.000 <frozen importlib._bootstrap>:157(_get_module_lock)\r\n",
      "      524    0.001    0.000    0.001    0.000 <frozen importlib._bootstrap>:176(cb)\r\n",
      "      681    0.001    0.000    0.003    0.000 <frozen importlib._bootstrap>:194(_lock_unlock_module)\r\n",
      "    681/1    0.000    0.000    0.310    0.310 <frozen importlib._bootstrap>:211(_call_with_frames_removed)\r\n",
      "     4196    0.001    0.000    0.001    0.000 <frozen importlib._bootstrap>:222(_verbose_message)\r\n",
      "       23    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:232(_requires_builtin_wrapper)\r\n",
      "      521    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:342(__init__)\r\n",
      "      406    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:35(_new_module)\r\n",
      "      880    0.001    0.000    0.005    0.000 <frozen importlib._bootstrap>:376(cached)\r\n",
      "      727    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap>:389(parent)\r\n",
      "      498    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:397(has_location)\r\n",
      "       24    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:406(spec_from_loader)\r\n",
      "      498    0.002    0.000    0.009    0.000 <frozen importlib._bootstrap>:477(_init_module_attrs)\r\n",
      "  498/495    0.001    0.000    0.032    0.000 <frozen importlib._bootstrap>:549(module_from_spec)\r\n",
      "      524    0.001    0.000    0.001    0.000 <frozen importlib._bootstrap>:58(__init__)\r\n",
      "    498/1    0.002    0.000    0.310    0.310 <frozen importlib._bootstrap>:650(_load_unlocked)\r\n",
      "      520    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:725(find_spec)\r\n",
      "       23    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap>:746(create_module)\r\n",
      "       23    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:754(exec_module)\r\n",
      "       23    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:771(is_package)\r\n",
      "     1208    0.002    0.000    0.002    0.000 <frozen importlib._bootstrap>:78(acquire)\r\n",
      "      497    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:800(find_spec)\r\n",
      "     1530    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap>:863(__enter__)\r\n",
      "     1530    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap>:867(__exit__)\r\n",
      "      520    0.003    0.000    0.032    0.000 <frozen importlib._bootstrap>:890(_find_spec)\r\n",
      "        2    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:937(_sanity_check)\r\n",
      "    527/1    0.002    0.000    0.311    0.311 <frozen importlib._bootstrap>:956(_find_and_load_unlocked)\r\n",
      "    527/1    0.002    0.000    0.311    0.311 <frozen importlib._bootstrap>:986(_find_and_load)\r\n",
      "      406    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:1004(__init__)\r\n",
      "      406    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:1029(get_filename)\r\n",
      "      406    0.002    0.000    0.011    0.000 <frozen importlib._bootstrap_external>:1034(get_data)\r\n",
      "      406    0.000    0.000    0.002    0.000 <frozen importlib._bootstrap_external>:1075(path_stats)\r\n",
      "       68    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:1153(__init__)\r\n",
      "       68    0.000    0.000    0.021    0.000 <frozen importlib._bootstrap_external>:1164(create_module)\r\n",
      "    68/39    0.000    0.000    0.058    0.001 <frozen importlib._bootstrap_external>:1172(exec_module)\r\n",
      "     3858    0.002    0.000    0.006    0.000 <frozen importlib._bootstrap_external>:121(_path_join)\r\n",
      "     3858    0.002    0.000    0.003    0.000 <frozen importlib._bootstrap_external>:123(<listcomp>)\r\n",
      "      812    0.001    0.000    0.002    0.000 <frozen importlib._bootstrap_external>:127(_path_split)\r\n",
      "     1624    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap_external>:129(<genexpr>)\r\n",
      "       53    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap_external>:1317(_path_hooks)\r\n",
      "      820    0.000    0.000    0.002    0.000 <frozen importlib._bootstrap_external>:1330(_path_importer_cache)\r\n",
      "     1896    0.001    0.000    0.007    0.000 <frozen importlib._bootstrap_external>:135(_path_stat)\r\n",
      "      497    0.002    0.000    0.026    0.000 <frozen importlib._bootstrap_external>:1367(_get_spec)\r\n",
      "      497    0.000    0.000    0.026    0.000 <frozen importlib._bootstrap_external>:1399(find_spec)\r\n",
      "      704    0.001    0.000    0.003    0.000 <frozen importlib._bootstrap_external>:145(_path_is_mode_type)\r\n",
      "       53    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:1459(__init__)\r\n",
      "      424    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:1465(<genexpr>)\r\n",
      "      474    0.001    0.000    0.003    0.000 <frozen importlib._bootstrap_external>:1493(_get_spec)\r\n",
      "      733    0.006    0.000    0.022    0.000 <frozen importlib._bootstrap_external>:1498(find_spec)\r\n",
      "      651    0.000    0.000    0.003    0.000 <frozen importlib._bootstrap_external>:154(_path_isfile)\r\n",
      "       53    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap_external>:1549(_fill_cache)\r\n",
      "       53    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:159(_path_isdir)\r\n",
      "       53    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap_external>:1590(path_hook_for_FileFinder)\r\n",
      "      527    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:175(_path_isabs)\r\n",
      "      812    0.003    0.000    0.007    0.000 <frozen importlib._bootstrap_external>:354(cache_from_source)\r\n",
      "      474    0.001    0.000    0.005    0.000 <frozen importlib._bootstrap_external>:484(_get_cached)\r\n",
      "      406    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:516(_check_name_wrapper)\r\n",
      "      406    0.001    0.000    0.001    0.000 <frozen importlib._bootstrap_external>:553(_classify_pyc)\r\n",
      "      406    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap_external>:586(_validate_timestamp_pyc)\r\n",
      "      406    0.001    0.000    0.038    0.000 <frozen importlib._bootstrap_external>:638(_compile_bytecode)\r\n",
      "      733    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:68(_relax_case)\r\n",
      "      474    0.001    0.000    0.002    0.000 <frozen importlib._bootstrap_external>:689(spec_from_file_location)\r\n",
      "     1218    0.001    0.000    0.001    0.000 <frozen importlib._bootstrap_external>:79(_unpack_uint32)\r\n",
      "      406    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:839(create_module)\r\n",
      "    406/1    0.001    0.000    0.310    0.310 <frozen importlib._bootstrap_external>:842(exec_module)\r\n",
      "      406    0.003    0.000    0.059    0.000 <frozen importlib._bootstrap_external>:914(get_code)\r\n",
      "       53    0.000    0.000    0.000    0.000 <frozen zipimport>:63(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 <string>:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 <string>:1(__create_fn__)\r\n",
      "        1    0.000    0.000    0.000    0.000 <string>:1(__new__)\r\n",
      "        1    0.000    0.000    0.000    0.000 __config__.py:3(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 __future__.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 __future__.py:81(_Feature)\r\n",
      "       10    0.000    0.000    0.000    0.000 __future__.py:83(__init__)\r\n",
      "       48    0.001    0.000    0.506    0.011 __init__.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 __init__.py:101(CFunctionType)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1042(StreamHandler)\r\n",
      "        2    0.000    0.000    0.000    0.000 __init__.py:107(import_lzma)\r\n",
      "        2    0.000    0.000    0.000    0.000 __init__.py:109(import_module)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:11(DeprecatedTzFormatWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1125(FileHandler)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1194(_StderrHandler)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1200(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1218(PlaceHolder)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1260(Manager)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1265(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:127(EmptyDataError)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1280(disable)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:129(InvalidVersion)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:134(ParserWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:135(_BaseVersion)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1389(Logger)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1404(__init__)\r\n",
      "       14    0.000    0.000    0.000    0.000 __init__.py:141(_check_size)\r\n",
      "        8    0.000    0.000    0.000    0.000 __init__.py:144(__lt__)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:15(IntCastingNaNError)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:151(align_method_SERIES)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:153(py_object)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:162(c_short)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:164(set_testing_mode)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:166(c_ushort)\r\n",
      "        1    0.000    0.000    0.002    0.002 __init__.py:17(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:170(c_long)\r\n",
      "       22    0.000    0.000    0.001    0.000 __init__.py:171(flex_method_SERIES)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:174(c_ulong)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1743(RootLogger)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1749(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:175(MergeError)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:1760(LoggerAdapter)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:181(LegacyVersion)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:182(AccessorRegistrationWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:183(c_int)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:187(c_uint)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:188(AbstractMethodError)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:191(c_float)\r\n",
      "        3    0.000    0.000    0.000    0.000 __init__.py:193(_checkLevel)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:195(c_double)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:199(c_longdouble)\r\n",
      "        5    0.000    0.000    0.037    0.007 __init__.py:2(<module>)\r\n",
      "        1    0.000    0.000    0.019    0.019 __init__.py:20(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:21(__deprecated_private_func)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:211(NumbaUtilError)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:213(UTC)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:2147(NullHandler)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:217(DuplicateLabelError)\r\n",
      "        2    0.000    0.000    0.000    0.000 __init__.py:218(_acquireLock)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:220(c_ubyte)\r\n",
      "        2    0.000    0.000    0.000    0.000 __init__.py:227(_releaseLock)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:227(c_byte)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:231(_sanity_check)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:232(c_char)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:237(c_char_p)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:238(InvalidIndexError)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:24(NullFrequencyError)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:243(c_void_p)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:248(_register_at_fork_reinit_lock)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:248(c_bool)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:253(c_wchar_p)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:258(c_wchar)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:26(InfinityType)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:261(_reset_cache)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:276(LogRecord)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:299(loads)\r\n",
      "        3    0.000    0.000    0.311    0.104 __init__.py:3(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:313(_CountryTimezoneDict)\r\n",
      "       32    0.001    0.000    0.004    0.000 __init__.py:313(namedtuple)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:318(CDLL)\r\n",
      "        3    0.000    0.000    0.000    0.000 __init__.py:323(<genexpr>)\r\n",
      "       32    0.000    0.000    0.000    0.000 __init__.py:327(_deprecate_scalar)\r\n",
      "        1    0.000    0.000    0.002    0.002 __init__.py:332(Version)\r\n",
      "       10    0.000    0.000    0.000    0.000 __init__.py:336(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:339(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:34(PerformanceWarning)\r\n",
      "       37    0.000    0.000    0.000    0.000 __init__.py:346(<genexpr>)\r\n",
      "        3    0.000    0.000    0.000    0.000 __init__.py:36(__deprecate_private_class)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:367(_FuncPtr)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:372(_CountryNameDict)\r\n",
      "      182    0.000    0.000    0.000    0.000 __init__.py:385(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:396(PyDLL)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:398(_FixedOffset)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:40(UnsupportedFunctionCall)\r\n",
      "       14    0.000    0.000    0.001    0.000 __init__.py:410(flex_arith_method_FRAME)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:415(dev)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:417(PercentStyle)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:424(__init__)\r\n",
      "        3    0.000    0.000    0.000    0.000 __init__.py:43(private_class)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:430(validate)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:436(LibraryLoader)\r\n",
      "        2    0.000    0.000    0.000    0.000 __init__.py:437(__init__)\r\n",
      "        1    0.000    0.000    0.001    0.001 __init__.py:445(StrFormatStyle)\r\n",
      "        6    0.000    0.000    0.001    0.000 __init__.py:455(flex_comp_method_FRAME)\r\n",
      "       30    0.000    0.000    0.000    0.000 __init__.py:468(_parse_letter_version)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:475(StringTemplateStyle)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:48(UnsortedIndexError)\r\n",
      "        3    0.000    0.000    0.000    0.000 __init__.py:498(PYFUNCTYPE)\r\n",
      "        3    0.000    0.000    0.000    0.000 __init__.py:499(CFunctionType)\r\n",
      "       10    0.000    0.000    0.000    0.000 __init__.py:507(_parse_local_version)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:514(Formatter)\r\n",
      "       10    0.000    0.000    0.000    0.000 __init__.py:519(_cmpkey)\r\n",
      "       20    0.000    0.000    0.000    0.000 __init__.py:534(<lambda>)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:55(ParserError)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:559(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:58(NegativeInfinityType)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:69(DtypeWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:692(BufferingFormatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:734(Filter)\r\n",
      "        2    0.000    0.000    0.000    0.000 __init__.py:75(CFUNCTYPE)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:771(Filterer)\r\n",
      "        2    0.000    0.000    0.000    0.000 __init__.py:776(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:843(_addHandlerRef)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:847(SubclassedSeries)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:853(Handler)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:859(SubclassedDataFrame)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:862(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:871(SubclassedCategorical)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:882(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 __init__.py:891(createLock)\r\n",
      "        1    0.000    0.000    0.003    0.003 __init__.py:9(<module>)\r\n",
      "        1    0.000    0.000    0.002    0.002 _add_newdocs.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _add_newdocs.py:6673(numeric_type_aliases)\r\n",
      "       18    0.000    0.000    0.000    0.000 _add_newdocs.py:6674(type_aliases_gen)\r\n",
      "       19    0.000    0.000    0.000    0.000 _add_newdocs.py:6709(add_newdoc_for_scalar_type)\r\n",
      "       27    0.000    0.000    0.000    0.000 _add_newdocs.py:6714(<genexpr>)\r\n",
      "       36    0.000    0.000    0.000    0.000 _add_newdocs.py:6715(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _asarray.py:1(<module>)\r\n",
      "      7/6    0.000    0.000    0.000    0.000 _asarray.py:14(asarray)\r\n",
      "        1    0.000    0.000    0.000    0.000 _asarray.py:221(require)\r\n",
      "        1    0.000    0.000    0.000    0.000 _asarray.py:298(<setcomp>)\r\n",
      "        4    0.000    0.000    0.000    0.000 _asarray.py:86(asanyarray)\r\n",
      "        1    0.000    0.000    0.005    0.005 _base.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 _base.py:1105(ExcelFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 _base.py:404(BaseExcelReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 _base.py:645(ExcelWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 _bootlocale.py:33(getpreferredencoding)\r\n",
      "        1    0.000    0.000    0.000    0.000 _collections_abc.py:252(__subclasshook__)\r\n",
      "        2    0.000    0.000    0.000    0.000 _collections_abc.py:349(__subclasshook__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _collections_abc.py:367(__subclasshook__)\r\n",
      "        5    0.000    0.000    0.000    0.000 _collections_abc.py:657(get)\r\n",
      "        2    0.000    0.000    0.000    0.000 _collections_abc.py:664(__contains__)\r\n",
      "        6    0.000    0.000    0.000    0.000 _collections_abc.py:72(_check_methods)\r\n",
      "        1    0.000    0.000    0.000    0.000 _color_data.py:7(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 _common.py:1(<module>)\r\n",
      "        6    0.000    0.000    0.000    0.000 _common.py:13(tzname_in_python2)\r\n",
      "        3    0.000    0.000    0.000    0.000 _common.py:132(_validate_fromutc_inputs)\r\n",
      "        1    0.000    0.000    0.000    0.000 _common.py:149(_tzinfo)\r\n",
      "        1    0.000    0.000    0.000    0.000 _common.py:267(tzrangebase)\r\n",
      "        1    0.000    0.000    0.000    0.000 _common.py:6(weekday)\r\n",
      "        7    0.000    0.000    0.000    0.000 _common.py:9(__init__)\r\n",
      "       43    0.000    0.000    0.000    0.000 _compat_pickle.py:165(<genexpr>)\r\n",
      "       85    0.000    0.000    0.000    0.000 _compat_pickle.py:167(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _compat_pickle.py:9(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _compression.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _compression.py:33(DecompressReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 _compression.py:9(BaseStream)\r\n",
      "        1    0.000    0.000    0.001    0.001 _core.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _core.py:620(PlotAccessor)\r\n",
      "        1    0.000    0.000    0.003    0.003 _datasource.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _datasource.py:101(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _datasource.py:198(DataSource)\r\n",
      "        1    0.000    0.000    0.000    0.000 _datasource.py:538(Repository)\r\n",
      "        1    0.000    0.000    0.000    0.000 _datasource.py:76(_FileOpeners)\r\n",
      "        1    0.000    0.000    0.022    0.022 _decorators.py:1(<module>)\r\n",
      "        7    0.000    0.000    0.000    0.000 _decorators.py:165(_deprecate_kwarg)\r\n",
      "        1    0.000    0.000    0.000    0.000 _decorators.py:18(deprecate)\r\n",
      "       41    0.000    0.000    0.000    0.000 _decorators.py:252(future_version_msg)\r\n",
      "       41    0.000    0.000    0.000    0.000 _decorators.py:260(deprecate_nonkeyword_arguments)\r\n",
      "       41    0.000    0.000    0.000    0.000 _decorators.py:286(decorate)\r\n",
      "        3    0.000    0.000    0.000    0.000 _decorators.py:318(rewrite_axis_style_signature)\r\n",
      "        3    0.000    0.000    0.000    0.000 _decorators.py:321(decorate)\r\n",
      "      231    0.000    0.000    0.000    0.000 _decorators.py:348(doc)\r\n",
      "      231    0.000    0.000    0.008    0.000 _decorators.py:368(decorator)\r\n",
      "      826    0.000    0.000    0.004    0.000 _decorators.py:387(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _decorators.py:407(Substitution)\r\n",
      "       56    0.000    0.000    0.000    0.000 _decorators.py:436(__init__)\r\n",
      "       56    0.000    0.000    0.000    0.000 _decorators.py:442(__call__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _decorators.py:454(Appender)\r\n",
      "      160    0.000    0.000    0.000    0.000 _decorators.py:476(__init__)\r\n",
      "      160    0.000    0.000    0.009    0.000 _decorators.py:483(__call__)\r\n",
      "        3    0.000    0.000    0.000    0.000 _decorators.py:491(indent)\r\n",
      "        7    0.000    0.000    0.000    0.000 _decorators.py:93(deprecate_kwarg)\r\n",
      "        1    0.000    0.000    0.000    0.000 _distributor_init.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _dtype.py:1(<module>)\r\n",
      "       18    0.000    0.000    0.000    0.000 _dtype.py:24(_kind_name)\r\n",
      "        2    0.000    0.000    0.000    0.000 _dtype.py:307(_name_includes_bit_suffix)\r\n",
      "        2    0.000    0.000    0.000    0.000 _dtype.py:321(_name_get)\r\n",
      "        1    0.000    0.000    0.000    0.000 _dtype_ctypes.py:1(<module>)\r\n",
      "       13    0.000    0.000    0.000    0.000 _dtype_ctypes.py:100(dtype_from_ctypes_type)\r\n",
      "       13    0.000    0.000    0.000    0.000 _dtype_ctypes.py:71(_from_ctypes_scalar)\r\n",
      "        1    0.000    0.000    0.000    0.000 _endian.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _endian.py:23(_swapped_meta)\r\n",
      "        1    0.000    0.000    0.000    0.000 _endian.py:46(BigEndianStructure)\r\n",
      "        2    0.000    0.000    0.000    0.000 _exceptions.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _exceptions.py:118(TooHardError)\r\n",
      "        1    0.000    0.000    0.000    0.000 _exceptions.py:123(AxisError)\r\n",
      "        1    0.000    0.000    0.000    0.000 _exceptions.py:141(_ArrayMemoryError)\r\n",
      "        6    0.000    0.000    0.000    0.000 _exceptions.py:17(_display_as_base)\r\n",
      "        1    0.000    0.000    0.000    0.000 _exceptions.py:32(UFuncTypeError)\r\n",
      "        1    0.000    0.000    0.000    0.000 _exceptions.py:38(_UFuncBinaryResolutionError)\r\n",
      "        1    0.000    0.000    0.000    0.000 _exceptions.py:54(_UFuncNoLoopError)\r\n",
      "        1    0.000    0.000    0.000    0.000 _exceptions.py:72(_UFuncCastingError)\r\n",
      "        1    0.000    0.000    0.000    0.000 _exceptions.py:81(_UFuncInputCastingError)\r\n",
      "        1    0.000    0.000    0.000    0.000 _exceptions.py:99(_UFuncOutputCastingError)\r\n",
      "        1    0.000    0.000    0.000    0.000 _factories.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _factories.py:13(__call__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _factories.py:19(_TzFactory)\r\n",
      "        1    0.000    0.000    0.000    0.000 _factories.py:25(_TzOffsetFactory)\r\n",
      "        1    0.000    0.000    0.000    0.000 _factories.py:26(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _factories.py:55(_TzStrFactory)\r\n",
      "        1    0.000    0.000    0.000    0.000 _factories.py:56(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _factories.py:8(_TzSingleton)\r\n",
      "        1    0.000    0.000    0.000    0.000 _factories.py:9(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _generated_version.py:4(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _globals.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _globals.py:30(ModuleDeprecationWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 _globals.py:44(VisibleDeprecationWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 _globals.py:57(_NoValueType)\r\n",
      "        1    0.000    0.000    0.000    0.000 _globals.py:65(__new__)\r\n",
      "        9    0.000    0.000    0.000    0.000 _globals.py:75(__repr__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _inspect.py:1(<module>)\r\n",
      "      616    0.000    0.000    0.000    0.000 _inspect.py:13(ismethod)\r\n",
      "       90    0.000    0.000    0.000    0.000 _inspect.py:131(strseq)\r\n",
      "       40    0.000    0.000    0.000    0.000 _inspect.py:140(formatargspec)\r\n",
      "       15    0.000    0.000    0.000    0.000 _inspect.py:142(<lambda>)\r\n",
      "       16    0.000    0.000    0.000    0.000 _inspect.py:143(<lambda>)\r\n",
      "       59    0.000    0.000    0.000    0.000 _inspect.py:144(<lambda>)\r\n",
      "      616    0.000    0.000    0.000    0.000 _inspect.py:26(isfunction)\r\n",
      "      612    0.000    0.000    0.000    0.000 _inspect.py:41(iscode)\r\n",
      "      612    0.002    0.000    0.002    0.000 _inspect.py:65(getargs)\r\n",
      "      616    0.001    0.000    0.003    0.000 _inspect.py:96(getargspec)\r\n",
      "        1    0.000    0.000    0.008    0.008 _internal.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _internal.py:204(dummy_ctype)\r\n",
      "        1    0.000    0.000    0.000    0.000 _internal.py:216(_getintp_ctype)\r\n",
      "        1    0.000    0.000    0.000    0.000 _internal.py:239(_missing_ctypes)\r\n",
      "        1    0.000    0.000    0.000    0.000 _internal.py:243(c_void_p)\r\n",
      "        1    0.000    0.000    0.000    0.000 _internal.py:248(_ctypes)\r\n",
      "        1    0.000    0.000    0.000    0.000 _internal.py:524(_Stream)\r\n",
      "       50    0.000    0.000    0.000    0.000 _internal.py:781(_ufunc_doc_signature_formatter)\r\n",
      "       78    0.000    0.000    0.000    0.000 _internal.py:792(<genexpr>)\r\n",
      "       15    0.000    0.000    0.000    0.000 _internal.py:827(npy_ctypes_check)\r\n",
      "        1    0.000    0.000    0.000    0.000 _internal.py:845(recursive)\r\n",
      "        1    0.000    0.000    0.001    0.001 _io.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _io.py:76(optional_args)\r\n",
      "        1    0.000    0.000    0.000    0.000 _iotools.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _iotools.py:133(LineSplitter)\r\n",
      "        1    0.000    0.000    0.000    0.000 _iotools.py:229(NameValidator)\r\n",
      "        1    0.000    0.000    0.000    0.000 _iotools.py:421(ConverterError)\r\n",
      "        1    0.000    0.000    0.000    0.000 _iotools.py:429(ConverterLockError)\r\n",
      "        1    0.000    0.000    0.000    0.000 _iotools.py:437(ConversionWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 _iotools.py:450(StringConverter)\r\n",
      "        1    0.000    0.000    0.001    0.001 _json.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _json.py:1043(SeriesParser)\r\n",
      "        1    0.000    0.000    0.000    0.000 _json.py:1091(FrameParser)\r\n",
      "        1    0.000    0.000    0.000    0.000 _json.py:138(Writer)\r\n",
      "        1    0.000    0.000    0.000    0.000 _json.py:193(SeriesWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 _json.py:208(FrameWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 _json.py:238(JSONTableWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 _json.py:617(JsonReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 _json.py:816(Parser)\r\n",
      "        1    0.000    0.000    0.001    0.001 _methods.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 _methods.py:53(_any)\r\n",
      "        1    0.000    0.000    0.000    0.000 _misc.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _misc.py:488(_Options)\r\n",
      "        1    0.000    0.000    0.000    0.000 _misc.py:501(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _mixins.py:1(<module>)\r\n",
      "        6    0.000    0.000    0.000    0.000 _mixins.py:49(ravel_compat)\r\n",
      "        1    0.000    0.000    0.000    0.000 _mixins.py:69(NDArrayBackedExtensionArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 _normalize.py:3(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _odfreader.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _odfreader.py:17(ODFReader)\r\n",
      "        1    0.000    0.000    0.001    0.001 _odswriter.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _odswriter.py:18(ODSWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 _openpyxl.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _openpyxl.py:31(OpenpyxlWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 _openpyxl.py:505(OpenpyxlReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 _optional.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 _optional.py:64(import_optional_dependency)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:1371(_tzparser)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:1373(_result)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:1378(_attr)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:1589(ParserError)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:1608(UnknownTimezoneWarning)\r\n",
      "        1    0.000    0.000    0.001    0.001 _parser.py:2(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:219(_resultbase)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:241(parserinfo)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:294(__init__)\r\n",
      "        7    0.000    0.000    0.000    0.000 _parser.py:309(_convert)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:394(_ymd)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:568(parser)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:569(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:58(_timelex)\r\n",
      "        1    0.000    0.000    0.000    0.000 _parser.py:661(_result)\r\n",
      "        1    0.000    0.000    0.008    0.008 _pickle.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 _pocketfft.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _polybase.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _polybase.py:17(ABCPolyBase)\r\n",
      "        1    0.000    0.000    0.000    0.000 _print_versions.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _pytesttester.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _pytesttester.py:45(PytestTester)\r\n",
      "        9    0.000    0.000    0.000    0.000 _pytesttester.py:75(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _pyxlsb.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _pyxlsb.py:13(PyxlsbReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 _random.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _ranges.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _string_helpers.py:1(<module>)\r\n",
      "       36    0.000    0.000    0.000    0.000 _string_helpers.py:16(english_lower)\r\n",
      "       16    0.000    0.000    0.000    0.000 _string_helpers.py:44(english_upper)\r\n",
      "       16    0.000    0.000    0.000    0.000 _string_helpers.py:72(english_capitalize)\r\n",
      "        1    0.000    0.000    0.000    0.000 _string_helpers.py:9(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _table_schema.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _tester.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 _type_aliases.py:1(<module>)\r\n",
      "        6    0.000    0.000    0.000    0.000 _type_aliases.py:112(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _type_aliases.py:114(_add_aliases)\r\n",
      "        1    0.000    0.000    0.000    0.000 _type_aliases.py:153(_add_integer_aliases)\r\n",
      "        1    0.000    0.000    0.000    0.000 _type_aliases.py:186(_set_up_aliases)\r\n",
      "       30    0.000    0.000    0.000    0.000 _type_aliases.py:231(_add_array_type)\r\n",
      "        1    0.000    0.000    0.000    0.000 _type_aliases.py:239(_set_array_types)\r\n",
      "        1    0.000    0.000    0.000    0.000 _type_aliases.py:35(TypeNADict)\r\n",
      "        1    0.000    0.000    0.000    0.000 _type_aliases.py:62(<setcomp>)\r\n",
      "       16    0.000    0.000    0.000    0.000 _type_aliases.py:65(_bits_of)\r\n",
      "       32    0.000    0.000    0.000    0.000 _type_aliases.py:67(<genexpr>)\r\n",
      "       16    0.000    0.000    0.000    0.000 _type_aliases.py:78(bitname)\r\n",
      "        1    0.000    0.000    0.000    0.000 _type_aliases.py:94(_add_types)\r\n",
      "        1    0.000    0.000    0.005    0.005 _typing.py:1(<module>)\r\n",
      "      340    0.000    0.000    0.000    0.000 _typing.py:77(<lambda>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _ufunc_config.py:1(<module>)\r\n",
      "       12    0.000    0.000    0.000    0.000 _ufunc_config.py:132(geterr)\r\n",
      "        1    0.000    0.000    0.000    0.000 _ufunc_config.py:29(<dictcomp>)\r\n",
      "       12    0.000    0.000    0.000    0.000 _ufunc_config.py:32(seterr)\r\n",
      "        1    0.000    0.000    0.000    0.000 _ufunc_config.py:362(_unspecified)\r\n",
      "        1    0.000    0.000    0.000    0.000 _ufunc_config.py:369(errstate)\r\n",
      "        6    0.000    0.000    0.000    0.000 _ufunc_config.py:429(__init__)\r\n",
      "        6    0.000    0.000    0.000    0.000 _ufunc_config.py:433(__enter__)\r\n",
      "        6    0.000    0.000    0.000    0.000 _ufunc_config.py:438(__exit__)\r\n",
      "        1    0.000    0.000    0.000    0.000 _ufunc_config.py:444(_setdef)\r\n",
      "        1    0.000    0.000    0.000    0.000 _util.py:1(<module>)\r\n",
      "        4    0.000    0.000    0.000    0.000 _util.py:18(register_writer)\r\n",
      "        1    0.000    0.000    0.000    0.000 _validators.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _version.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _version.py:14(NumpyVersion)\r\n",
      "        1    0.000    0.000    0.000    0.000 _version.py:20(get_versions)\r\n",
      "        1    0.000    0.000    0.000    0.000 _version.py:4(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _version.py:7(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _warnings.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 _weakrefset.py:36(__init__)\r\n",
      "        2    0.000    0.000    0.000    0.000 _weakrefset.py:81(add)\r\n",
      "        1    0.000    0.000    0.000    0.000 _xlrd.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _xlrd.py:11(XlrdReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 _xlsxwriter.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _xlsxwriter.py:15(_XlsxStyler)\r\n",
      "        1    0.000    0.000    0.000    0.000 _xlsxwriter.py:167(XlsxWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 _xlwt.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 _xlwt.py:21(XlwtWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 abc.py:1(<module>)\r\n",
      "    45/26    0.000    0.000    0.000    0.000 abc.py:100(__subclasscheck__)\r\n",
      "      177    0.000    0.000    0.000    0.000 abc.py:7(abstractmethod)\r\n",
      "       95    0.000    0.000    0.002    0.000 abc.py:84(__new__)\r\n",
      "       20    0.000    0.000    0.000    0.000 abc.py:89(register)\r\n",
      "       11    0.000    0.000    0.000    0.000 abc.py:96(__instancecheck__)\r\n",
      "        3    0.000    0.000    0.003    0.001 accessor.py:1(<module>)\r\n",
      "       50    0.000    0.000    0.000    0.000 accessor.py:105(_forbid_nonstring_types)\r\n",
      "       10    0.000    0.000    0.000    0.000 accessor.py:112(delegate_names)\r\n",
      "        9    0.000    0.000    0.000    0.000 accessor.py:124(_map_and_wrap)\r\n",
      "        1    0.000    0.000    0.002    0.002 accessor.py:134(StringMethods)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessor.py:14(DirNamesMixin)\r\n",
      "       10    0.000    0.000    0.000    0.000 accessor.py:140(add_delegate_accessors)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessor.py:153(CachedAccessor)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessor.py:17(BaseAccessor)\r\n",
      "        8    0.000    0.000    0.000    0.000 accessor.py:173(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessor.py:216(SparseFrameAccessor)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessor.py:28(SparseAccessor)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessor.py:43(PandasDelegate)\r\n",
      "       10    0.000    0.000    0.000    0.000 accessor.py:57(_add_delegate_accessors)\r\n",
      "       50    0.000    0.000    0.000    0.000 accessor.py:57(forbid_nonstring_types)\r\n",
      "       62    0.000    0.000    0.000    0.000 accessor.py:77(_create_delegator_property)\r\n",
      "       34    0.000    0.000    0.000    0.000 accessor.py:91(_create_delegator_method)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessors.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessors.py:140(DatetimeProperties)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessors.py:300(TimedeltaProperties)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessors.py:407(PeriodProperties)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessors.py:42(Properties)\r\n",
      "        1    0.000    0.000    0.000    0.000 accessors.py:474(CombinedDatetimelikeProperties)\r\n",
      "        1    0.000    0.000    0.006    0.006 aggregation.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.002    0.002 algorithms.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 algorithms.py:1207(SelectN)\r\n",
      "        1    0.000    0.000    0.000    0.000 algorithms.py:1239(SelectNSeries)\r\n",
      "        1    0.000    0.000    0.000    0.000 algorithms.py:1317(SelectNFrame)\r\n",
      "        1    0.000    0.000    0.000    0.000 align.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 align.py:64(_filter_special_cases)\r\n",
      "        4    0.000    0.000    0.021    0.005 api.py:1(<module>)\r\n",
      "        4    0.000    0.000    0.116    0.029 api.py:3(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 apply.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 apply.py:1006(SeriesApply)\r\n",
      "        1    0.000    0.000    0.000    0.000 apply.py:1115(GroupByApply)\r\n",
      "        1    0.000    0.000    0.000    0.000 apply.py:1141(ResamplerWindowApply)\r\n",
      "        1    0.000    0.000    0.000    0.000 apply.py:595(NDFrameApply)\r\n",
      "        1    0.000    0.000    0.000    0.000 apply.py:610(FrameApply)\r\n",
      "        1    0.000    0.000    0.000    0.000 apply.py:870(FrameRowApply)\r\n",
      "        1    0.000    0.000    0.000    0.000 apply.py:930(FrameColumnApply)\r\n",
      "        1    0.000    0.000    0.000    0.000 apply.py:98(Apply)\r\n",
      "        1    0.000    0.000    0.001    0.001 array.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 array.py:223(SparseArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 array_manager.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 array_manager.py:100(BaseArrayManager)\r\n",
      "        1    0.000    0.000    0.000    0.000 array_manager.py:1166(SingleArrayManager)\r\n",
      "        1    0.000    0.000    0.000    0.000 array_manager.py:1320(NullArrayProxy)\r\n",
      "        1    0.000    0.000    0.000    0.000 array_manager.py:689(ArrayManager)\r\n",
      "        1    0.000    0.000    0.001    0.001 array_ops.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 array_ops.py:138(_na_arithmetic_op)\r\n",
      "        1    0.000    0.000    0.000    0.000 array_ops.py:185(arithmetic_op)\r\n",
      "        1    0.000    0.000    0.000    0.000 array_ops.py:229(comparison_op)\r\n",
      "       14    0.000    0.000    0.000    0.000 array_ops.py:399(get_array_op)\r\n",
      "        1    0.000    0.000    0.000    0.000 array_ops.py:441(maybe_prepare_scalar_for_op)\r\n",
      "        1    0.000    0.000    0.000    0.000 array_ops.py:510(_bool_arith_check)\r\n",
      "        1    0.000    0.000    0.000    0.000 arraylike.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 arraylike.py:130(__mod__)\r\n",
      "        1    0.000    0.000    0.000    0.000 arraylike.py:23(OpsMixin)\r\n",
      "        1    0.000    0.000    0.000    0.000 arraylike.py:30(__eq__)\r\n",
      "        1    0.000    0.000    0.000    0.000 arraypad.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 arrayprint.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 arrayprint.py:1123(IntegerFormat)\r\n",
      "        1    0.000    0.000    0.000    0.000 arrayprint.py:1136(BoolFormat)\r\n",
      "        1    0.000    0.000    0.000    0.000 arrayprint.py:1146(ComplexFloatingFormat)\r\n",
      "        1    0.000    0.000    0.000    0.000 arrayprint.py:1179(_TimelikeFormat)\r\n",
      "        1    0.000    0.000    0.000    0.000 arrayprint.py:1205(DatetimeFormat)\r\n",
      "        1    0.000    0.000    0.000    0.000 arrayprint.py:1237(TimedeltaFormat)\r\n",
      "        1    0.000    0.000    0.000    0.000 arrayprint.py:1242(SubArrayFormat)\r\n",
      "        1    0.000    0.000    0.000    0.000 arrayprint.py:1252(StructuredVoidFormat)\r\n",
      "       15    0.000    0.000    0.000    0.000 arrayprint.py:1466(_guarded_repr_or_str)\r\n",
      "       15    0.000    0.000    0.001    0.000 arrayprint.py:1473(_array_str_implementation)\r\n",
      "        2    0.000    0.000    0.000    0.000 arrayprint.py:1546(set_string_function)\r\n",
      "        2    0.000    0.000    0.000    0.000 arrayprint.py:448(_recursive_guard)\r\n",
      "        2    0.000    0.000    0.000    0.000 arrayprint.py:458(decorating_function)\r\n",
      "       15    0.000    0.000    0.001    0.000 arrayprint.py:461(wrapper)\r\n",
      "        1    0.000    0.000    0.000    0.000 arrayprint.py:834(FloatingFormat)\r\n",
      "        1    0.000    0.000    0.001    0.001 arraysetops.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 arrayterator.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 arrayterator.py:16(Arrayterator)\r\n",
      "        1    0.000    0.000    0.000    0.000 asserters.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 ast.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 ast.py:347(NodeVisitor)\r\n",
      "        1    0.000    0.000    0.000    0.000 ast.py:405(NodeTransformer)\r\n",
      "        1    0.000    0.000    0.000    0.000 ast.py:476(_ABC)\r\n",
      "        1    0.000    0.000    0.000    0.000 ast.py:505(Num)\r\n",
      "        1    0.000    0.000    0.000    0.000 ast.py:509(Str)\r\n",
      "        1    0.000    0.000    0.000    0.000 ast.py:513(Bytes)\r\n",
      "        1    0.000    0.000    0.000    0.000 ast.py:517(NameConstant)\r\n",
      "        1    0.000    0.000    0.000    0.000 ast.py:520(Ellipsis)\r\n",
      "        7    0.000    0.000    0.009    0.001 base.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:12(BaseStringArrayMethods)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:129(NoNewAttributesMixin)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:1327(ExtensionOpsMixin)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:134(SingleDataManager)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:1388(ExtensionScalarOpsMixin)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:1449(name)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:163(DataError)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:167(SpecificationError)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:171(SelectionMixin)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:193(_maybe_return_indexers)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:2018(is_unique)\r\n",
      "        2    0.000    0.000    0.000    0.000 base.py:2058(is_boolean)\r\n",
      "        2    0.000    0.000    0.000    0.000 base.py:2130(is_floating)\r\n",
      "        4    0.000    0.000    0.000    0.000 base.py:220(disallow_kwargs)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:2218(is_object)\r\n",
      "        2    0.000    0.000    0.000    0.000 base.py:2382(inferred_type)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:24(DataManager)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:2410(_is_multi)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:248(Index)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:258(IndexOpsMixin)\r\n",
      "        6    0.000    0.000    0.000    0.000 base.py:263(is_dtype)\r\n",
      "        2    0.000    0.000    0.000    0.000 base.py:3317(get_loc)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:3426(get_indexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:3488(_get_indexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:35(ExtensionDtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:3516(_check_indexing_method)\r\n",
      "       17    0.000    0.000    0.000    0.000 base.py:371(register_extension_dtype)\r\n",
      "      7/4    0.000    0.000    0.000    0.000 base.py:375(__new__)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:395(Registry)\r\n",
      "        3    0.000    0.000    0.000    0.000 base.py:41(shape)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:411(__init__)\r\n",
      "       17    0.000    0.000    0.000    0.000 base.py:414(register)\r\n",
      "       18    0.000    0.000    0.000    0.000 base.py:425(find)\r\n",
      "        9    0.000    0.000    0.000    0.000 base.py:43(<genexpr>)\r\n",
      "        7    0.000    0.000    0.000    0.000 base.py:4379(_values)\r\n",
      "        2    0.000    0.000    0.000    0.000 base.py:4405(_get_engine_target)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:4493(_validate_fill_value)\r\n",
      "        4    0.000    0.000    0.000    0.000 base.py:4537(__contains__)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:4587(__getitem__)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:4638(_can_hold_identifiers_and_holds_name)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:4729(equals)\r\n",
      "        4    0.000    0.000    0.000    0.000 base.py:484(<genexpr>)\r\n",
      "        4    0.000    0.000    0.000    0.000 base.py:497(_ensure_array)\r\n",
      "        4    0.000    0.000    0.000    0.000 base.py:511(_dtype_to_subclass)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:5262(get_indexer_for)\r\n",
      "        2    0.000    0.000    0.000    0.000 base.py:5341(_index_as_unique)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:5353(_maybe_promote)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:5435(_should_compare)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:5453(_is_comparable_dtype)\r\n",
      "        2    0.000    0.000    0.000    0.000 base.py:5696(_maybe_cast_indexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:5705(_maybe_cast_listlike_indexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:5957(insert)\r\n",
      "        5    0.000    0.000    0.000    0.000 base.py:605(_simple_new)\r\n",
      "        5    0.000    0.000    0.000    0.000 base.py:6280(ensure_index)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:6376(default_index)\r\n",
      "       10    0.000    0.000    0.000    0.000 base.py:6382(maybe_extract_name)\r\n",
      "        3    0.000    0.000    0.000    0.000 base.py:6398(_maybe_cast_data_without_dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:6445(unpack_nested_dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:707(_view)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:725(is_)\r\n",
      "        7    0.000    0.000    0.000    0.000 base.py:756(_reset_identity)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:767(_engine)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:774(<lambda>)\r\n",
      "        7    0.000    0.000    0.000    0.000 base.py:794(__len__)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:800(__array__)\r\n",
      "        2    0.000    0.000    0.000    0.000 base.py:818(dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:82(PandasObject)\r\n",
      "        2    0.000    0.000    0.000    0.000 base.py:848(view)\r\n",
      "        1    0.000    0.000    0.000    0.000 base.py:90(ExtensionArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 base64.py:3(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 base_parser.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 base_parser.py:117(ParserBase)\r\n",
      "        1    0.000    0.000    0.000    0.000 base_parser.py:118(BadLineHandleMethod)\r\n",
      "        1    0.000    0.000    0.000    0.000 bisect.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 blocks.py:1(<module>)\r\n",
      "        3    0.000    0.000    0.000    0.000 blocks.py:128(maybe_split)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:1328(EABackedBlock)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:1374(ExtensionBlock)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:146(Block)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:1671(NumpyBlock)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:1677(NumericBlock)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:1682(NDArrayBackedExtensionBlock)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:1779(DatetimeLikeBlock)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:1787(DatetimeTZBlock)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:1798(ObjectBlock)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:1844(CategoricalBlock)\r\n",
      "        5    0.000    0.000    0.000    0.000 blocks.py:1853(maybe_coerce_values)\r\n",
      "        5    0.000    0.000    0.000    0.000 blocks.py:1885(get_block_type)\r\n",
      "        4    0.000    0.000    0.000    0.000 blocks.py:1926(new_block)\r\n",
      "        4    0.000    0.000    0.000    0.000 blocks.py:1941(check_ndim)\r\n",
      "        4    0.000    0.000    0.000    0.000 blocks.py:1983(extract_pandas_array)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:2005(extend_blocks)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:2021(ensure_block_shape)\r\n",
      "        2    0.000    0.000    0.000    0.000 blocks.py:238(mgr_locs)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:261(make_block_same_class)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:340(shape)\r\n",
      "        2    0.000    0.000    0.000    0.000 blocks.py:344(dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:349(iget)\r\n",
      "        1    0.000    0.000    0.000    0.000 blocks.py:646(copy)\r\n",
      "        1    0.000    0.000    0.002    0.002 boolean.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 boolean.py:238(BooleanArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 boolean.py:45(BooleanDtype)\r\n",
      "        1    0.000    0.000    0.001    0.001 bz2.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 bz2.py:30(BZ2File)\r\n",
      "        1    0.000    0.000    0.000    0.000 c_parser_wrapper.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 c_parser_wrapper.py:29(CParserWrapper)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:148(Calendar)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:154(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:160(setfirstweekday)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:24(IllegalMonthError)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:293(TextCalendar)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:31(IllegalWeekdayError)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:410(HTMLCalendar)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:50(_localized_month)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:52(<listcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 calendar.py:53(<lambda>)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:546(different_locale)\r\n",
      "        2    0.000    0.000    0.000    0.000 calendar.py:55(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:558(LocaleTextCalendar)\r\n",
      "       26    0.000    0.000    0.000    0.000 calendar.py:58(__getitem__)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:589(LocaleHTMLCalendar)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:69(_localized_day)\r\n",
      "        1    0.000    0.000    0.000    0.000 calendar.py:72(<listcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 calendar.py:74(__init__)\r\n",
      "       14    0.000    0.000    0.000    0.000 calendar.py:77(__getitem__)\r\n",
      "        1    0.000    0.000    0.000    0.000 cast.py:1(<module>)\r\n",
      "        3    0.000    0.000    0.000    0.000 cast.py:1727(sanitize_to_nanoseconds)\r\n",
      "        3    0.000    0.000    0.000    0.000 cast.py:1969(construct_1d_object_array_from_listlike)\r\n",
      "        1    0.000    0.000    0.000    0.000 cast.py:2156(can_hold_element)\r\n",
      "        1    0.000    0.000    0.000    0.000 cast.py:852(maybe_infer_dtype_type)\r\n",
      "        2    0.000    0.000    0.005    0.003 categorical.py:1(<module>)\r\n",
      "        6    0.000    0.000    0.000    0.000 categorical.py:123(_cat_compare_op)\r\n",
      "        1    0.000    0.000    0.000    0.000 categorical.py:247(Categorical)\r\n",
      "        1    0.000    0.000    0.000    0.000 categorical.py:2472(CategoricalAccessor)\r\n",
      "        1    0.000    0.000    0.001    0.001 category.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 category.py:56(CategoricalIndex)\r\n",
      "        1    0.000    0.000    0.000    0.000 chainmap.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 chainmap.py:12(DeepChainMap)\r\n",
      "        1    0.000    0.000    0.000    0.000 chebyshev.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 chebyshev.py:1982(Chebyshev)\r\n",
      "        1    0.000    0.000    0.000    0.000 check.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 clipboards.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.003    0.003 cloudpickle.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 cloudpickle.py:706(instance)\r\n",
      "        1    0.000    0.000    0.000    0.000 cloudpickle.py:722(_empty_cell_value)\r\n",
      "        1    0.000    0.000    0.002    0.002 cloudpickle_fast.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 cloudpickle_fast.py:513(CloudPickler)\r\n",
      "        1    0.000    0.000    0.000    0.000 codecs.py:260(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 codecs.py:309(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 codecs.py:319(decode)\r\n",
      "        6    0.000    0.000    0.004    0.001 common.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:1035(is_numeric_v_string_like)\r\n",
      "        2    0.000    0.000    0.000    0.000 common.py:116(ensure_python_int)\r\n",
      "        6    0.000    0.000    0.000    0.000 common.py:1230(is_float_dtype)\r\n",
      "        5    0.000    0.000    0.000    0.000 common.py:1409(is_1d_only_ea_dtype)\r\n",
      "       10    0.000    0.000    0.000    0.000 common.py:144(classes)\r\n",
      "       10    0.000    0.000    0.000    0.000 common.py:146(<lambda>)\r\n",
      "       14    0.000    0.000    0.000    0.000 common.py:1474(is_ea_or_datetimelike_dtype)\r\n",
      "        9    0.000    0.000    0.000    0.000 common.py:149(classes_and_not_datetimelike)\r\n",
      "        9    0.000    0.000    0.000    0.000 common.py:154(<lambda>)\r\n",
      "        2    0.000    0.000    0.000    0.000 common.py:1543(get_dtype)\r\n",
      "        3    0.000    0.000    0.000    0.000 common.py:155(cast_scalar_indexer)\r\n",
      "       19    0.000    0.000    0.000    0.000 common.py:1578(_is_dtype_type)\r\n",
      "        4    0.000    0.000    0.000    0.000 common.py:160(is_object_dtype)\r\n",
      "       52    0.000    0.000    0.000    0.000 common.py:17(unpack_zerodim_and_defer)\r\n",
      "        7    0.000    0.000    0.000    0.000 common.py:1718(validate_all_hashable)\r\n",
      "       14    0.000    0.000    0.000    0.000 common.py:1737(<genexpr>)\r\n",
      "       24    0.000    0.000    0.000    0.000 common.py:1744(pandas_dtype)\r\n",
      "        5    0.000    0.000    0.000    0.000 common.py:190(is_sparse)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:196(all_none)\r\n",
      "        2    0.000    0.000    0.000    0.000 common.py:200(<genexpr>)\r\n",
      "        7    0.000    0.000    0.000    0.000 common.py:224(asarray_tuplesafe)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:287(maybe_iterable_to_list)\r\n",
      "       52    0.000    0.000    0.000    0.000 common.py:30(wrapper)\r\n",
      "      3/2    0.000    0.000    0.001    0.000 common.py:346(apply_if_callable)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:347(is_datetime64tz_dtype)\r\n",
      "       52    0.000    0.000    0.000    0.000 common.py:36(_unpack_zerodim_and_defer)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:458(is_interval_dtype)\r\n",
      "        4    0.000    0.000    0.000    0.000 common.py:496(is_categorical_dtype)\r\n",
      "        2    0.000    0.000    0.000    0.000 common.py:526(require_length_match)\r\n",
      "        2    0.000    0.000    0.000    0.000 common.py:54(new_method)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:57(SettingWithCopyError)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:574(is_dtype_equal)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:58(IOArgs)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:61(SettingWithCopyWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:673(is_integer_dtype)\r\n",
      "        4    0.000    0.000    0.000    0.000 common.py:725(is_signed_integer_dtype)\r\n",
      "        2    0.000    0.000    0.000    0.000 common.py:74(get_op_result_name)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:758(_BytesZipFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:76(IOHandles)\r\n",
      "        4    0.000    0.000    0.000    0.000 common.py:779(is_unsigned_integer_dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 common.py:815(_MMapWrapper)\r\n",
      "        2    0.000    0.000    0.000    0.000 compat.py:1(<module>)\r\n",
      "     1239    0.000    0.000    0.006    0.000 compute.py:134(<genexpr>)\r\n",
      "      189    0.000    0.000    0.001    0.000 compute.py:138(_get_options_class)\r\n",
      "      189    0.000    0.000    0.000    0.000 compute.py:171(_make_generic_wrapper)\r\n",
      "        1    0.000    0.000    0.037    0.037 compute.py:18(<module>)\r\n",
      "      189    0.001    0.000    0.006    0.000 compute.py:183(_make_signature)\r\n",
      "      189    0.001    0.000    0.016    0.000 compute.py:203(_wrap_function)\r\n",
      "        1    0.000    0.000    0.016    0.016 compute.py:218(_make_global_functions)\r\n",
      "      378    0.000    0.000    0.001    0.000 compute.py:74(_get_arg_names)\r\n",
      "      189    0.001    0.000    0.008    0.000 compute.py:78(_decorate_compute_function)\r\n",
      "        3    0.000    0.000    0.007    0.002 concat.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 concat.py:310(_Concatenator)\r\n",
      "        1    0.000    0.000    0.000    0.000 concat.py:327(JoinUnit)\r\n",
      "        1    0.000    0.000    0.000    0.000 config.py:1(<module>)\r\n",
      "        5    0.000    0.000    0.000    0.000 config.py:114(_get_option)\r\n",
      "        1    0.000    0.000    0.000    0.000 config.py:191(DictWrapper)\r\n",
      "        1    0.000    0.000    0.000    0.000 config.py:194(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 config.py:237(CallableDynamicDoc)\r\n",
      "        4    0.000    0.000    0.000    0.000 config.py:238(__init__)\r\n",
      "        5    0.000    0.000    0.000    0.000 config.py:242(__call__)\r\n",
      "        1    0.000    0.000    0.000    0.000 config.py:392(option_context)\r\n",
      "       62    0.000    0.000    0.001    0.000 config.py:424(register_option)\r\n",
      "        2    0.000    0.000    0.000    0.000 config.py:499(deprecate_option)\r\n",
      "        5    0.000    0.000    0.000    0.000 config.py:547(_select_options)\r\n",
      "        5    0.000    0.000    0.000    0.000 config.py:565(_get_root)\r\n",
      "       10    0.000    0.000    0.000    0.000 config.py:579(_get_deprecated_option)\r\n",
      "        5    0.000    0.000    0.000    0.000 config.py:606(_translate_key)\r\n",
      "        5    0.000    0.000    0.000    0.000 config.py:618(_warn_if_deprecated)\r\n",
      "       48    0.000    0.000    0.000    0.000 config.py:707(config_prefix)\r\n",
      "       72    0.000    0.000    0.000    0.000 config.py:737(wrap)\r\n",
      "       62    0.000    0.000    0.001    0.000 config.py:738(inner)\r\n",
      "        4    0.000    0.000    0.000    0.000 config.py:760(is_type_factory)\r\n",
      "       22    0.000    0.000    0.000    0.000 config.py:774(inner)\r\n",
      "        5    0.000    0.000    0.000    0.000 config.py:781(is_instance_factory)\r\n",
      "        7    0.000    0.000    0.000    0.000 config.py:800(inner)\r\n",
      "       16    0.000    0.000    0.000    0.000 config.py:807(is_one_of_factory)\r\n",
      "       16    0.000    0.000    0.000    0.000 config.py:809(<listcomp>)\r\n",
      "       16    0.000    0.000    0.000    0.000 config.py:810(<listcomp>)\r\n",
      "       16    0.000    0.000    0.000    0.000 config.py:812(inner)\r\n",
      "        4    0.000    0.000    0.000    0.000 config.py:826(is_nonnegative_int)\r\n",
      "        1    0.000    0.000    0.000    0.000 config.py:85(OptionError)\r\n",
      "        5    0.000    0.000    0.000    0.000 config.py:96(_get_single_key)\r\n",
      "        1    0.000    0.000    0.001    0.001 config_init.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 config_init.py:324(is_terminal)\r\n",
      "        1    0.000    0.000    0.000    0.000 config_init.py:696(register_plotting_backend_cb)\r\n",
      "        1    0.000    0.000    0.000    0.000 console.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 construction.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 construction.py:100(arrays_to_mgr)\r\n",
      "        1    0.000    0.000    0.000    0.000 construction.py:215(mgr_to_mgr)\r\n",
      "       12    0.000    0.000    0.000    0.000 construction.py:369(extract_array)\r\n",
      "        1    0.000    0.000    0.000    0.000 construction.py:396(dict_to_mgr)\r\n",
      "       12    0.000    0.000    0.000    0.000 construction.py:431(ensure_wrapped_if_datetimelike)\r\n",
      "        1    0.000    0.000    0.000    0.000 construction.py:445(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 construction.py:448(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 construction.py:449(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 construction.py:456(<listcomp>)\r\n",
      "        4    0.000    0.000    0.000    0.000 construction.py:463(sanitize_array)\r\n",
      "        1    0.000    0.000    0.000    0.000 construction.py:560(_homogenize)\r\n",
      "        1    0.000    0.000    0.000    0.000 construction.py:598(_extract_index)\r\n",
      "        4    0.000    0.000    0.000    0.000 construction.py:606(_sanitize_ndim)\r\n",
      "        4    0.000    0.000    0.000    0.000 construction.py:643(_sanitize_str_dtypes)\r\n",
      "        4    0.000    0.000    0.000    0.000 construction.py:663(_maybe_repeat)\r\n",
      "        4    0.000    0.000    0.000    0.000 construction.py:674(_try_cast)\r\n",
      "        2    0.000    0.000    0.000    0.000 construction.py:781(is_empty_data)\r\n",
      "       24    0.000    0.000    0.000    0.000 contextlib.py:108(__enter__)\r\n",
      "       24    0.000    0.000    0.000    0.000 contextlib.py:117(__exit__)\r\n",
      "       19    0.000    0.000    0.000    0.000 contextlib.py:211(contextmanager)\r\n",
      "       24    0.000    0.000    0.000    0.000 contextlib.py:238(helper)\r\n",
      "        2    0.000    0.000    0.000    0.000 contextlib.py:379(_create_cb_wrapper)\r\n",
      "        2    0.000    0.000    0.000    0.000 contextlib.py:381(_exit_wrapper)\r\n",
      "        1    0.000    0.000    0.000    0.000 contextlib.py:385(__init__)\r\n",
      "        2    0.000    0.000    0.000    0.000 contextlib.py:429(callback)\r\n",
      "        2    0.000    0.000    0.000    0.000 contextlib.py:463(_push_exit_callback)\r\n",
      "        1    0.000    0.000    0.000    0.000 contextlib.py:479(__enter__)\r\n",
      "        1    0.000    0.000    0.000    0.000 contextlib.py:482(__exit__)\r\n",
      "        1    0.000    0.000    0.000    0.000 contextlib.py:59(_recreate_cm)\r\n",
      "        1    0.000    0.000    0.000    0.000 contextlib.py:71(__call__)\r\n",
      "        1    0.000    0.000    0.000    0.000 contextlib.py:72(inner)\r\n",
      "       24    0.000    0.000    0.000    0.000 contextlib.py:82(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 contexts.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 contexts.py:212(RNGContext)\r\n",
      "        1    0.000    0.000    0.000    0.000 copy.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 copy.py:55(Error)\r\n",
      "        1    0.000    0.000    0.000    0.000 copy.py:66(copy)\r\n",
      "        1    0.000    0.000    0.000    0.000 copyreg.py:12(pickle)\r\n",
      "        1    0.000    0.000    0.000    0.000 copyreg.py:22(constructor)\r\n",
      "        1    0.000    0.000    0.003    0.003 core.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:1126(_DomainedBinaryOperation)\r\n",
      "        6    0.000    0.000    0.000    0.000 core.py:1147(__init__)\r\n",
      "        4    0.000    0.000    0.000    0.000 core.py:115(doc_note)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:1284(_replace_dtype_fields_recursive)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:1316(_replace_dtype_fields)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:1330(make_mask_descr)\r\n",
      "        3    0.000    0.000    0.000    0.000 core.py:1363(getmask)\r\n",
      "       44    0.000    0.000    0.001    0.000 core.py:138(get_object_signature)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:155(MAError)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:163(MaskError)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:197(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:198(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:201(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:202(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:2383(_MaskedPrintOption)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:2389(__init__)\r\n",
      "        7    0.000    0.000    0.000    0.000 core.py:2555(_arraymethod)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:2600(MaskedIterator)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:2708(MaskedArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:2819(__new__)\r\n",
      "        2    0.000    0.000    0.000    0.000 core.py:2949(_update_from)\r\n",
      "        2    0.000    0.000    0.000    0.000 core.py:2975(__array_finalize__)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:3124(view)\r\n",
      "        4    0.000    0.000    0.000    0.000 core.py:3406(dtype)\r\n",
      "        2    0.000    0.000    0.000    0.000 core.py:3422(shape)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:6234(mvoid)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:6429(MaskedConstant)\r\n",
      "        4    0.000    0.000    0.000    0.000 core.py:6433(__has_singleton)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:6439(__new__)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:6457(__array_finalize__)\r\n",
      "        2    0.000    0.000    0.000    0.000 core.py:6532(__setattr__)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:6624(_extrema_operation)\r\n",
      "        2    0.000    0.000    0.000    0.000 core.py:6633(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:6739(_frommethod)\r\n",
      "       26    0.000    0.000    0.001    0.000 core.py:6750(__init__)\r\n",
      "       26    0.000    0.000    0.001    0.000 core.py:6755(getdoc)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:798(_DomainCheckInterval)\r\n",
      "        3    0.000    0.000    0.000    0.000 core.py:807(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:8081(_convert2ma)\r\n",
      "        8    0.000    0.000    0.000    0.000 core.py:8094(__init__)\r\n",
      "        8    0.000    0.000    0.000    0.000 core.py:8099(getdoc)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:823(_DomainTan)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:831(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:84(MaskedArrayFutureWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:841(_DomainSafeDivide)\r\n",
      "        6    0.000    0.000    0.000    0.000 core.py:847(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:862(_DomainGreater)\r\n",
      "        3    0.000    0.000    0.000    0.000 core.py:868(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:878(_DomainGreaterEqual)\r\n",
      "        2    0.000    0.000    0.000    0.000 core.py:884(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:894(_MaskedUFunc)\r\n",
      "       52    0.000    0.000    0.000    0.000 core.py:895(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:904(_MaskedUnaryOperation)\r\n",
      "       26    0.000    0.000    0.000    0.000 core.py:922(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 core.py:978(_MaskedBinaryOperation)\r\n",
      "       18    0.000    0.000    0.000    0.000 core.py:998(__init__)\r\n",
      "        1    0.000    0.000    0.312    0.312 cprofilers_example.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 cprofilers_example.py:5(is_even)\r\n",
      "        1    0.000    0.000    0.001    0.001 cprofilers_example.py:8(<lambda>)\r\n",
      "        1    0.000    0.000    0.000    0.000 css.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 css.py:10(CSSWarning)\r\n",
      "        5    0.000    0.000    0.000    0.000 css.py:16(_side_expander)\r\n",
      "        1    0.000    0.000    0.000    0.000 css.py:30(CSSResolver)\r\n",
      "        1    0.000    0.000    0.000    0.000 csv.py:130(DictWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 csv.py:165(Sniffer)\r\n",
      "        1    0.000    0.000    0.000    0.000 csv.py:2(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 csv.py:23(Dialect)\r\n",
      "        1    0.000    0.000    0.000    0.000 csv.py:54(excel)\r\n",
      "        1    0.000    0.000    0.000    0.000 csv.py:64(excel_tab)\r\n",
      "        1    0.000    0.000    0.000    0.000 csv.py:69(unix_dialect)\r\n",
      "        1    0.000    0.000    0.000    0.000 csv.py:80(DictReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 ctypeslib.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 ctypeslib.py:177(_ndptr)\r\n",
      "        1    0.000    0.000    0.000    0.000 ctypeslib.py:198(_concrete_ndptr)\r\n",
      "        1    0.000    0.000    0.000    0.000 ctypeslib.py:357(_get_scalar_type_map)\r\n",
      "        1    0.000    0.000    0.000    0.000 ctypeslib.py:368(<dictcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 dataclasses.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.001    0.000 dataclasses.py:1010(wrap)\r\n",
      "        1    0.000    0.000    0.000    0.000 dataclasses.py:155(FrozenInstanceError)\r\n",
      "        1    0.000    0.000    0.000    0.000 dataclasses.py:160(_HAS_DEFAULT_FACTORY_CLASS)\r\n",
      "        1    0.000    0.000    0.000    0.000 dataclasses.py:167(_MISSING_TYPE)\r\n",
      "        1    0.000    0.000    0.000    0.000 dataclasses.py:176(_FIELD_BASE)\r\n",
      "        3    0.000    0.000    0.000    0.000 dataclasses.py:177(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 dataclasses.py:202(_InitVarMeta)\r\n",
      "        1    0.000    0.000    0.000    0.000 dataclasses.py:206(InitVar)\r\n",
      "        1    0.000    0.000    0.000    0.000 dataclasses.py:231(Field)\r\n",
      "       10    0.000    0.000    0.000    0.000 dataclasses.py:244(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 dataclasses.py:281(__set_name__)\r\n",
      "        1    0.000    0.000    0.000    0.000 dataclasses.py:289(_DataclassParams)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:298(__init__)\r\n",
      "       10    0.000    0.000    0.000    0.000 dataclasses.py:320(field)\r\n",
      "        4    0.000    0.000    0.000    0.000 dataclasses.py:342(_tuple_str)\r\n",
      "        4    0.000    0.000    0.000    0.000 dataclasses.py:351(<listcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:356(_recursive_repr)\r\n",
      "        6    0.000    0.000    0.000    0.000 dataclasses.py:375(_create_fn)\r\n",
      "       24    0.000    0.000    0.000    0.000 dataclasses.py:389(<genexpr>)\r\n",
      "       10    0.000    0.000    0.000    0.000 dataclasses.py:402(_field_assign)\r\n",
      "       10    0.000    0.000    0.000    0.000 dataclasses.py:414(_field_init)\r\n",
      "       10    0.000    0.000    0.000    0.000 dataclasses.py:468(_init_param)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:487(_init_fn)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:505(<dictcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:530(<listcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:537(_repr_fn)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:541(<listcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:573(_cmp_fn)\r\n",
      "       20    0.000    0.000    0.000    0.000 dataclasses.py:595(_is_classvar)\r\n",
      "       20    0.000    0.000    0.000    0.000 dataclasses.py:603(_is_initvar)\r\n",
      "       20    0.000    0.000    0.000    0.000 dataclasses.py:610(_is_type)\r\n",
      "       10    0.000    0.000    0.000    0.000 dataclasses.py:669(_get_field)\r\n",
      "        6    0.000    0.000    0.000    0.000 dataclasses.py:751(_set_new_attribute)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:765(_hash_set_none)\r\n",
      "        2    0.000    0.000    0.001    0.000 dataclasses.py:807(_process_class)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:861(<listcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:922(<listcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:938(<listcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:941(<listcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 dataclasses.py:947(<listcomp>)\r\n",
      "        2    0.000    0.000    0.001    0.000 dataclasses.py:996(dataclass)\r\n",
      "        1    0.000    0.000    0.000    0.000 date_converters.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 dates.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 datetime.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetime.py:1141(tzinfo)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetime.py:1211(time)\r\n",
      "        2    0.000    0.000    0.000    0.000 datetime.py:1236(__new__)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetime.py:1559(datetime)\r\n",
      "        3    0.000    0.000    0.000    0.000 datetime.py:1567(__new__)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetime.py:2181(timezone)\r\n",
      "        3    0.000    0.000    0.000    0.000 datetime.py:2201(_create)\r\n",
      "       35    0.000    0.000    0.000    0.000 datetime.py:379(_check_int_field)\r\n",
      "        3    0.000    0.000    0.000    0.000 datetime.py:41(_days_before_year)\r\n",
      "        5    0.000    0.000    0.000    0.000 datetime.py:411(_check_date_fields)\r\n",
      "        5    0.000    0.000    0.000    0.000 datetime.py:424(_check_time_fields)\r\n",
      "        5    0.000    0.000    0.000    0.000 datetime.py:441(_check_tzinfo_arg)\r\n",
      "        5    0.000    0.000    0.000    0.000 datetime.py:46(_days_in_month)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetime.py:469(timedelta)\r\n",
      "       12    0.000    0.000    0.000    0.000 datetime.py:488(__new__)\r\n",
      "        2    0.000    0.000    0.000    0.000 datetime.py:661(__neg__)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetime.py:789(date)\r\n",
      "        2    0.000    0.000    0.000    0.000 datetime.py:819(__new__)\r\n",
      "        2    0.000    0.000    0.002    0.001 datetimelike.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetimelike.py:135(InvalidComparison)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetimelike.py:144(DatetimeLikeArrayMixin)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetimelike.py:1529(DatelikeOps)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetimelike.py:1679(TimelikeOps)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetimelike.py:607(DatetimeTimedeltaMixin)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetimelike.py:77(DatetimeIndexOpsMixin)\r\n",
      "        3    0.000    0.000    0.005    0.002 datetimes.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetimes.py:108(DatetimeIndex)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetimes.py:110(<listcomp>)\r\n",
      "       19    0.000    0.000    0.000    0.000 datetimes.py:113(_field_accessor)\r\n",
      "        1    0.000    0.000    0.000    0.000 datetimes.py:151(DatetimeArray)\r\n",
      "        1    0.000    0.000    0.001    0.001 decimal.py:2(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 decoder.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 decoder.py:20(JSONDecodeError)\r\n",
      "        1    0.000    0.000    0.000    0.000 decoder.py:254(JSONDecoder)\r\n",
      "        1    0.000    0.000    0.000    0.000 decoder.py:284(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 decoder.py:332(decode)\r\n",
      "        1    0.000    0.000    0.000    0.000 decoder.py:343(raw_decode)\r\n",
      "        1    0.000    0.000    0.004    0.004 defchararray.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 defchararray.py:1805(chararray)\r\n",
      "        1    0.000    0.000    0.004    0.004 defmatrix.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 defmatrix.py:72(matrix)\r\n",
      "        1    0.000    0.000    0.007    0.007 describe.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 describe.py:125(SeriesDescriber)\r\n",
      "        1    0.000    0.000    0.000    0.000 describe.py:138(DataFrameDescriber)\r\n",
      "        1    0.000    0.000    0.000    0.000 describe.py:99(NDFrameDescriberAbstract)\r\n",
      "        1    0.000    0.000    0.001    0.001 dis.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 dis.py:209(Instruction)\r\n",
      "        1    0.000    0.000    0.000    0.000 dis.py:479(Bytecode)\r\n",
      "        1    0.000    0.000    0.000    0.000 dispatch.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 dispatch.py:11(should_extension_dispatch)\r\n",
      "        1    0.000    0.000    0.000    0.000 display.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 display.py:17(detect_console_encoding)\r\n",
      "        1    0.000    0.000    0.000    0.000 doc.py:1(<module>)\r\n",
      "      153    0.000    0.000    0.000    0.000 doc.py:9(create_section_header)\r\n",
      "        1    0.000    0.000    0.000    0.000 docstrings.py:1(<module>)\r\n",
      "       36    0.000    0.000    0.000    0.000 docstrings.py:7(make_flex_doc)\r\n",
      "        1    0.000    0.000    0.000    0.000 dtype.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 dtype.py:41(SparseDtype)\r\n",
      "        1    0.000    0.000    0.001    0.001 dtypes.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 dtypes.py:1012(IntervalDtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 dtypes.py:111(CategoricalDtypeType)\r\n",
      "       17    0.000    0.000    0.000    0.000 dtypes.py:1139(construct_from_string)\r\n",
      "        1    0.000    0.000    0.000    0.000 dtypes.py:119(CategoricalDtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 dtypes.py:1201(is_dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 dtypes.py:1267(PandasDtype)\r\n",
      "       17    0.000    0.000    0.000    0.000 dtypes.py:300(construct_from_string)\r\n",
      "        1    0.000    0.000    0.000    0.000 dtypes.py:631(DatetimeTZDtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 dtypes.py:69(PandasExtensionDtype)\r\n",
      "       17    0.000    0.000    0.000    0.000 dtypes.py:738(construct_from_string)\r\n",
      "        1    0.000    0.000    0.000    0.000 dtypes.py:807(PeriodDtype)\r\n",
      "       17    0.000    0.000    0.000    0.000 dtypes.py:897(construct_from_string)\r\n",
      "        1    0.000    0.000    0.000    0.000 easter.py:2(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 einsumfunc.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 encoder.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 encoder.py:104(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 encoder.py:73(JSONEncoder)\r\n",
      "        1    0.000    0.000    0.003    0.003 engines.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 engines.py:107(NumExprEngine)\r\n",
      "        1    0.000    0.000    0.000    0.000 engines.py:124(PythonEngine)\r\n",
      "        1    0.000    0.000    0.000    0.000 engines.py:23(NumExprClobberingError)\r\n",
      "        1    0.000    0.000    0.000    0.000 engines.py:46(AbstractEngine)\r\n",
      "        7    0.000    0.000    0.000    0.000 enum.py:1009(<lambda>)\r\n",
      "        9    0.000    0.000    0.000    0.000 enum.py:1015(_power_of_two)\r\n",
      "      147    0.000    0.000    0.000    0.000 enum.py:12(_is_descriptor)\r\n",
      "       14    0.000    0.000    0.000    0.000 enum.py:143(__prepare__)\r\n",
      "       14    0.001    0.000    0.002    0.000 enum.py:157(__new__)\r\n",
      "       14    0.000    0.000    0.000    0.000 enum.py:175(<dictcomp>)\r\n",
      "       14    0.000    0.000    0.000    0.000 enum.py:200(<setcomp>)\r\n",
      "      191    0.000    0.000    0.000    0.000 enum.py:22(_is_dunder)\r\n",
      "       27    0.000    0.000    0.000    0.000 enum.py:223(<genexpr>)\r\n",
      "      944    0.000    0.000    0.002    0.000 enum.py:313(__call__)\r\n",
      "      191    0.000    0.000    0.000    0.000 enum.py:33(_is_sunder)\r\n",
      "       14    0.000    0.000    0.000    0.000 enum.py:370(__getattr__)\r\n",
      "        7    0.000    0.000    0.000    0.000 enum.py:398(__members__)\r\n",
      "      226    0.000    0.000    0.000    0.000 enum.py:417(__setattr__)\r\n",
      "        8    0.000    0.000    0.001    0.000 enum.py:430(_create_)\r\n",
      "        7    0.000    0.000    0.002    0.000 enum.py:483(_convert_)\r\n",
      "        7    0.000    0.000    0.001    0.000 enum.py:500(<listcomp>)\r\n",
      "      101    0.000    0.000    0.000    0.000 enum.py:506(<lambda>)\r\n",
      "       14    0.000    0.000    0.000    0.000 enum.py:522(_check_for_existing_members)\r\n",
      "       36    0.000    0.000    0.000    0.000 enum.py:532(_get_mixins_)\r\n",
      "       36    0.000    0.000    0.000    0.000 enum.py:543(_find_data_type)\r\n",
      "       14    0.000    0.000    0.000    0.000 enum.py:579(_find_new_)\r\n",
      "      936    0.000    0.000    0.000    0.000 enum.py:631(__new__)\r\n",
      "       14    0.000    0.000    0.000    0.000 enum.py:68(__init__)\r\n",
      "       36    0.000    0.000    0.000    0.000 enum.py:748(name)\r\n",
      "      191    0.000    0.000    0.001    0.000 enum.py:75(__setitem__)\r\n",
      "       30    0.000    0.000    0.000    0.000 enum.py:753(value)\r\n",
      "        3    0.000    0.000    0.000    0.000 enum.py:889(_missing_)\r\n",
      "        3    0.000    0.000    0.000    0.000 enum.py:899(_create_pseudo_member_)\r\n",
      "        6    0.000    0.000    0.000    0.000 enum.py:932(__or__)\r\n",
      "       53    0.000    0.000    0.000    0.000 enum.py:938(__and__)\r\n",
      "        6    0.000    0.000    0.000    0.000 enum.py:957(_high_bit)\r\n",
      "        3    0.000    0.000    0.000    0.000 enum.py:978(_decompose)\r\n",
      "        3    0.000    0.000    0.000    0.000 enum.py:997(<listcomp>)\r\n",
      "        1    0.000    0.000    0.003    0.003 eval.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.003    0.003 ewm.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 ewm.py:119(ExponentialMovingWindow)\r\n",
      "        1    0.000    0.000    0.000    0.000 ewm.py:673(ExponentialMovingWindowGroupby)\r\n",
      "        1    0.000    0.000    0.000    0.000 ewm.py:706(OnlineExponentialMovingWindow)\r\n",
      "        1    0.000    0.000    0.001    0.001 excel.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 excel.py:422(ExcelFormatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 excel.py:52(ExcelCell)\r\n",
      "        1    0.000    0.000    0.000    0.000 excel.py:73(CSSToExcelConverter)\r\n",
      "        1    0.000    0.000    0.000    0.000 exceptions.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 exceptions.py:11(Error)\r\n",
      "        1    0.000    0.000    0.000    0.000 exceptions.py:15(UnknownTimeZoneError)\r\n",
      "        1    0.000    0.000    0.000    0.000 exceptions.py:38(InvalidTimeError)\r\n",
      "        1    0.000    0.000    0.000    0.000 exceptions.py:42(AmbiguousTimeError)\r\n",
      "        1    0.000    0.000    0.000    0.000 exceptions.py:53(NonExistentTimeError)\r\n",
      "        1    0.000    0.000    0.001    0.001 expanding.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 expanding.py:40(Expanding)\r\n",
      "        1    0.000    0.000    0.000    0.000 expanding.py:667(ExpandingGroupby)\r\n",
      "        1    0.000    0.000    0.002    0.002 expr.py:1(<module>)\r\n",
      "        5    0.000    0.000    0.000    0.000 expr.py:120(_compose2)\r\n",
      "        2    0.000    0.000    0.000    0.000 expr.py:127(_compose)\r\n",
      "        2    0.000    0.000    0.000    0.000 expr.py:169(_is_type)\r\n",
      "      120    0.000    0.000    0.000    0.000 expr.py:181(<genexpr>)\r\n",
      "      153    0.000    0.000    0.000    0.000 expr.py:183(<genexpr>)\r\n",
      "       14    0.000    0.000    0.000    0.000 expr.py:188(_filter_nodes)\r\n",
      "      128    0.000    0.000    0.000    0.000 expr.py:192(<genexpr>)\r\n",
      "      119    0.000    0.000    0.000    0.000 expr.py:196(<lambda>)\r\n",
      "      162    0.000    0.000    0.000    0.000 expr.py:257(_node_not_implemented)\r\n",
      "        3    0.000    0.000    0.000    0.000 expr.py:271(disallow)\r\n",
      "        3    0.000    0.000    0.000    0.000 expr.py:281(disallowed)\r\n",
      "       22    0.000    0.000    0.000    0.000 expr.py:293(_op_maker)\r\n",
      "        1    0.000    0.000    0.000    0.000 expr.py:318(add_ops)\r\n",
      "        1    0.000    0.000    0.000    0.000 expr.py:323(f)\r\n",
      "        1    0.000    0.000    0.000    0.000 expr.py:337(BaseExprVisitor)\r\n",
      "        1    0.000    0.000    0.000    0.000 expr.py:381(<dictcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 expr.py:752(PandasExprVisitor)\r\n",
      "        1    0.000    0.000    0.000    0.000 expr.py:770(PythonExprVisitor)\r\n",
      "        1    0.000    0.000    0.000    0.000 expr.py:776(Expr)\r\n",
      "        1    0.000    0.000    0.000    0.000 expressions.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 expressions.py:223(evaluate)\r\n",
      "        1    0.000    0.000    0.000    0.000 expressions.py:41(set_use_numexpr)\r\n",
      "        2    0.000    0.000    0.000    0.000 expressions.py:63(_evaluate_standard)\r\n",
      "        1    0.000    0.000    0.000    0.000 extension.py:1(<module>)\r\n",
      "       13    0.000    0.000    0.000    0.000 extension.py:119(inherit_names)\r\n",
      "       13    0.000    0.000    0.000    0.000 extension.py:132(wrapper)\r\n",
      "        6    0.000    0.000    0.000    0.000 extension.py:142(_make_wrapped_comparison_op)\r\n",
      "       16    0.000    0.000    0.000    0.000 extension.py:162(make_wrapped_arith_op)\r\n",
      "        1    0.000    0.000    0.000    0.000 extension.py:221(ExtensionIndex)\r\n",
      "        1    0.000    0.000    0.000    0.000 extension.py:436(NDArrayBackedExtensionIndex)\r\n",
      "      119    0.000    0.000    0.000    0.000 extension.py:47(inherit_from_data)\r\n",
      "        1    0.000    0.000    0.000    0.000 extras.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 extras.py:1472(MAxisConcatenator)\r\n",
      "        1    0.000    0.000    0.000    0.000 extras.py:1502(mr_class)\r\n",
      "        1    0.000    0.000    0.000    0.000 extras.py:1520(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 extras.py:215(_fromnxfunction)\r\n",
      "       10    0.000    0.000    0.000    0.000 extras.py:235(__init__)\r\n",
      "       10    0.000    0.000    0.000    0.000 extras.py:239(getdoc)\r\n",
      "        1    0.000    0.000    0.000    0.000 extras.py:270(_fromnxfunction_single)\r\n",
      "        1    0.000    0.000    0.000    0.000 extras.py:288(_fromnxfunction_seq)\r\n",
      "        1    0.000    0.000    0.000    0.000 extras.py:301(_fromnxfunction_args)\r\n",
      "        1    0.000    0.000    0.000    0.000 extras.py:326(_fromnxfunction_allargs)\r\n",
      "        1    0.000    0.000    0.000    0.000 feather_format.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 filesystem.py:19(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 filesystem.py:242(LocalFileSystem)\r\n",
      "        1    0.000    0.000    0.000    0.000 filesystem.py:246(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 filesystem.py:250(_get_instance)\r\n",
      "        1    0.000    0.000    0.000    0.000 filesystem.py:315(DaskFileSystem)\r\n",
      "        1    0.000    0.000    0.000    0.000 filesystem.py:36(FileSystem)\r\n",
      "        1    0.000    0.000    0.000    0.000 filesystem.py:381(S3FSWrapper)\r\n",
      "        1    0.000    0.000    0.002    0.002 financial.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 flags.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 flags.py:4(Flags)\r\n",
      "        5    0.000    0.000    0.000    0.000 flags.py:47(__init__)\r\n",
      "        4    0.000    0.000    0.000    0.000 flags.py:51(allows_duplicate_labels)\r\n",
      "        4    0.000    0.000    0.000    0.000 flags.py:83(allows_duplicate_labels)\r\n",
      "        1    0.000    0.000    0.000    0.000 floating.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 floating.py:182(FloatingArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 floating.py:42(FloatingDtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 floating.py:424(Float32Dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 floating.py:431(Float64Dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 fnmatch.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.003    0.001 format.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:1243(GenericArrayFormatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:1349(FloatArrayFormatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:1521(IntArrayFormatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:1532(Datetime64Formatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:1560(ExtensionArrayFormatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:1731(Datetime64TZFormatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:1744(Timedelta64Formatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:1923(EngFormatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:198(CategoricalFormatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:262(SeriesFormatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:422(TextAdjustment)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:436(EastAsianTextAdjustment)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:483(DataFrameFormatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 format.py:931(DataFrameRenderer)\r\n",
      "        1    0.000    0.000    0.037    0.037 frame.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 frame.py:10764(_reindex_for_setitem)\r\n",
      "        1    0.000    0.000    0.000    0.000 frame.py:1352(__len__)\r\n",
      "        1    0.000    0.000    0.000    0.000 frame.py:3418(__getitem__)\r\n",
      "        1    0.000    0.000    0.001    0.001 frame.py:3584(__setitem__)\r\n",
      "        1    0.000    0.000    0.000    0.000 frame.py:3744(_set_item_mgr)\r\n",
      "        1    0.000    0.000    0.000    0.000 frame.py:3769(_set_item)\r\n",
      "        1    0.000    0.000    0.000    0.000 frame.py:3832(_ensure_valid_index)\r\n",
      "        1    0.000    0.000    0.000    0.000 frame.py:3855(_box_col_values)\r\n",
      "        1    0.000    0.000    0.000    0.000 frame.py:3868(_clear_item_cache)\r\n",
      "        1    0.000    0.000    0.000    0.000 frame.py:3871(_get_item_cache)\r\n",
      "        1    0.000    0.000    0.001    0.001 frame.py:4416(assign)\r\n",
      "        1    0.000    0.000    0.000    0.000 frame.py:4484(_sanitize_column)\r\n",
      "        1    0.000    0.000    0.003    0.003 frame.py:456(DataFrame)\r\n",
      "        1    0.000    0.000    0.000    0.000 frame.py:564(_constructor)\r\n",
      "        2    0.000    0.000    0.000    0.000 frame.py:573(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 frequencies.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 frequencies.py:199(_FrequencyInferer)\r\n",
      "        1    0.000    0.000    0.000    0.000 frequencies.py:425(_TimedeltaFrequencyInferer)\r\n",
      "        1    0.000    0.000    0.005    0.005 fromnumeric.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 fromnumeric.py:1701(_ravel_dispatcher)\r\n",
      "        2    0.000    0.000    0.000    0.000 fromnumeric.py:1705(ravel)\r\n",
      "        1    0.000    0.000    0.000    0.000 fromnumeric.py:2876(_prod_dispatcher)\r\n",
      "        1    0.000    0.000    0.000    0.000 fromnumeric.py:2881(prod)\r\n",
      "        2    0.000    0.000    0.000    0.000 fromnumeric.py:3071(_ndim_dispatcher)\r\n",
      "        2    0.000    0.000    0.000    0.000 fromnumeric.py:3075(ndim)\r\n",
      "        1    0.000    0.000    0.000    0.000 fromnumeric.py:70(_wrapreduction)\r\n",
      "        1    0.000    0.000    0.000    0.000 fromnumeric.py:71(<dictcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 frozen.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 frozen.py:18(FrozenList)\r\n",
      "        1    0.000    0.000    0.000    0.000 function.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 function.py:36(CompatValidator)\r\n",
      "       24    0.000    0.000    0.000    0.000 function.py:37(__init__)\r\n",
      "        2    0.000    0.000    0.003    0.002 function_base.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 function_base.py:1895(vectorize)\r\n",
      "      274    0.000    0.000    0.000    0.000 function_base.py:419(_needs_add_docstring)\r\n",
      "      274    0.000    0.000    0.000    0.000 function_base.py:437(_add_docstring)\r\n",
      "      274    0.001    0.000    0.002    0.000 function_base.py:451(add_newdoc)\r\n",
      "        2    0.000    0.000    0.000    0.000 function_base.py:4612(_append_dispatcher)\r\n",
      "        2    0.000    0.000    0.000    0.000 function_base.py:4616(append)\r\n",
      "      568    0.002    0.000    0.003    0.000 functools.py:34(update_wrapper)\r\n",
      "       12    0.000    0.000    0.000    0.000 functools.py:487(lru_cache)\r\n",
      "       12    0.000    0.000    0.000    0.000 functools.py:525(decorating_function)\r\n",
      "      556    0.000    0.000    0.000    0.000 functools.py:64(wraps)\r\n",
      "        1    0.000    0.000    0.000    0.000 gbq.py:1(<module>)\r\n",
      "        3    0.000    0.000    0.068    0.023 generic.py:1(<module>)\r\n",
      "       28    0.000    0.000    0.000    0.000 generic.py:102(generate_property)\r\n",
      "        2    0.000    0.000    0.000    0.000 generic.py:10513(_add_numeric_operations)\r\n",
      "        2    0.000    0.000    0.000    0.000 generic.py:11051(_doc_params)\r\n",
      "        5    0.000    0.000    0.000    0.000 generic.py:11054(<genexpr>)\r\n",
      "        2    0.000    0.000    0.000    0.000 generic.py:125(pin_allowlisted_properties)\r\n",
      "        2    0.000    0.000    0.000    0.000 generic.py:146(pinner)\r\n",
      "        1    0.000    0.000    0.001    0.001 generic.py:161(SeriesGroupBy)\r\n",
      "        1    0.000    0.000    0.003    0.003 generic.py:191(NDFrame)\r\n",
      "        5    0.000    0.000    0.000    0.000 generic.py:233(__init__)\r\n",
      "        4    0.000    0.000    0.000    0.000 generic.py:324(attrs)\r\n",
      "        8    0.000    0.000    0.000    0.000 generic.py:345(flags)\r\n",
      "        1    0.000    0.000    0.000    0.000 generic.py:3860(_check_setitem_copy)\r\n",
      "       20    0.000    0.000    0.000    0.000 generic.py:39(create_pandas_abc_type)\r\n",
      "      109    0.000    0.000    0.000    0.000 generic.py:43(_check)\r\n",
      "        4    0.000    0.000    0.000    0.000 generic.py:5435(__finalize__)\r\n",
      "      4/3    0.000    0.000    0.000    0.000 generic.py:5473(__getattr__)\r\n",
      "        7    0.000    0.000    0.000    0.000 generic.py:5489(__setattr__)\r\n",
      "        1    0.000    0.000    0.000    0.000 generic.py:5827(copy)\r\n",
      "        3    0.000    0.000    0.000    0.000 generic.py:631(_info_axis)\r\n",
      "        1    0.000    0.000    0.000    0.000 generic.py:875(DataFrameGroupBy)\r\n",
      "        1    0.000    0.000    0.000    0.000 genericpath.py:27(isfile)\r\n",
      "        1    0.000    0.000    0.000    0.000 getlimits.py:1(<module>)\r\n",
      "       30    0.000    0.000    0.000    0.000 getlimits.py:17(_fr0)\r\n",
      "       30    0.000    0.000    0.000    0.000 getlimits.py:25(_fr1)\r\n",
      "        1    0.000    0.000    0.000    0.000 getlimits.py:291(finfo)\r\n",
      "        1    0.000    0.000    0.000    0.000 getlimits.py:32(MachArLike)\r\n",
      "        6    0.000    0.000    0.001    0.000 getlimits.py:35(__init__)\r\n",
      "       36    0.000    0.000    0.000    0.000 getlimits.py:39(<lambda>)\r\n",
      "       30    0.000    0.000    0.000    0.000 getlimits.py:40(<lambda>)\r\n",
      "       30    0.000    0.000    0.001    0.000 getlimits.py:41(<lambda>)\r\n",
      "        1    0.000    0.000    0.000    0.000 getlimits.py:445(iinfo)\r\n",
      "       23    0.000    0.000    0.000    0.000 getlimits.py:498(__init__)\r\n",
      "        5    0.000    0.000    0.000    0.000 getlimits.py:509(min)\r\n",
      "       16    0.000    0.000    0.000    0.000 getlimits.py:522(max)\r\n",
      "        8    0.000    0.000    0.000    0.000 getlimits.py:90(_register_type)\r\n",
      "        1    0.000    0.000    0.001    0.001 getlimits.py:94(_register_known_types)\r\n",
      "        1    0.000    0.000    0.003    0.003 groupby.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 groupby.py:523(GroupByPlot)\r\n",
      "        1    0.000    0.000    0.000    0.000 groupby.py:570(BaseGroupBy)\r\n",
      "        1    0.000    0.000    0.001    0.001 groupby.py:774(GroupBy)\r\n",
      "        1    0.000    0.000    0.000    0.000 grouper.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 grouper.py:424(Grouping)\r\n",
      "        1    0.000    0.000    0.000    0.000 grouper.py:49(Grouper)\r\n",
      "        1    0.000    0.000    0.000    0.000 gzip.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 gzip.py:116(BadGzipFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 gzip.py:120(GzipFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 gzip.py:393(_GzipReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 gzip.py:74(_PaddedFile)\r\n",
      "        1    0.000    0.000    0.003    0.003 hashing.py:1(<module>)\r\n",
      "       14    0.000    0.000    0.000    0.000 hashlib.py:123(__get_openssl_constructor)\r\n",
      "        1    0.000    0.000    0.000    0.000 hashlib.py:5(<module>)\r\n",
      "        8    0.000    0.000    0.000    0.000 hashlib.py:79(__get_builtin_constructor)\r\n",
      "        1    0.000    0.000    0.000    0.000 hdfs.py:19(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 hdfs.py:29(HadoopFileSystem)\r\n",
      "        1    0.000    0.000    0.000    0.000 helper.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 hermite.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 hermite.py:1641(Hermite)\r\n",
      "        1    0.000    0.000    0.000    0.000 hermite_e.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 hermite_e.py:1635(HermiteE)\r\n",
      "        1    0.000    0.000    0.000    0.000 histograms.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 hmac.py:1(<module>)\r\n",
      "      257    0.000    0.000    0.000    0.000 hmac.py:17(<genexpr>)\r\n",
      "      257    0.000    0.000    0.000    0.000 hmac.py:18(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 hmac.py:26(HMAC)\r\n",
      "        1    0.000    0.000    0.000    0.000 html.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 html.py:151(_HtmlFrameParser)\r\n",
      "        1    0.000    0.000    0.000    0.000 html.py:526(_BeautifulSoupHtml5LibFrameParser)\r\n",
      "        1    0.000    0.000    0.000    0.000 html.py:638(_LxmlFrameParser)\r\n",
      "        1    0.000    0.000    0.009    0.009 index_tricks.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:108(nd_grid)\r\n",
      "        2    0.000    0.000    0.000    0.000 index_tricks.py:143(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:208(MGridClass)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:250(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:255(OGridClass)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:294(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:300(AxisConcatenator)\r\n",
      "        3    0.000    0.000    0.000    0.000 index_tricks.py:310(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:316(__getitem__)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:422(RClass)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:517(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:522(CClass)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:547(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:554(ndenumerate)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:603(ndindex)\r\n",
      "        1    0.000    0.000    0.000    0.000 index_tricks.py:680(IndexExpression)\r\n",
      "        2    0.000    0.000    0.000    0.000 index_tricks.py:724(__init__)\r\n",
      "        2    0.000    0.000    0.000    0.000 indexers.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexers.py:100(VariableWindowIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexers.py:126(VariableOffsetWindowIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexers.py:208(ExpandingIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexers.py:226(FixedForwardWindowIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexers.py:276(GroupbyIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexers.py:361(ExponentialMovingWindowIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexers.py:40(BaseIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexers.py:70(FixedWindowIndexer)\r\n",
      "        1    0.000    0.000    0.001    0.001 indexing.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexing.py:124(IndexingError)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexing.py:128(IndexingMixin)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexing.py:1380(_iLocIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexing.py:2204(_ScalarAccessIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexing.py:2240(_AtIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexing.py:2289(_iAtIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexing.py:2323(convert_to_index_sliceable)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexing.py:628(_LocationIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexing.py:77(_IndexSlice)\r\n",
      "        1    0.000    0.000    0.000    0.000 indexing.py:953(_LocIndexer)\r\n",
      "        1    0.000    0.000    0.000    0.000 inference.py:1(<module>)\r\n",
      "       35    0.000    0.000    0.000    0.000 inference.py:321(is_hashable)\r\n",
      "        1    0.000    0.000    0.000    0.000 info.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 info.py:228(DataFrameInfo)\r\n",
      "        1    0.000    0.000    0.000    0.000 info.py:304(InfoPrinterAbstract)\r\n",
      "        1    0.000    0.000    0.000    0.000 info.py:322(DataFrameInfoPrinter)\r\n",
      "        1    0.000    0.000    0.000    0.000 info.py:403(TableBuilderAbstract)\r\n",
      "        1    0.000    0.000    0.000    0.000 info.py:459(DataFrameTableBuilder)\r\n",
      "        1    0.000    0.000    0.000    0.000 info.py:510(DataFrameTableBuilderNonVerbose)\r\n",
      "        1    0.000    0.000    0.000    0.000 info.py:528(TableBuilderVerboseMixin)\r\n",
      "        1    0.000    0.000    0.000    0.000 info.py:621(DataFrameTableBuilderVerbose)\r\n",
      "        1    0.000    0.000    0.000    0.000 info.py:99(BaseInfo)\r\n",
      "        1    0.000    0.000    0.004    0.004 inspect.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 inspect.py:1102(getfullargspec)\r\n",
      "      188    0.000    0.000    0.000    0.000 inspect.py:158(isfunction)\r\n",
      "      186    0.000    0.000    0.000    0.000 inspect.py:1720(_signature_get_user_defined_method)\r\n",
      "       62    0.000    0.000    0.000    0.000 inspect.py:1812(_signature_bound_method)\r\n",
      "       62    0.000    0.000    0.000    0.000 inspect.py:1838(_signature_is_builtin)\r\n",
      "      186    0.000    0.000    0.000    0.000 inspect.py:1850(_signature_is_functionlike)\r\n",
      "       63    0.000    0.000    0.001    0.000 inspect.py:2124(_signature_from_function)\r\n",
      "   125/63    0.001    0.000    0.003    0.000 inspect.py:2218(_signature_from_callable)\r\n",
      "        1    0.000    0.000    0.000    0.000 inspect.py:2420(_void)\r\n",
      "        1    0.000    0.000    0.000    0.000 inspect.py:2424(_empty)\r\n",
      "        1    0.000    0.000    0.000    0.000 inspect.py:2428(_ParameterKind)\r\n",
      "        1    0.000    0.000    0.000    0.000 inspect.py:2457(Parameter)\r\n",
      "      818    0.001    0.000    0.002    0.000 inspect.py:2489(__init__)\r\n",
      "      947    0.000    0.000    0.000    0.000 inspect.py:2539(name)\r\n",
      "      517    0.000    0.000    0.000    0.000 inspect.py:2543(default)\r\n",
      "       29    0.000    0.000    0.000    0.000 inspect.py:2547(annotation)\r\n",
      "     1056    0.000    0.000    0.000    0.000 inspect.py:2551(kind)\r\n",
      "      114    0.000    0.000    0.000    0.000 inspect.py:2555(replace)\r\n",
      "        1    0.000    0.000    0.000    0.000 inspect.py:2612(BoundArguments)\r\n",
      "        1    0.000    0.000    0.000    0.000 inspect.py:2742(Signature)\r\n",
      "      317    0.001    0.000    0.001    0.000 inspect.py:2772(__init__)\r\n",
      "       16    0.000    0.000    0.000    0.000 inspect.py:2821(<genexpr>)\r\n",
      "       62    0.000    0.000    0.000    0.000 inspect.py:285(isbuiltin)\r\n",
      "       62    0.000    0.000    0.003    0.000 inspect.py:2851(from_callable)\r\n",
      "      125    0.000    0.000    0.000    0.000 inspect.py:2857(parameters)\r\n",
      "        2    0.000    0.000    0.000    0.000 inspect.py:2861(return_annotation)\r\n",
      "       62    0.000    0.000    0.000    0.000 inspect.py:2865(replace)\r\n",
      "       62    0.000    0.000    0.003    0.000 inspect.py:3103(signature)\r\n",
      "      124    0.000    0.000    0.000    0.000 inspect.py:493(unwrap)\r\n",
      "      124    0.000    0.000    0.000    0.000 inspect.py:513(_is_wrapper)\r\n",
      "      248    0.000    0.000    0.000    0.000 inspect.py:72(isclass)\r\n",
      "        1    0.000    0.000    0.000    0.000 inspect.py:895(EndOfBlock)\r\n",
      "        1    0.000    0.000    0.000    0.000 inspect.py:897(BlockFinder)\r\n",
      "       62    0.000    0.000    0.000    0.000 inspect.py:90(ismethoddescriptor)\r\n",
      "        1    0.000    0.000    0.001    0.001 integer.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 integer.py:236(IntegerArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 integer.py:48(_IntegerDtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 integer.py:506(Int8Dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 integer.py:513(Int16Dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 integer.py:520(Int32Dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 integer.py:527(Int64Dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 integer.py:534(UInt8Dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 integer.py:541(UInt16Dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 integer.py:548(UInt32Dtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 integer.py:555(UInt64Dtype)\r\n",
      "        2    0.000    0.000    0.007    0.003 interval.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 interval.py:145(IntervalIndex)\r\n",
      "        1    0.000    0.000    0.001    0.001 interval.py:162(IntervalArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 invalid.py:1(<module>)\r\n",
      "       34    0.000    0.000    0.000    0.000 invalid.py:38(make_invalid_op)\r\n",
      "        1    0.000    0.000    0.000    0.000 ipc.py:20(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 ipc.py:34(RecordBatchStreamReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 ipc.py:71(RecordBatchStreamWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 ipc.py:81(RecordBatchFileReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 ipc.py:98(RecordBatchFileWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 isoparser.py:2(<module>)\r\n",
      "        4    0.000    0.000    0.000    0.000 isoparser.py:22(_takes_ascii)\r\n",
      "        1    0.000    0.000    0.000    0.000 isoparser.py:42(isoparser)\r\n",
      "        1    0.000    0.000    0.000    0.000 isoparser.py:43(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 laguerre.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 laguerre.py:1592(Laguerre)\r\n",
      "        1    0.000    0.000    0.000    0.000 lazy.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 lazy.py:118(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 lazy.py:121(LazySet)\r\n",
      "        2    0.000    0.000    0.000    0.000 lazy.py:139(__new__)\r\n",
      "        2    0.000    0.000    0.000    0.000 lazy.py:144(LazySet)\r\n",
      "       84    0.000    0.000    0.000    0.000 lazy.py:149(lazy)\r\n",
      "        1    0.000    0.000    0.000    0.000 lazy.py:16(LazyDict)\r\n",
      "        1    0.000    0.000    0.000    0.000 lazy.py:172(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 lazy.py:71(LazyList)\r\n",
      "        2    0.000    0.000    0.000    0.000 lazy.py:84(__new__)\r\n",
      "        2    0.000    0.000    0.000    0.000 lazy.py:91(LazyList)\r\n",
      "       62    0.000    0.000    0.000    0.000 lazy.py:96(lazy)\r\n",
      "        1    0.000    0.000    0.000    0.000 legendre.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 legendre.py:1608(Legendre)\r\n",
      "        1    0.000    0.000    0.003    0.003 linalg.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 linalg.py:43(LinAlgError)\r\n",
      "        1    0.000    0.000    0.000    0.000 linalg.py:73(_determine_error_states)\r\n",
      "        1    0.000    0.000    0.001    0.001 linecache.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 locale.py:384(normalize)\r\n",
      "        2    0.000    0.000    0.000    0.000 locale.py:467(_parse_localename)\r\n",
      "        2    0.000    0.000    0.000    0.000 locale.py:575(getlocale)\r\n",
      "        1    0.000    0.000    0.002    0.002 localization.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 lzma.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 lzma.py:38(LZMAFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 machar.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 machar.py:16(MachAr)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:1144(insert)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:1530(SingleBlockManager)\r\n",
      "        3    0.000    0.000    0.000    0.000 managers.py:1539(__init__)\r\n",
      "        2    0.000    0.000    0.000    0.000 managers.py:1569(from_array)\r\n",
      "        2    0.000    0.000    0.000    0.000 managers.py:158(blknos)\r\n",
      "        3    0.000    0.000    0.000    0.000 managers.py:1619(_block)\r\n",
      "        3    0.000    0.000    0.000    0.000 managers.py:1674(internal_values)\r\n",
      "        2    0.000    0.000    0.000    0.000 managers.py:174(blklocs)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:1756(_extract_array)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:1760(create_block_manager_from_arrays)\r\n",
      "        3    0.000    0.000    0.000    0.000 managers.py:1768(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:1770(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:1811(_form_blocks)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:1913(_multi_blockify)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:1920(<lambda>)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:1950(_stack_arrays)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:2018(_fast_count_smallints)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:224(_rebuild_blknos_and_blklocs)\r\n",
      "        2    0.000    0.000    0.000    0.000 managers.py:245(items)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:276(apply)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:305(<dictcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 managers.py:468(is_consolidated)\r\n",
      "        2    0.000    0.000    0.000    0.000 managers.py:476(_consolidate_check)\r\n",
      "        2    0.000    0.000    0.000    0.000 managers.py:477(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:574(copy)\r\n",
      "        2    0.000    0.000    0.000    0.000 managers.py:592(copy_func)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:595(<listcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 managers.py:622(_consolidate_inplace)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:874(BlockManager)\r\n",
      "        2    0.000    0.000    0.000    0.000 managers.py:884(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:89(BaseBlockManager)\r\n",
      "        3    0.000    0.000    0.000    0.000 managers.py:892(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:916(_verify_integrity)\r\n",
      "        2    0.000    0.000    0.000    0.000 managers.py:918(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:929(from_blocks)\r\n",
      "        1    0.000    0.000    0.000    0.000 managers.py:977(iget)\r\n",
      "        1    0.000    0.000    0.000    0.000 mask_ops.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.002    0.002 masked.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 masked.py:105(BaseMaskedArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 masked.py:68(BaseMaskedDtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 masked_reductions.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 melt.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 memmap.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 memmap.py:22(memmap)\r\n",
      "        1    0.000    0.000    0.000    0.000 merge.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 merge.py:1599(_OrderedMerge)\r\n",
      "        1    0.000    0.000    0.000    0.000 merge.py:1704(_AsOfMerge)\r\n",
      "        1    0.000    0.000    0.000    0.000 merge.py:603(_MergeOperation)\r\n",
      "        1    0.000    0.000    0.000    0.000 methods.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 methods.py:116(<dictcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 methods.py:120(_add_methods)\r\n",
      "        2    0.000    0.000    0.000    0.000 methods.py:14(_get_method_wrappers)\r\n",
      "        2    0.000    0.000    0.003    0.001 methods.py:46(add_flex_arithmetic_methods)\r\n",
      "        8    0.000    0.000    0.000    0.000 methods.py:66(<genexpr>)\r\n",
      "        2    0.000    0.000    0.003    0.001 methods.py:71(_create_methods)\r\n",
      "        3    0.000    0.000    0.000    0.000 missing.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 missing.py:102(clean_fill_method)\r\n",
      "        2    0.000    0.000    0.000    0.000 missing.py:140(dispatch_fill_zeros)\r\n",
      "        2    0.000    0.000    0.000    0.000 missing.py:144(_isna)\r\n",
      "        1    0.000    0.000    0.000    0.000 missing.py:37(fill_zeros)\r\n",
      "        1    0.000    0.000    0.000    0.000 missing.py:606(is_valid_na_for_dtype)\r\n",
      "        2    0.000    0.000    0.000    0.000 missing.py:61(isna)\r\n",
      "        4    0.000    0.000    0.000    0.000 missing.py:807(_datetimelike_compat)\r\n",
      "        1    0.000    0.000    0.000    0.000 missing.py:883(clean_reindex_fill_method)\r\n",
      "        1    0.000    0.000    0.000    0.000 mixins.py:1(<module>)\r\n",
      "       20    0.000    0.000    0.000    0.000 mixins.py:16(_binary_method)\r\n",
      "       14    0.000    0.000    0.000    0.000 mixins.py:26(_reflected_binary_method)\r\n",
      "       13    0.000    0.000    0.000    0.000 mixins.py:36(_inplace_binary_method)\r\n",
      "       13    0.000    0.000    0.000    0.000 mixins.py:44(_numeric_methods)\r\n",
      "        4    0.000    0.000    0.000    0.000 mixins.py:51(_unary_method)\r\n",
      "        1    0.000    0.000    0.000    0.000 mixins.py:59(NDArrayOperatorsMixin)\r\n",
      "        1    0.000    0.000    0.001    0.001 multi.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 multi.py:108(MultiIndexUIntEngine)\r\n",
      "        1    0.000    0.000    0.000    0.000 multi.py:147(MultiIndexPyIntEngine)\r\n",
      "        1    0.000    0.000    0.000    0.000 multi.py:188(names_compat)\r\n",
      "        1    0.000    0.000    0.001    0.001 multi.py:207(MultiIndex)\r\n",
      "        1    0.000    0.000    0.029    0.029 multiarray.py:1(<module>)\r\n",
      "        4    0.000    0.000    0.000    0.000 multiarray.py:1043(copyto)\r\n",
      "        5    0.000    0.000    0.000    0.000 multiarray.py:143(concatenate)\r\n",
      "        1    0.000    0.000    0.000    0.000 multiarray.py:852(bincount)\r\n",
      "        1    0.000    0.000    0.001    0.001 nanfunctions.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 nanops.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 nanops.py:106(bottleneck_switch)\r\n",
      "        6    0.000    0.000    0.000    0.000 nanops.py:107(__init__)\r\n",
      "        6    0.000    0.000    0.000    0.000 nanops.py:111(__call__)\r\n",
      "        6    0.000    0.000    0.000    0.000 nanops.py:1616(make_nancomp)\r\n",
      "        4    0.000    0.000    0.000    0.000 nanops.py:389(_datetimelike_compat)\r\n",
      "        1    0.000    0.000    0.000    0.000 nanops.py:64(set_use_bottleneck)\r\n",
      "        1    0.000    0.000    0.000    0.000 nanops.py:74(disallow)\r\n",
      "       11    0.000    0.000    0.000    0.000 nanops.py:75(__init__)\r\n",
      "       29    0.000    0.000    0.000    0.000 nanops.py:77(<genexpr>)\r\n",
      "       11    0.000    0.000    0.000    0.000 nanops.py:82(__call__)\r\n",
      "        2    0.000    0.000    0.000    0.000 nanops.py:995(_nanminmax)\r\n",
      "        1    0.000    0.000    0.005    0.005 npyio.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 npyio.py:115(NpzFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 npyio.py:51(BagObj)\r\n",
      "        1    0.000    0.000    0.001    0.001 ntpath.py:2(<module>)\r\n",
      "        3    0.000    0.000    0.000    0.000 numba_.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 numbers.py:12(Number)\r\n",
      "        1    0.000    0.000    0.000    0.000 numbers.py:147(Real)\r\n",
      "        1    0.000    0.000    0.000    0.000 numbers.py:267(Rational)\r\n",
      "        1    0.000    0.000    0.000    0.000 numbers.py:294(Integral)\r\n",
      "        1    0.000    0.000    0.000    0.000 numbers.py:32(Complex)\r\n",
      "        1    0.000    0.000    0.000    0.000 numbers.py:4(<module>)\r\n",
      "        4    0.000    0.000    0.011    0.003 numeric.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 numeric.py:144(ones)\r\n",
      "        1    0.000    0.000    0.000    0.000 numeric.py:176(_validate_dtype)\r\n",
      "        6    0.000    0.000    0.000    0.000 numeric.py:2446(extend_all)\r\n",
      "        3    0.000    0.000    0.000    0.000 numeric.py:268(full)\r\n",
      "        3    0.000    0.000    0.000    0.000 numeric.py:296(_is_all_dates)\r\n",
      "        1    0.000    0.000    0.000    0.000 numeric.py:328(IntegerIndex)\r\n",
      "        1    0.000    0.000    0.000    0.000 numeric.py:344(Int64Index)\r\n",
      "        1    0.000    0.000    0.000    0.000 numeric.py:359(UInt64Index)\r\n",
      "        1    0.000    0.000    0.000    0.000 numeric.py:384(Float64Index)\r\n",
      "        1    0.000    0.000    0.000    0.000 numeric.py:40(NumericDtype)\r\n",
      "        1    0.000    0.000    0.000    0.000 numeric.py:59(ComplexWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 numeric.py:80(NumericArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 numeric.py:82(NumericIndex)\r\n",
      "        1    0.000    0.000    0.002    0.002 numerictypes.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 numerictypes.py:396(_typedict)\r\n",
      "        1    0.000    0.000    0.000    0.000 numerictypes.py:412(_construct_lookups)\r\n",
      "        2    0.000    0.000    0.000    0.000 numerictypes.py:545(_can_coerce_all)\r\n",
      "        8    0.000    0.000    0.000    0.000 numerictypes.py:554(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 numerictypes.py:560(_register_types)\r\n",
      "        1    0.000    0.000    0.000    0.000 numerictypes.py:569(find_common_type)\r\n",
      "        1    0.000    0.000    0.000    0.000 numerictypes.py:621(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 numerictypes.py:622(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 numpy_.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 numpy_.py:30(PandasArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 object_array.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 object_array.py:24(ObjectStringArrayMixin)\r\n",
      "        1    0.000    0.000    0.000    0.000 offsets.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 online.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 online.py:89(EWMMeanState)\r\n",
      "        1    0.000    0.000    0.000    0.000 opcode.py:2(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 opcode.py:37(<listcomp>)\r\n",
      "      120    0.000    0.000    0.000    0.000 opcode.py:39(def_op)\r\n",
      "       12    0.000    0.000    0.000    0.000 opcode.py:43(name_op)\r\n",
      "        6    0.000    0.000    0.000    0.000 opcode.py:47(jrel_op)\r\n",
      "        5    0.000    0.000    0.000    0.000 opcode.py:51(jabs_op)\r\n",
      "        3    0.000    0.000    0.002    0.001 ops.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:1086(BinGrouper)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:109(WrappedCythonOp)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:1270(DataSplitter)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:1310(SeriesSplitter)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:1324(FrameSplitter)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:191(Constant)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:211(Op)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:367(BinOp)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:523(Div)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:552(UnaryOp)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:600(MathCall)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:616(FuncNode)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:649(BaseGrouper)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:68(UndefinedVariableError)\r\n",
      "        1    0.000    0.000    0.000    0.000 ops.py:82(Term)\r\n",
      "        1    0.000    0.000    0.000    0.000 orc.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 os.py:1073(__subclasshook__)\r\n",
      "        1    0.000    0.000    0.000    0.000 os.py:42(_get_exports_list)\r\n",
      "        1    0.000    0.000    0.000    0.000 os.py:46(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 os.py:613(get_exec_path)\r\n",
      "        8    0.000    0.000    0.000    0.000 os.py:670(__getitem__)\r\n",
      "        2    0.000    0.000    0.000    0.000 os.py:678(__setitem__)\r\n",
      "        2    0.000    0.000    0.000    0.000 os.py:684(__delitem__)\r\n",
      "       14    0.000    0.000    0.000    0.000 os.py:748(encode)\r\n",
      "        1    0.000    0.000    0.000    0.000 os.py:752(decode)\r\n",
      "       15    0.000    0.000    0.000    0.000 os.py:800(fsencode)\r\n",
      "        1    0.000    0.000    0.026    0.026 overrides.py:1(<module>)\r\n",
      "       78    0.000    0.000    0.000    0.000 overrides.py:105(decorator)\r\n",
      "      316    0.000    0.000    0.000    0.000 overrides.py:124(array_function_dispatch)\r\n",
      "      316    0.001    0.000    0.026    0.000 overrides.py:166(decorator)\r\n",
      "       23    0.000    0.000    0.000    0.000 overrides.py:202(array_function_from_dispatcher)\r\n",
      "       23    0.000    0.000    0.002    0.000 overrides.py:206(decorator)\r\n",
      "      286    0.001    0.000    0.004    0.000 overrides.py:72(verify_matching_signatures)\r\n",
      "       78    0.000    0.000    0.000    0.000 overrides.py:94(set_module)\r\n",
      "        1    0.000    0.000    0.000    0.000 parquet.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 parquet.py:109(BaseImpl)\r\n",
      "        1    0.000    0.000    0.000    0.000 parquet.py:145(PyArrowImpl)\r\n",
      "        1    0.000    0.000    0.000    0.000 parquet.py:250(FastParquetImpl)\r\n",
      "        1    0.000    0.000    0.001    0.001 parse.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:127(_ResultMixinStr)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:135(_ResultMixinBytes)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:143(_NetlocResultMixinBase)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:180(_NetlocResultMixinStr)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:210(_NetlocResultMixinBytes)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:315(DefragResult)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:323(SplitResult)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:328(ParseResult)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:334(DefragResultBytes)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:342(SplitResultBytes)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:347(ParseResultBytes)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:353(_fix_result_transcoding)\r\n",
      "        1    0.000    0.000    0.000    0.000 parse.py:777(Quoter)\r\n",
      "        1    0.000    0.000    0.000    0.000 parsing.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.005    0.005 pathlib.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:1002(PurePosixPath)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:1012(PureWindowsPath)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:1025(Path)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:120(_WindowsFlavour)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:136(<setcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:137(<setcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:1562(PosixPath)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:1569(WindowsPath)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:285(_PosixFlavour)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:394(_Accessor)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:399(_NormalAccessor)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:479(_Selector)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:504(_TerminatingSelector)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:510(_PreciseSelector)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:526(_WildcardSelector)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:557(_RecursiveWildcardSelector)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:57(_Flavour)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:601(_PathParents)\r\n",
      "        2    0.000    0.000    0.000    0.000 pathlib.py:61(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 pathlib.py:629(PurePath)\r\n",
      "        2    0.000    0.000    0.000    0.000 period.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 period.py:80(PeriodIndex)\r\n",
      "       12    0.000    0.000    0.000    0.000 period.py:84(_field_accessor)\r\n",
      "        1    0.000    0.000    0.000    0.000 period.py:95(PeriodArray)\r\n",
      "        2    0.000    0.000    0.003    0.002 pickle.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle.py:1136(_Unpickler)\r\n",
      "        1    0.000    0.000    0.001    0.001 pickle.py:197(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle.py:200(_Framer)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle.py:263(_Unframer)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle.py:407(_Pickler)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle.py:73(PickleError)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle.py:77(PicklingError)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle.py:84(UnpicklingError)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle.py:97(_Stop)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle_compat.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle_compat.py:201(Unpickler)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle_compat.py:78(_LoadSparseSeries)\r\n",
      "        1    0.000    0.000    0.000    0.000 pickle_compat.py:96(_LoadSparseFrame)\r\n",
      "        1    0.000    0.000    0.000    0.000 pivot.py:1(<module>)\r\n",
      "        3    0.000    0.000    0.000    0.000 platform.py:1077(python_implementation)\r\n",
      "        1    0.000    0.000    0.004    0.004 platform.py:3(<module>)\r\n",
      "        1    0.000    0.000    0.002    0.002 platform.py:604(_syscmd_uname)\r\n",
      "        1    0.000    0.000    0.002    0.002 platform.py:747(uname)\r\n",
      "        1    0.000    0.000    0.002    0.002 platform.py:885(system)\r\n",
      "        3    0.000    0.000    0.000    0.000 platform.py:973(_sys_version)\r\n",
      "        2    0.000    0.000    0.003    0.001 polynomial.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 polynomial.py:1007(poly1d)\r\n",
      "        1    0.000    0.000    0.000    0.000 polynomial.py:1456(Polynomial)\r\n",
      "        1    0.000    0.000    0.000    0.000 polynomial.py:28(RankWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 polyutils.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 polyutils.py:60(RankWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 polyutils.py:64(PolyError)\r\n",
      "        1    0.000    0.000    0.000    0.000 polyutils.py:68(PolyDomainError)\r\n",
      "        1    0.000    0.000    0.000    0.000 polyutils.py:81(PolyBase)\r\n",
      "        5    0.000    0.000    0.000    0.000 posixpath.py:150(dirname)\r\n",
      "       22    0.000    0.000    0.000    0.000 posixpath.py:41(_get_sep)\r\n",
      "        1    0.000    0.000    0.000    0.000 posixpath.py:52(normcase)\r\n",
      "        1    0.000    0.000    0.000    0.000 posixpath.py:60(isabs)\r\n",
      "       16    0.000    0.000    0.000    0.000 posixpath.py:71(join)\r\n",
      "        1    0.000    0.000    0.000    0.000 pprint.py:103(PrettyPrinter)\r\n",
      "        1    0.000    0.000    0.000    0.000 pprint.py:11(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 pprint.py:77(_safe_key)\r\n",
      "        1    0.000    0.000    0.000    0.000 printing.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 printing.py:546(PrettyDict)\r\n",
      "        1    0.000    0.000    0.000    0.000 putmask.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.015    0.015 py3k.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 py3k.py:88(contextlib_nullcontext)\r\n",
      "        1    0.000    0.000    0.019    0.019 pyarrow.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.001    0.001 pytables.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:168(PossibleDataLossError)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:172(ClosedFileError)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:176(IncompatibilityWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:1836(TableIterator)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:187(AttributeConflictWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:1948(IndexCol)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:197(DuplicateWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:2234(GenericIndexCol)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:2263(DataCol)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:2548(DataIndexableCol)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:2575(GenericDataIndexableCol)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:2581(Fixed)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:263(FilterBinOp)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:2757(GenericFixed)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:2761(<dictcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:3109(SeriesFixed)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:3141(BlockManagerFixed)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:3236(FrameFixed)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:324(JointFilterBinOp)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:3241(Table)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:332(ConditionBinOp)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:378(JointConditionBinOp)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:384(UnaryOp)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:39(PyTablesScope)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:404(PyTablesExprVisitor)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:4238(WORMTable)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:4268(AppendableTable)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:4497(AppendableFrameTable)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:4597(AppendableSeriesTable)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:4646(AppendableMultiSeriesTable)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:4663(GenericTable)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:4729(AppendableMultiFrameTable)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:488(HDFStore)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:515(PyTablesExpr)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:5185(Selection)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:55(Term)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:622(TermValue)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:88(Constant)\r\n",
      "        1    0.000    0.000    0.000    0.000 pytables.py:97(BinOp)\r\n",
      "        1    0.000    0.000    0.000    0.000 python_parser.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 python_parser.py:1087(FixedWidthReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 python_parser.py:1193(FixedWidthFieldParser)\r\n",
      "        1    0.000    0.000    0.000    0.000 python_parser.py:43(PythonParser)\r\n",
      "        1    0.000    0.000    0.000    0.000 quantile.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 queue.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 queue.py:22(Full)\r\n",
      "        1    0.000    0.000    0.000    0.000 queue.py:220(PriorityQueue)\r\n",
      "        1    0.000    0.000    0.000    0.000 queue.py:239(LifoQueue)\r\n",
      "        1    0.000    0.000    0.000    0.000 queue.py:255(_PySimpleQueue)\r\n",
      "        1    0.000    0.000    0.000    0.000 queue.py:27(Queue)\r\n",
      "        1    0.000    0.000    0.001    0.001 random.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 random.py:103(__init_subclass__)\r\n",
      "        1    0.000    0.000    0.000    0.000 random.py:123(seed)\r\n",
      "        1    0.000    0.000    0.000    0.000 random.py:709(SystemRandom)\r\n",
      "        1    0.000    0.000    0.000    0.000 random.py:721(getrandbits)\r\n",
      "        1    0.000    0.000    0.000    0.000 random.py:729(seed)\r\n",
      "        1    0.000    0.000    0.000    0.000 random.py:78(Random)\r\n",
      "        2    0.000    0.000    0.000    0.000 random.py:94(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 range.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 range.py:105(__new__)\r\n",
      "        2    0.000    0.000    0.000    0.000 range.py:160(_simple_new)\r\n",
      "        1    0.000    0.000    0.000    0.000 range.py:461(_view)\r\n",
      "        1    0.000    0.000    0.000    0.000 range.py:543(equals)\r\n",
      "        1    0.000    0.000    0.000    0.000 range.py:57(RangeIndex)\r\n",
      "        9    0.000    0.000    0.000    0.000 range.py:806(__len__)\r\n",
      "      268    0.000    0.000    0.001    0.000 re.py:188(match)\r\n",
      "     1132    0.000    0.000    0.006    0.000 re.py:203(sub)\r\n",
      "        4    0.000    0.000    0.000    0.000 re.py:223(split)\r\n",
      "       50    0.000    0.000    0.014    0.000 re.py:250(compile)\r\n",
      "       88    0.000    0.000    0.000    0.000 re.py:270(escape)\r\n",
      "     1454    0.001    0.000    0.016    0.000 re.py:289(_compile)\r\n",
      "        2    0.000    0.000    0.000    0.000 re.py:315(_compile_repl)\r\n",
      "        6    0.000    0.000    0.000    0.000 re.py:325(_subx)\r\n",
      "        1    0.000    0.000    0.002    0.002 readers.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 readers.py:765(TextFileReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 records.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 records.py:233(record)\r\n",
      "        1    0.000    0.000    0.000    0.000 records.py:318(recarray)\r\n",
      "        1    0.000    0.000    0.000    0.000 records.py:78(_OrderedCounter)\r\n",
      "        1    0.000    0.000    0.000    0.000 records.py:97(format_parser)\r\n",
      "        8    0.000    0.000    0.000    0.000 relativedelta.py:13(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 relativedelta.py:18(relativedelta)\r\n",
      "        1    0.000    0.000    0.000    0.000 relativedelta.py:2(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 replace.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 reshape.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 reshape.py:53(_Unstacker)\r\n",
      "        1    0.000    0.000    0.001    0.001 rolling.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 rolling.py:109(BaseWindow)\r\n",
      "        1    0.000    0.000    0.000    0.000 rolling.py:1139(RollingAndExpandingMixin)\r\n",
      "        1    0.000    0.000    0.001    0.001 rolling.py:1468(Rolling)\r\n",
      "        1    0.000    0.000    0.000    0.000 rolling.py:2298(RollingGroupby)\r\n",
      "        1    0.000    0.000    0.000    0.000 rolling.py:552(BaseWindowGroupby)\r\n",
      "        1    0.000    0.000    0.000    0.000 rolling.py:750(Window)\r\n",
      "        1    0.000    0.000    0.000    0.000 roperator.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 sasreader.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 sasreader.py:25(ReaderBase)\r\n",
      "        1    0.000    0.000    0.001    0.001 scanner.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.002    0.002 scimath.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 scope.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 scope.py:87(Scope)\r\n",
      "        1    0.000    0.000    0.003    0.003 secrets.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 selectors.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 selectors.py:206(_BaseSelectorImpl)\r\n",
      "        1    0.000    0.000    0.000    0.000 selectors.py:290(SelectSelector)\r\n",
      "        1    0.000    0.000    0.000    0.000 selectors.py:341(_PollLikeSelector)\r\n",
      "        1    0.000    0.000    0.000    0.000 selectors.py:433(PollSelector)\r\n",
      "        1    0.000    0.000    0.000    0.000 selectors.py:442(EpollSelector)\r\n",
      "        1    0.000    0.000    0.000    0.000 selectors.py:60(_SelectorMapping)\r\n",
      "        1    0.000    0.000    0.000    0.000 selectors.py:80(BaseSelector)\r\n",
      "        1    0.000    0.000    0.000    0.000 serialization.py:18(<module>)\r\n",
      "        1    0.000    0.000    0.010    0.010 series.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 series.py:1194(_set_as_cached)\r\n",
      "        3    0.000    0.000    0.000    0.000 series.py:177(_coerce_method)\r\n",
      "        1    0.006    0.006    0.007    0.007 series.py:195(Series)\r\n",
      "        2    0.000    0.000    0.000    0.000 series.py:2916(_construct_result)\r\n",
      "        3    0.000    0.000    0.000    0.000 series.py:315(__init__)\r\n",
      "        2    0.000    0.000    0.000    0.000 series.py:507(_constructor)\r\n",
      "        3    0.000    0.000    0.000    0.000 series.py:528(_set_axis)\r\n",
      "        1    0.000    0.000    0.000    0.000 series.py:5492(_cmp_method)\r\n",
      "        1    0.000    0.000    0.000    0.000 series.py:5516(_arith_method)\r\n",
      "        9    0.000    0.000    0.000    0.000 series.py:577(name)\r\n",
      "        7    0.000    0.000    0.000    0.000 series.py:627(name)\r\n",
      "        3    0.000    0.000    0.000    0.000 series.py:674(_values)\r\n",
      "        2    0.000    0.000    0.008    0.004 shape_base.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 shared_docs.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.003    0.003 shutil.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 shutil.py:69(Error)\r\n",
      "        1    0.000    0.000    0.000    0.000 shutil.py:72(SameFileError)\r\n",
      "        1    0.000    0.000    0.000    0.000 shutil.py:75(SpecialFileError)\r\n",
      "        1    0.000    0.000    0.000    0.000 shutil.py:79(ExecError)\r\n",
      "        1    0.000    0.000    0.000    0.000 shutil.py:82(ReadError)\r\n",
      "        1    0.000    0.000    0.000    0.000 shutil.py:85(RegistryError)\r\n",
      "        1    0.000    0.000    0.000    0.000 shutil.py:89(_GiveupOnFastCopy)\r\n",
      "        1    0.000    0.000    0.001    0.001 signal.py:1(<module>)\r\n",
      "       76    0.000    0.000    0.000    0.000 signal.py:10(<lambda>)\r\n",
      "       77    0.000    0.000    0.000    0.000 signal.py:17(<lambda>)\r\n",
      "       78    0.000    0.000    0.000    0.000 signal.py:22(<lambda>)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:108(MovedModule)\r\n",
      "       46    0.000    0.000    0.000    0.000 six.py:110(__init__)\r\n",
      "        2    0.000    0.000    0.000    0.000 six.py:119(_resolve)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:129(_LazyModule)\r\n",
      "        6    0.000    0.000    0.000    0.000 six.py:131(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:144(MovedAttribute)\r\n",
      "       88    0.000    0.000    0.000    0.000 six.py:146(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:169(_SixMetaPathImporter)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:178(__init__)\r\n",
      "       53    0.000    0.000    0.000    0.000 six.py:182(_add_module)\r\n",
      "        5    0.000    0.000    0.000    0.000 six.py:186(_get_module)\r\n",
      "       16    0.000    0.000    0.000    0.000 six.py:194(find_spec)\r\n",
      "        2    0.000    0.000    0.000    0.000 six.py:199(__get_module)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:205(load_module)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:21(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:219(is_package)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:236(create_module)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:239(exec_module)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:245(_MovedItems)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:340(Module_six_moves_urllib_parse)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:382(Module_six_moves_urllib_error)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:402(Module_six_moves_urllib_request)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:454(Module_six_moves_urllib_response)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:475(Module_six_moves_urllib_robotparser)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:493(Module_six_moves_urllib)\r\n",
      "        8    0.000    0.000    0.000    0.000 six.py:80(_add_doc)\r\n",
      "        2    0.000    0.000    0.000    0.000 six.py:85(_import_module)\r\n",
      "        3    0.000    0.000    0.000    0.000 six.py:880(add_metaclass)\r\n",
      "        3    0.000    0.000    0.000    0.000 six.py:882(wrapper)\r\n",
      "        1    0.000    0.000    0.000    0.000 six.py:91(_LazyDescr)\r\n",
      "      134    0.000    0.000    0.000    0.000 six.py:93(__init__)\r\n",
      "        2    0.000    0.000    0.000    0.000 six.py:96(__get__)\r\n",
      "        1    0.000    0.000    0.000    0.000 socket.py:210(_GiveupOnSendfile)\r\n",
      "        1    0.000    0.000    0.000    0.000 socket.py:213(socket)\r\n",
      "        1    0.000    0.000    0.002    0.002 socket.py:4(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 socket.py:626(SocketIO)\r\n",
      "      376    0.000    0.000    0.000    0.000 socket.py:76(<lambda>)\r\n",
      "      377    0.000    0.000    0.000    0.000 socket.py:81(<lambda>)\r\n",
      "      378    0.000    0.000    0.000    0.000 socket.py:86(<lambda>)\r\n",
      "      379    0.000    0.000    0.000    0.000 socket.py:91(<lambda>)\r\n",
      "        1    0.000    0.000    0.000    0.000 sorting.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 spss.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 sql.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 sql.py:1271(PandasSQL)\r\n",
      "        1    0.000    0.000    0.000    0.000 sql.py:1300(BaseEngine)\r\n",
      "        1    0.000    0.000    0.000    0.000 sql.py:1319(SQLAlchemyEngine)\r\n",
      "        1    0.000    0.000    0.000    0.000 sql.py:1385(SQLDatabase)\r\n",
      "        1    0.000    0.000    0.000    0.000 sql.py:1879(SQLiteTable)\r\n",
      "        1    0.000    0.000    0.000    0.000 sql.py:2023(SQLiteDatabase)\r\n",
      "        1    0.000    0.000    0.000    0.000 sql.py:50(SQLAlchemyRequired)\r\n",
      "        1    0.000    0.000    0.000    0.000 sql.py:54(DatabaseError)\r\n",
      "        1    0.000    0.000    0.000    0.000 sql.py:795(SQLTable)\r\n",
      "      149    0.000    0.000    0.000    0.000 sre_compile.py:249(_compile_charset)\r\n",
      "      149    0.001    0.000    0.002    0.000 sre_compile.py:276(_optimize_charset)\r\n",
      "       24    0.000    0.000    0.000    0.000 sre_compile.py:411(_mk_bitmap)\r\n",
      "       24    0.000    0.000    0.000    0.000 sre_compile.py:413(<listcomp>)\r\n",
      "        5    0.000    0.000    0.000    0.000 sre_compile.py:416(_bytes_to_codes)\r\n",
      "      171    0.000    0.000    0.000    0.000 sre_compile.py:423(_simple)\r\n",
      "        6    0.000    0.000    0.000    0.000 sre_compile.py:432(_generate_overlap_table)\r\n",
      "      108    0.000    0.000    0.000    0.000 sre_compile.py:453(_get_iscased)\r\n",
      "    66/48    0.000    0.000    0.000    0.000 sre_compile.py:461(_get_literal_prefix)\r\n",
      "       42    0.000    0.000    0.000    0.000 sre_compile.py:492(_get_charset_prefix)\r\n",
      "       53    0.000    0.000    0.001    0.000 sre_compile.py:536(_compile_info)\r\n",
      "      106    0.000    0.000    0.000    0.000 sre_compile.py:595(isstring)\r\n",
      "       53    0.000    0.000    0.006    0.000 sre_compile.py:598(_code)\r\n",
      "      123    0.000    0.000    0.000    0.000 sre_compile.py:65(_combine_flags)\r\n",
      "   367/53    0.002    0.000    0.004    0.000 sre_compile.py:71(_compile)\r\n",
      "       53    0.000    0.000    0.014    0.000 sre_compile.py:759(compile)\r\n",
      "      389    0.000    0.000    0.000    0.000 sre_parse.py:111(__init__)\r\n",
      "      804    0.000    0.000    0.000    0.000 sre_parse.py:160(__len__)\r\n",
      "     2421    0.001    0.000    0.001    0.000 sre_parse.py:164(__getitem__)\r\n",
      "      178    0.000    0.000    0.000    0.000 sre_parse.py:168(__setitem__)\r\n",
      "      685    0.000    0.000    0.000    0.000 sre_parse.py:172(append)\r\n",
      "  454/140    0.001    0.000    0.001    0.000 sre_parse.py:174(getwidth)\r\n",
      "       55    0.000    0.000    0.000    0.000 sre_parse.py:224(__init__)\r\n",
      "     2594    0.001    0.000    0.001    0.000 sre_parse.py:233(__next)\r\n",
      "      959    0.000    0.000    0.000    0.000 sre_parse.py:249(match)\r\n",
      "     2080    0.001    0.000    0.001    0.000 sre_parse.py:254(get)\r\n",
      "        4    0.000    0.000    0.000    0.000 sre_parse.py:258(getwhile)\r\n",
      "       26    0.000    0.000    0.000    0.000 sre_parse.py:267(getuntil)\r\n",
      "      542    0.000    0.000    0.000    0.000 sre_parse.py:286(tell)\r\n",
      "        3    0.000    0.000    0.000    0.000 sre_parse.py:288(seek)\r\n",
      "       67    0.000    0.000    0.000    0.000 sre_parse.py:295(_class_escape)\r\n",
      "       99    0.000    0.000    0.000    0.000 sre_parse.py:355(_escape)\r\n",
      "       99    0.000    0.000    0.000    0.000 sre_parse.py:432(_uniq)\r\n",
      "   160/53    0.000    0.000    0.008    0.000 sre_parse.py:435(_parse_sub)\r\n",
      "   196/56    0.003    0.000    0.008    0.000 sre_parse.py:493(_parse)\r\n",
      "       53    0.000    0.000    0.000    0.000 sre_parse.py:76(__init__)\r\n",
      "      280    0.000    0.000    0.000    0.000 sre_parse.py:81(groups)\r\n",
      "       87    0.000    0.000    0.000    0.000 sre_parse.py:84(opengroup)\r\n",
      "        6    0.000    0.000    0.000    0.000 sre_parse.py:861(_parse_flags)\r\n",
      "       53    0.000    0.000    0.000    0.000 sre_parse.py:921(fix_flags)\r\n",
      "       53    0.000    0.000    0.008    0.000 sre_parse.py:937(parse)\r\n",
      "       87    0.000    0.000    0.001    0.000 sre_parse.py:96(closegroup)\r\n",
      "        2    0.000    0.000    0.000    0.000 sre_parse.py:969(parse_template)\r\n",
      "        1    0.000    0.000    0.000    0.000 sre_parse.py:978(addgroup)\r\n",
      "        1    0.000    0.000    0.001    0.001 stata.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:1043(StataReader)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:2110(StataWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:2812(StataStrLWriter)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:2993(StataWriter117)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:3372(StataWriterUTF8)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:487(PossiblePrecisionLoss)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:497(ValueLabelTypeMismatch)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:508(InvalidColumnName)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:524(CategoricalConversionWarning)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:628(StataValueLabel)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:737(StataMissingValue)\r\n",
      "        1    0.000    0.000    0.000    0.000 stata.py:881(StataParser)\r\n",
      "        1    0.000    0.000    0.000    0.000 stride_tricks.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 stride_tricks.py:14(DummyArray)\r\n",
      "        1    0.000    0.000    0.001    0.001 string.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 string.py:161(Formatter)\r\n",
      "        1    0.000    0.000    0.000    0.000 string.py:57(_TemplateMetaclass)\r\n",
      "        1    0.000    0.000    0.001    0.001 string.py:67(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 string.py:80(Template)\r\n",
      "        1    0.000    0.000    0.000    0.000 string_.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 string_.py:227(BaseStringArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 string_.py:231(StringArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 string_.py:57(StringDtype)\r\n",
      "        1    0.000    0.000    0.037    0.037 string_arrow.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 string_arrow.py:92(ArrowStringArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 struct.py:3(<module>)\r\n",
      "        1    0.000    0.000    0.002    0.002 subprocess.py:10(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:1052(poll)\r\n",
      "        2    0.000    0.000    0.000    0.000 subprocess.py:1078(wait)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:1101(_close_pipe_fds)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:136(TimeoutExpired)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:1459(_get_handles)\r\n",
      "        1    0.000    0.000    0.001    0.001 subprocess.py:1552(_execute_child)\r\n",
      "       15    0.000    0.000    0.000    0.000 subprocess.py:1634(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:1708(_handle_exitstatus)\r\n",
      "        2    0.000    0.000    0.000    0.000 subprocess.py:1726(_internal_poll)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:1761(_try_wait)\r\n",
      "        2    0.000    0.000    0.000    0.000 subprocess.py:1774(_wait)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:241(_cleanup)\r\n",
      "        1    0.000    0.000    0.002    0.002 subprocess.py:368(check_output)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:419(CompletedProcess)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:430(__init__)\r\n",
      "        1    0.000    0.000    0.002    0.002 subprocess.py:452(run)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:638(_use_posix_spawn)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:688(Popen)\r\n",
      "        1    0.000    0.000    0.001    0.001 subprocess.py:736(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:908(__enter__)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:911(__exit__)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:939(__del__)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:954(_get_devnull)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:96(SubprocessError)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:984(communicate)\r\n",
      "        1    0.000    0.000    0.000    0.000 subprocess.py:99(CalledProcessError)\r\n",
      "        1    0.000    0.000    0.000    0.000 take.py:1(<module>)\r\n",
      "       12    0.000    0.000    0.000    0.000 take.py:324(_view_wrapper)\r\n",
      "        1    0.000    0.000    0.000    0.000 tempfile.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 tempfile.py:262(_RandomNameSequence)\r\n",
      "        1    0.000    0.000    0.000    0.000 tempfile.py:545(_TemporaryFileCloser)\r\n",
      "        1    0.000    0.000    0.000    0.000 tempfile.py:588(_TemporaryFileWrapper)\r\n",
      "        1    0.000    0.000    0.000    0.000 tempfile.py:761(SpooledTemporaryFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 tempfile.py:906(TemporaryDirectory)\r\n",
      "        1    0.000    0.000    0.002    0.002 testing.py:1(<module>)\r\n",
      "        2    0.000    0.000    0.000    0.000 textwrap.py:115(__init__)\r\n",
      "        2    0.000    0.000    0.000    0.000 textwrap.py:146(_munge_whitespace)\r\n",
      "        2    0.000    0.000    0.000    0.000 textwrap.py:160(_split)\r\n",
      "        2    0.000    0.000    0.000    0.000 textwrap.py:179(<listcomp>)\r\n",
      "        2    0.000    0.000    0.000    0.000 textwrap.py:233(_wrap_chunks)\r\n",
      "        2    0.000    0.000    0.000    0.000 textwrap.py:336(_split_chunks)\r\n",
      "        2    0.000    0.000    0.000    0.000 textwrap.py:342(wrap)\r\n",
      "        2    0.000    0.000    0.000    0.000 textwrap.py:356(fill)\r\n",
      "        2    0.000    0.000    0.000    0.000 textwrap.py:381(fill)\r\n",
      "     1412    0.003    0.000    0.025    0.000 textwrap.py:414(dedent)\r\n",
      "        1    0.000    0.000    0.000    0.000 textwrap.py:465(indent)\r\n",
      "        1    0.000    0.000    0.000    0.000 textwrap.py:474(predicate)\r\n",
      "        2    0.000    0.000    0.000    0.000 textwrap.py:477(prefixed_lines)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:1095(daemon)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:1177(_make_invoke_excepthook)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:1230(Timer)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:1260(_MainThread)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:1262(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:1281(_DummyThread)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:210(Condition)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:222(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:246(__enter__)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:249(__exit__)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:261(_is_owned)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:341(notify)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:364(notify_all)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:376(Semaphore)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:456(BoundedSemaphore)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:494(Event)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:505(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:519(set)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:573(Barrier)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:727(BrokenBarrierError)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:750(Thread)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:761(__init__)\r\n",
      "        3    0.000    0.000    0.000    0.000 threading.py:81(RLock)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:896(_set_ident)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:900(_set_native_id)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:903(_set_tstate_lock)\r\n",
      "        1    0.000    0.000    0.000    0.000 threading.py:94(_RLock)\r\n",
      "        1    0.000    0.000    0.000    0.000 tile.py:1(<module>)\r\n",
      "        3    0.000    0.000    0.000    0.000 timedeltas.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 timedeltas.py:35(TimedeltaIndex)\r\n",
      "        4    0.000    0.000    0.000    0.000 timedeltas.py:80(_field_accessor)\r\n",
      "        1    0.000    0.000    0.000    0.000 timedeltas.py:96(TimedeltaArray)\r\n",
      "        1    0.000    0.000    0.000    0.000 times.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 token.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 token.py:74(<dictcomp>)\r\n",
      "        1    0.000    0.000    0.001    0.001 tokenize.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 tokenize.py:157(TokenError)\r\n",
      "        1    0.000    0.000    0.000    0.000 tokenize.py:159(StopTokenizing)\r\n",
      "        1    0.000    0.000    0.000    0.000 tokenize.py:162(Untokenizer)\r\n",
      "        1    0.000    0.000    0.000    0.000 tokenize.py:45(TokenInfo)\r\n",
      "       19    0.000    0.000    0.000    0.000 tokenize.py:58(group)\r\n",
      "        1    0.000    0.000    0.000    0.000 tokenize.py:59(any)\r\n",
      "        2    0.000    0.000    0.000    0.000 tokenize.py:60(maybe)\r\n",
      "        3    0.000    0.000    0.000    0.000 tokenize.py:83(_all_string_prefixes)\r\n",
      "       24    0.000    0.000    0.000    0.000 tokenize.py:94(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 traceback.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 traceback.py:227(FrameSummary)\r\n",
      "        1    0.000    0.000    0.000    0.000 traceback.py:318(StackSummary)\r\n",
      "        1    0.000    0.000    0.000    0.000 traceback.py:440(TracebackException)\r\n",
      "        1    0.000    0.000    0.000    0.000 transforms.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 twodim_base.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.001    0.001 type_check.py:1(<module>)\r\n",
      "       66    0.000    0.000    0.000    0.000 types.py:171(__get__)\r\n",
      "        1    0.000    0.000    0.000    0.000 types.py:21(<module>)\r\n",
      "        1    0.000    0.000    0.002    0.002 typing.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1006(_ProtocolMeta)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1026(Protocol)\r\n",
      "        7    0.000    0.000    0.000    0.000 typing.py:1060(__init_subclass__)\r\n",
      "       14    0.000    0.000    0.000    0.000 typing.py:1065(<genexpr>)\r\n",
      "        7    0.000    0.000    0.000    0.000 typing.py:1124(runtime_checkable)\r\n",
      "      151    0.000    0.000    0.000    0.000 typing.py:1149(cast)\r\n",
      "      304    0.000    0.000    0.001    0.000 typing.py:120(_type_check)\r\n",
      "       76    0.000    0.000    0.000    0.000 typing.py:1362(overload)\r\n",
      "       38    0.000    0.000    0.001    0.000 typing.py:1435(_alias)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1521(SupportsInt)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1531(SupportsFloat)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1541(SupportsComplex)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1551(SupportsBytes)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1561(SupportsIndex)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1571(SupportsAbs)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1581(SupportsRound)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1613(NamedTupleMeta)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1615(__new__)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1644(NamedTuple)\r\n",
      "      170    0.000    0.000    0.000    0.000 typing.py:172(_collect_type_vars)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1734(_TypedDictMeta)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1735(__new__)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1749(<dictcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1760(TypedDict)\r\n",
      "       77    0.000    0.000    0.000    0.000 typing.py:183(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1838(IO)\r\n",
      "    47/26    0.000    0.000    0.001    0.000 typing.py:187(_subs_tvars)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1937(BinaryIO)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1951(TextIO)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:1986(io)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:2001(re)\r\n",
      "       33    0.000    0.000    0.000    0.000 typing.py:206(_check_generic)\r\n",
      "       63    0.000    0.000    0.000    0.000 typing.py:219(_remove_dups_flatten)\r\n",
      "        6    0.000    0.000    0.000    0.000 typing.py:248(_tp_cache)\r\n",
      "  141/130    0.000    0.000    0.004    0.000 typing.py:255(inner)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:281(_Final)\r\n",
      "        9    0.000    0.000    0.000    0.000 typing.py:286(__init_subclass__)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:290(_Immutable)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:300(_SpecialForm)\r\n",
      "       10    0.000    0.000    0.000    0.000 typing.py:307(__new__)\r\n",
      "       10    0.000    0.000    0.000    0.000 typing.py:320(__init__)\r\n",
      "      328    0.000    0.000    0.000    0.000 typing.py:324(__eq__)\r\n",
      "      230    0.000    0.000    0.000    0.000 typing.py:329(__hash__)\r\n",
      "    71/63    0.000    0.000    0.002    0.000 typing.py:347(__getitem__)\r\n",
      "      249    0.000    0.000    0.001    0.000 typing.py:358(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:489(ForwardRef)\r\n",
      "       57    0.000    0.000    0.001    0.000 typing.py:496(__init__)\r\n",
      "        5    0.000    0.000    0.000    0.000 typing.py:524(__eq__)\r\n",
      "      136    0.000    0.000    0.000    0.000 typing.py:532(__hash__)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:539(TypeVar)\r\n",
      "       44    0.000    0.000    0.000    0.000 typing.py:586(__init__)\r\n",
      "       48    0.000    0.000    0.000    0.000 typing.py:598(<genexpr>)\r\n",
      "     1178    0.000    0.000    0.001    0.000 typing.py:646(_is_dunder)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:650(_GenericAlias)\r\n",
      "      157    0.000    0.000    0.002    0.000 typing.py:659(__init__)\r\n",
      "      534    0.000    0.000    0.000    0.000 typing.py:669(<genexpr>)\r\n",
      "       26    0.000    0.000    0.001    0.000 typing.py:677(__getitem__)\r\n",
      "       64    0.000    0.000    0.000    0.000 typing.py:685(<genexpr>)\r\n",
      "       44    0.000    0.000    0.001    0.000 typing.py:689(copy_with)\r\n",
      "      239    0.000    0.000    0.000    0.000 typing.py:711(__eq__)\r\n",
      "  449/230    0.000    0.000    0.000    0.000 typing.py:720(__hash__)\r\n",
      "       13    0.000    0.000    0.000    0.000 typing.py:736(__mro_entries__)\r\n",
      "        2    0.000    0.000    0.000    0.000 typing.py:742(<genexpr>)\r\n",
      "     1178    0.001    0.000    0.001    0.000 typing.py:762(__setattr__)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:798(_VariadicGenericAlias)\r\n",
      "       22    0.000    0.000    0.001    0.000 typing.py:802(__getitem__)\r\n",
      "       18    0.000    0.000    0.000    0.000 typing.py:818(__getitem_inner__)\r\n",
      "       25    0.000    0.000    0.000    0.000 typing.py:830(<genexpr>)\r\n",
      "       13    0.000    0.000    0.000    0.000 typing.py:839(<genexpr>)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:845(Generic)\r\n",
      "       10    0.000    0.000    0.000    0.000 typing.py:878(__class_getitem__)\r\n",
      "       20    0.000    0.000    0.000    0.000 typing.py:886(<genexpr>)\r\n",
      "        6    0.000    0.000    0.000    0.000 typing.py:889(<genexpr>)\r\n",
      "       32    0.000    0.000    0.000    0.000 typing.py:900(__init_subclass__)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:936(_TypingEmpty)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing.py:943(_TypingEllipsis)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:1696(_TypedDictMeta)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:1697(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:1703(__new__)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:1717(<dictcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:1784(_AnnotatedAlias)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:1825(Annotated)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:2157(_TypeAliasForm)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:2235(_Immutable)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:2245(ParamSpecArgs)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:2263(ParamSpecKwargs)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:2286(ParamSpec)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:2392(_ConcatenateGenericAlias)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:2472(_ConcatenateForm)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:2612(_TypeGuardForm)\r\n",
      "        5    0.000    0.000    0.000    0.000 typing_extensions.py:759(_define_guard)\r\n",
      "        1    0.000    0.000    0.000    0.000 typing_extensions.py:778(_ExtensionsGenericMeta)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:1036(tzstr)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:1156(_tzicalvtzcomp)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:1167(_tzicalvtz)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:1253(tzical)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:132(tzoffset)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:1470(__get_gettz)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:1475(GettzFunc)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:1545(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:1552(__call__)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:1590(nocache)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:1818(_get_supported_offset)\r\n",
      "        1    0.000    0.000    0.002    0.002 tz.py:2(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:201(tzlocal)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:328(_ttinfo)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:332(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:373(_tzfile)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:381(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:386(tzfile)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:41(tzutc)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:458(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:482(_set_tzdata)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:488(_read_tzfile)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:627(<listcomp>)\r\n",
      "        1    0.000    0.000    0.000    0.000 tz.py:874(tzrange)\r\n",
      "        1    0.000    0.000    0.000    0.000 tzfile.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 tzfile.py:12(_byte_string)\r\n",
      "        1    0.000    0.000    0.000    0.000 tzinfo.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 tzinfo.py:156(DstTzInfo)\r\n",
      "        1    0.000    0.000    0.000    0.000 tzinfo.py:18(memorized_timedelta)\r\n",
      "        1    0.000    0.000    0.000    0.000 tzinfo.py:66(BaseTzInfo)\r\n",
      "        1    0.000    0.000    0.000    0.000 tzinfo.py:76(StaticTzInfo)\r\n",
      "        1    0.000    0.000    0.000    0.000 ufunclike.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 ufunclike.py:16(_deprecate_out_named_y)\r\n",
      "        3    0.000    0.000    0.000    0.000 ufunclike.py:41(_fix_out_named_y)\r\n",
      "        3    0.000    0.000    0.000    0.000 ufunclike.py:58(_fix_and_maybe_deprecate_out_named_y)\r\n",
      "        1    0.000    0.000    0.000    0.000 umath.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 util.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.002    0.002 util.py:20(<module>)\r\n",
      "       21    0.000    0.000    0.000    0.000 util.py:35(implements)\r\n",
      "       21    0.000    0.000    0.000    0.000 util.py:36(decorator)\r\n",
      "        9    0.000    0.000    0.000    0.000 util.py:42(_deprecate_api)\r\n",
      "       34    0.000    0.000    0.000    0.000 util.py:51(_deprecate_class)\r\n",
      "       34    0.000    0.000    0.000    0.000 util.py:56(_DeprecatedMeta)\r\n",
      "        1    0.000    0.000    0.001    0.001 utils.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 utils.py:133(_get_indent)\r\n",
      "        1    0.000    0.000    0.000    0.000 utils.py:147(deprecate)\r\n",
      "        1    0.000    0.000    0.000    0.000 utils.py:52(_set_function_name)\r\n",
      "        1    0.000    0.000    0.000    0.000 utils.py:57(_Deprecate)\r\n",
      "        1    0.000    0.000    0.000    0.000 utils.py:69(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 utils.py:74(__call__)\r\n",
      "        1    0.000    0.000    0.002    0.002 uuid.py:1(<module>)\r\n",
      "        4    0.000    0.000    0.000    0.000 uuid.py:132(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 uuid.py:72(SafeUUID)\r\n",
      "        1    0.000    0.000    0.000    0.000 uuid.py:78(UUID)\r\n",
      "        1    0.000    0.000    0.000    0.000 version.py:5(<module>)\r\n",
      "        3    0.000    0.000    0.001    0.000 warnings.py:130(filterwarnings)\r\n",
      "        3    0.000    0.000    0.000    0.000 warnings.py:165(simplefilter)\r\n",
      "        6    0.000    0.000    0.000    0.000 warnings.py:181(_add_filter)\r\n",
      "        2    0.000    0.000    0.000    0.000 warnings.py:437(__init__)\r\n",
      "        2    0.000    0.000    0.000    0.000 warnings.py:458(__enter__)\r\n",
      "        2    0.000    0.000    0.000    0.000 warnings.py:477(__exit__)\r\n",
      "        5    0.000    0.000    0.000    0.000 weakref.py:102(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 weakref.py:159(__setitem__)\r\n",
      "        1    0.000    0.000    0.000    0.000 weakref.py:189(get)\r\n",
      "        5    0.000    0.000    0.000    0.000 weakref.py:284(update)\r\n",
      "        1    0.000    0.000    0.000    0.000 weakref.py:323(__new__)\r\n",
      "        1    0.000    0.000    0.000    0.000 weakref.py:328(__init__)\r\n",
      "        2    0.000    0.000    0.000    0.000 weakref.py:343(__init__)\r\n",
      "        1    0.000    0.000    0.000    0.000 win.py:2(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 xml.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 xml.py:196(_EtreeFrameParser)\r\n",
      "        1    0.000    0.000    0.000    0.000 xml.py:37(_XMLFrameParser)\r\n",
      "        1    0.000    0.000    0.000    0.000 xml.py:371(_LxmlFrameParser)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:1(<module>)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:1114(_ZipWriteFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:1192(ZipFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:1956(PyZipFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:2183(CompleteDirs)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:2233(FastLookup)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:2251(Path)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:318(ZipInfo)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:43(BadZipFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:47(LargeZipFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:613(LZMACompressor)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:636(LZMADecompressor)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:737(_SharedFile)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:775(_Tellable)\r\n",
      "        1    0.000    0.000    0.000    0.000 zipfile.py:795(ZipExtFile)\r\n",
      "     1703    0.002    0.000    0.002    0.000 {built-in method __new__ of type object at 0x908780}\r\n",
      "       95    0.001    0.000    0.001    0.000 {built-in method _abc._abc_init}\r\n",
      "       11    0.000    0.000    0.000    0.000 {built-in method _abc._abc_instancecheck}\r\n",
      "       20    0.000    0.000    0.000    0.000 {built-in method _abc._abc_register}\r\n",
      "    45/26    0.000    0.000    0.000    0.000 {built-in method _abc._abc_subclasscheck}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _codecs.utf_8_decode}\r\n",
      "        3    0.000    0.000    0.000    0.000 {built-in method _csv.register_dialect}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method _ctypes.POINTER}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _ctypes.dlopen}\r\n",
      "       38    0.000    0.000    0.000    0.000 {built-in method _ctypes.sizeof}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method _functools.reduce}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _hashlib.openssl_md5}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _hashlib.openssl_sha1}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _hashlib.openssl_sha224}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _hashlib.openssl_sha256}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _hashlib.openssl_sha384}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _hashlib.openssl_sha512}\r\n",
      "      406    0.000    0.000    0.000    0.000 {built-in method _imp._fix_co_filename}\r\n",
      "     3262    0.000    0.000    0.000    0.000 {built-in method _imp.acquire_lock}\r\n",
      "       23    0.001    0.000    0.001    0.000 {built-in method _imp.create_builtin}\r\n",
      "       68    0.018    0.000    0.021    0.000 {built-in method _imp.create_dynamic}\r\n",
      "       23    0.000    0.000    0.000    0.000 {built-in method _imp.exec_builtin}\r\n",
      "    68/39    0.028    0.000    0.058    0.001 {built-in method _imp.exec_dynamic}\r\n",
      "      110    0.000    0.000    0.000    0.000 {built-in method _imp.is_builtin}\r\n",
      "      497    0.000    0.000    0.000    0.000 {built-in method _imp.is_frozen}\r\n",
      "     3262    0.000    0.000    0.000    0.000 {built-in method _imp.release_lock}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _locale.nl_langinfo}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method _locale.setlocale}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _operator.eq}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _operator.mod}\r\n",
      "        1    0.001    0.001    0.001    0.001 {built-in method _posixsubprocess.fork_exec}\r\n",
      "        4    0.000    0.000    0.000    0.000 {built-in method _sre.ascii_iscased}\r\n",
      "        4    0.000    0.000    0.000    0.000 {built-in method _sre.ascii_tolower}\r\n",
      "       53    0.000    0.000    0.000    0.000 {built-in method _sre.compile}\r\n",
      "      178    0.000    0.000    0.000    0.000 {built-in method _sre.unicode_iscased}\r\n",
      "      165    0.000    0.000    0.000    0.000 {built-in method _sre.unicode_tolower}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _stat.S_ISREG}\r\n",
      "       23    0.000    0.000    0.000    0.000 {built-in method _struct.calcsize}\r\n",
      "      108    0.000    0.000    0.000    0.000 {built-in method _struct.pack}\r\n",
      "      116    0.000    0.000    0.000    0.000 {built-in method _struct.unpack}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _thread._set_sentinel}\r\n",
      "     1057    0.000    0.000    0.000    0.000 {built-in method _thread.allocate_lock}\r\n",
      "     2432    0.000    0.000    0.000    0.000 {built-in method _thread.get_ident}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _thread.get_native_id}\r\n",
      "       10    0.000    0.000    0.000    0.000 {built-in method _warnings._filters_mutated}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method _warnings.warn}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method atexit.register}\r\n",
      "  858/848    0.011    0.000    0.045    0.000 {built-in method builtins.__build_class__}\r\n",
      "   372/27    0.001    0.000    0.178    0.007 {built-in method builtins.__import__}\r\n",
      "       96    0.000    0.000    0.000    0.000 {built-in method builtins.abs}\r\n",
      "       15    0.000    0.000    0.000    0.000 {built-in method builtins.all}\r\n",
      "       34    0.000    0.000    0.000    0.000 {built-in method builtins.any}\r\n",
      "      567    0.000    0.000    0.000    0.000 {built-in method builtins.callable}\r\n",
      "      420    0.000    0.000    0.000    0.000 {built-in method builtins.chr}\r\n",
      "      373    0.017    0.000    0.017    0.000 {built-in method builtins.compile}\r\n",
      "        3    0.000    0.000    0.000    0.000 {built-in method builtins.delattr}\r\n",
      "        3    0.000    0.000    0.000    0.000 {built-in method builtins.dir}\r\n",
      "       60    0.000    0.000    0.000    0.000 {built-in method builtins.divmod}\r\n",
      "    762/1    0.004    0.000    0.312    0.312 {built-in method builtins.exec}\r\n",
      "     9314    0.003    0.000    0.003    0.000 {built-in method builtins.getattr}\r\n",
      "      432    0.000    0.000    0.000    0.000 {built-in method builtins.globals}\r\n",
      "     5037    0.001    0.000    0.001    0.000 {built-in method builtins.hasattr}\r\n",
      "  854/499    0.000    0.000    0.000    0.000 {built-in method builtins.hash}\r\n",
      "      139    0.000    0.000    0.000    0.000 {built-in method builtins.id}\r\n",
      "    20800    0.002    0.000    0.002    0.000 {built-in method builtins.isinstance}\r\n",
      "     2044    0.000    0.000    0.000    0.000 {built-in method builtins.issubclass}\r\n",
      "7395/6979    0.001    0.000    0.001    0.000 {built-in method builtins.len}\r\n",
      "      867    0.001    0.000    0.001    0.000 {built-in method builtins.max}\r\n",
      "      857    0.000    0.000    0.000    0.000 {built-in method builtins.min}\r\n",
      "       64    0.000    0.000    0.000    0.000 {built-in method builtins.next}\r\n",
      "      618    0.000    0.000    0.000    0.000 {built-in method builtins.ord}\r\n",
      "       91    0.000    0.000    0.000    0.000 {built-in method builtins.repr}\r\n",
      "       12    0.000    0.000    0.000    0.000 {built-in method builtins.round}\r\n",
      "     4195    0.001    0.000    0.001    0.000 {built-in method builtins.setattr}\r\n",
      "        5    0.000    0.000    0.000    0.000 {built-in method builtins.sorted}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method builtins.sum}\r\n",
      "        7    0.000    0.000    0.000    0.000 {built-in method builtins.vars}\r\n",
      "     1219    0.000    0.000    0.000    0.000 {built-in method from_bytes}\r\n",
      "       99    0.000    0.000    0.000    0.000 {built-in method fromkeys}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method gc.disable}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method gc.enable}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method gc.isenabled}\r\n",
      "      406    0.005    0.000    0.005    0.000 {built-in method io.open_code}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method io.open}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method maketrans}\r\n",
      "      406    0.036    0.000    0.036    0.000 {built-in method marshal.loads}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method math.exp}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method math.log}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method math.sqrt}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method numpy.arange}\r\n",
      "  126/125    0.000    0.000    0.000    0.000 {built-in method numpy.array}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method numpy.core._multiarray_umath._set_madvise_hugepage}\r\n",
      "      299    0.000    0.000    0.000    0.000 {built-in method numpy.core._multiarray_umath.add_docstring}\r\n",
      "    17/13    0.000    0.000    0.000    0.000 {built-in method numpy.core._multiarray_umath.implement_array_function}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method numpy.core._multiarray_umath.set_string_function}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method numpy.core._multiarray_umath.set_typeDict}\r\n",
      "       10    0.000    0.000    0.000    0.000 {built-in method numpy.empty}\r\n",
      "       26    0.000    0.000    0.000    0.000 {built-in method numpy.geterrobj}\r\n",
      "       13    0.000    0.000    0.000    0.000 {built-in method numpy.seterrobj}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method pandas._libs.missing.checknull}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method posix.WEXITSTATUS}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method posix.WIFEXITED}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method posix.WIFSIGNALED}\r\n",
      "        4    0.000    0.000    0.000    0.000 {built-in method posix.close}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method posix.confstr}\r\n",
      "     1324    0.000    0.000    0.000    0.000 {built-in method posix.fspath}\r\n",
      "       87    0.000    0.000    0.000    0.000 {built-in method posix.getcwd}\r\n",
      "       53    0.001    0.000    0.001    0.000 {built-in method posix.listdir}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method posix.open}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method posix.pipe}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method posix.putenv}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method posix.read}\r\n",
      "        3    0.000    0.000    0.000    0.000 {built-in method posix.register_at_fork}\r\n",
      "     1897    0.007    0.000    0.007    0.000 {built-in method posix.stat}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method posix.uname}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method posix.unsetenv}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method posix.urandom}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method posix.waitpid}\r\n",
      "       77    0.000    0.000    0.000    0.000 {built-in method sys._getframe}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method sys.audit}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method sys.exc_info}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method sys.getdefaultencoding}\r\n",
      "      124    0.000    0.000    0.000    0.000 {built-in method sys.getrecursionlimit}\r\n",
      "      182    0.000    0.000    0.000    0.000 {built-in method sys.intern}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method time.localtime}\r\n",
      "        1    0.000    0.000    0.000    0.000 {built-in method time.time}\r\n",
      "        2    0.000    0.000    0.000    0.000 {built-in method utcfromtimestamp}\r\n",
      "        1    0.000    0.000    0.000    0.000 {function Random.seed at 0x7f9ba6a58940}\r\n",
      "        1    0.000    0.000    0.000    0.000 {function SeedSequence.generate_state at 0x7f9ba6a2f550}\r\n",
      "      343    0.000    0.000    0.000    0.000 {method '__contains__' of 'frozenset' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method '__enter__' of '_thread.lock' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method '__exit__' of '_thread.lock' objects}\r\n",
      "       32    0.000    0.000    0.000    0.000 {method '__init_subclass__' of 'object' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'acquire' of '_thread.RLock' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'acquire' of '_thread.lock' objects}\r\n",
      "      346    0.000    0.000    0.000    0.000 {method 'add' of 'set' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'any' of 'numpy.generic' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'any' of 'numpy.ndarray' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'append' of 'collections.deque' objects}\r\n",
      "     8917    0.001    0.000    0.001    0.000 {method 'append' of 'list' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'astype' of 'numpy.ndarray' objects}\r\n",
      "        6    0.000    0.000    0.000    0.000 {method 'bit_length' of 'int' objects}\r\n",
      "        5    0.000    0.000    0.000    0.000 {method 'cast' of 'memoryview' objects}\r\n",
      "        3    0.000    0.000    0.000    0.000 {method 'clear' of 'dict' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'close' of '_io.TextIOWrapper' objects}\r\n",
      "       15    0.000    0.000    0.000    0.000 {method 'copy' of 'dict' objects}\r\n",
      "        3    0.000    0.000    0.000    0.000 {method 'copy' of 'mappingproxy' objects}\r\n",
      "       62    0.000    0.000    0.000    0.000 {method 'copy' of 'numpy.ndarray' objects}\r\n",
      "        5    0.000    0.000    0.000    0.000 {method 'count' of 'list' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'count' of 'str' objects}\r\n",
      "        3    0.000    0.000    0.000    0.000 {method 'decode' of 'bytes' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'disable' of '_lsprof.Profiler' objects}\r\n",
      "       16    0.000    0.000    0.000    0.000 {method 'discard' of 'set' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'dot' of 'numpy.ndarray' objects}\r\n",
      "       29    0.000    0.000    0.000    0.000 {method 'encode' of 'str' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'end' of 're.Match' objects}\r\n",
      "       14    0.000    0.000    0.000    0.000 {method 'endswith' of 'bytes' objects}\r\n",
      "     1251    0.000    0.000    0.000    0.000 {method 'endswith' of 'str' objects}\r\n",
      "        3    0.000    0.000    0.000    0.000 {method 'expandtabs' of 'str' objects}\r\n",
      "      370    0.000    0.000    0.000    0.000 {method 'extend' of 'list' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'fill' of 'numpy.ndarray' objects}\r\n",
      "      477    0.000    0.000    0.000    0.000 {method 'find' of 'bytearray' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'find' of 'str' objects}\r\n",
      "     1412    0.008    0.000    0.008    0.000 {method 'findall' of 're.Pattern' objects}\r\n",
      "     2014    0.002    0.000    0.002    0.000 {method 'format' of 'str' objects}\r\n",
      "     2055    0.000    0.000    0.000    0.000 {method 'get' of 'dict' objects}\r\n",
      "      241    0.000    0.000    0.000    0.000 {method 'get' of 'mappingproxy' objects}\r\n",
      "      189    0.000    0.000    0.000    0.000 {method 'get_function' of 'pyarrow._compute.FunctionRegistry' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'get_indexer' of 'pandas._libs.index.IndexEngine' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'get_loc' of 'pandas._libs.index.IndexEngine' objects}\r\n",
      "      140    0.000    0.000    0.000    0.000 {method 'group' of 're.Match' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'groups' of 're.Match' objects}\r\n",
      "        5    0.000    0.000    0.000    0.000 {method 'index' of 'tuple' objects}\r\n",
      "        8    0.000    0.000    0.000    0.000 {method 'insert' of 'list' objects}\r\n",
      "     1026    0.000    0.000    0.000    0.000 {method 'isidentifier' of 'str' objects}\r\n",
      "     1586    0.000    0.000    0.000    0.000 {method 'isupper' of 'str' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'items' of 'collections.OrderedDict' objects}\r\n",
      "      239    0.000    0.000    0.000    0.000 {method 'items' of 'dict' objects}\r\n",
      "       64    0.000    0.000    0.000    0.000 {method 'items' of 'mappingproxy' objects}\r\n",
      "     5710    0.002    0.000    0.012    0.000 {method 'join' of 'str' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'keys' of 'collections.OrderedDict' objects}\r\n",
      "       11    0.000    0.000    0.000    0.000 {method 'keys' of 'dict' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'list_functions' of 'pyarrow._compute.FunctionRegistry' objects}\r\n",
      "      161    0.000    0.000    0.000    0.000 {method 'lower' of 'str' objects}\r\n",
      "       47    0.000    0.000    0.000    0.000 {method 'lstrip' of 'str' objects}\r\n",
      "      308    0.000    0.000    0.000    0.000 {method 'match' of 're.Pattern' objects}\r\n",
      "       14    0.000    0.000    0.000    0.000 {method 'mro' of 'type' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'nonzero' of 'numpy.ndarray' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'pop' of 'collections.OrderedDict' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'pop' of 'collections.deque' objects}\r\n",
      "      535    0.000    0.000    0.000    0.000 {method 'pop' of 'dict' objects}\r\n",
      "       80    0.000    0.000    0.000    0.000 {method 'pop' of 'list' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'randint' of 'numpy.random.mtrand.RandomState' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'ravel' of 'numpy.ndarray' objects}\r\n",
      "      413    0.004    0.000    0.004    0.000 {method 'read' of '_io.BufferedReader' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'read' of '_io.TextIOWrapper' objects}\r\n",
      "        3    0.000    0.000    0.000    0.000 {method 'reduce' of 'numpy.ufunc' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'release' of '_thread.RLock' objects}\r\n",
      "        9    0.000    0.000    0.000    0.000 {method 'remove' of 'list' objects}\r\n",
      "       14    0.000    0.000    0.000    0.000 {method 'remove' of 'set' objects}\r\n",
      "      145    0.000    0.000    0.000    0.000 {method 'replace' of 'str' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'reshape' of 'numpy.ndarray' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'reverse' of 'list' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'rfind' of 'bytes' objects}\r\n",
      "      816    0.000    0.000    0.000    0.000 {method 'rfind' of 'str' objects}\r\n",
      "     3036    0.001    0.000    0.001    0.000 {method 'rpartition' of 'str' objects}\r\n",
      "     8532    0.001    0.000    0.001    0.000 {method 'rstrip' of 'str' objects}\r\n",
      "       28    0.000    0.000    0.000    0.000 {method 'search' of 're.Pattern' objects}\r\n",
      "       49    0.000    0.000    0.000    0.000 {method 'setdefault' of 'dict' objects}\r\n",
      "       29    0.000    0.000    0.000    0.000 {method 'setter' of 'property' objects}\r\n",
      "       10    0.000    0.000    0.000    0.000 {method 'sort' of 'list' objects}\r\n",
      "        6    0.000    0.000    0.000    0.000 {method 'split' of 're.Pattern' objects}\r\n",
      "      105    0.000    0.000    0.000    0.000 {method 'split' of 'str' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'splitlines' of 'str' objects}\r\n",
      "       14    0.000    0.000    0.000    0.000 {method 'startswith' of 'bytes' objects}\r\n",
      "    20623    0.002    0.000    0.002    0.000 {method 'startswith' of 'str' objects}\r\n",
      "       38    0.000    0.000    0.000    0.000 {method 'strftime' of 'datetime.date' objects}\r\n",
      "      466    0.000    0.000    0.000    0.000 {method 'strip' of 'str' objects}\r\n",
      "     2544    0.011    0.000    0.011    0.000 {method 'sub' of 're.Pattern' objects}\r\n",
      "        5    0.000    0.000    0.000    0.000 {method 'tolist' of 'memoryview' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'toordinal' of 'datetime.date' objects}\r\n",
      "       24    0.000    0.000    0.000    0.000 {method 'translate' of 'bytearray' objects}\r\n",
      "      142    0.000    0.000    0.000    0.000 {method 'translate' of 'str' objects}\r\n",
      "        2    0.000    0.000    0.000    0.000 {method 'transpose' of 'numpy.ndarray' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'union' of 'set' objects}\r\n",
      "      621    0.000    0.000    0.000    0.000 {method 'update' of 'dict' objects}\r\n",
      "        3    0.000    0.000    0.000    0.000 {method 'update' of 'set' objects}\r\n",
      "       37    0.000    0.000    0.000    0.000 {method 'upper' of 'str' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'values' of 'collections.OrderedDict' objects}\r\n",
      "       21    0.000    0.000    0.000    0.000 {method 'values' of 'dict' objects}\r\n",
      "      125    0.000    0.000    0.000    0.000 {method 'values' of 'mappingproxy' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {method 'view' of 'numpy.generic' objects}\r\n",
      "      4/3    0.000    0.000    0.000    0.000 {method 'view' of 'numpy.ndarray' objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {pandas._libs.algos.ensure_platform_int}\r\n",
      "        2    0.000    0.000    0.000    0.000 {pandas._libs.lib.infer_dtype}\r\n",
      "        1    0.000    0.000    0.000    0.000 {pandas._libs.lib.is_all_arraylike}\r\n",
      "        3    0.000    0.000    0.000    0.000 {pandas._libs.lib.is_float}\r\n",
      "        3    0.000    0.000    0.000    0.000 {pandas._libs.lib.is_iterator}\r\n",
      "       13    0.000    0.000    0.000    0.000 {pandas._libs.lib.is_list_like}\r\n",
      "       12    0.000    0.000    0.000    0.000 {pandas._libs.lib.is_scalar}\r\n",
      "        5    0.000    0.000    0.000    0.000 {pandas._libs.lib.item_from_zerodim}\r\n",
      "        3    0.000    0.000    0.000    0.000 {pandas._libs.lib.maybe_convert_objects}\r\n",
      "        1    0.000    0.000    0.000    0.000 {pyarrow._compute.function_registry}\r\n",
      "\r\n",
      "\r\n"
     ]
    }
   ],
   "source": [
    "!python -m cProfile cprofilers_example.py"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "56a7e5cb",
   "metadata": {},
   "source": [
    "A small portion of the output:\n",
    "```bash\n",
    "         246355 function calls (240252 primitive calls) in 0.311 seconds\n",
    "\n",
    "   Ordered by: standard name\n",
    "\n",
    "   ncalls  tottime  percall  cumtime  percall filename:lineno(function)\n",
    "        1    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(<module>)\n",
    "        2    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(append)\n",
    "        1    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(bincount)\n",
    "        5    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(concatenate)\n",
    "        4    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(copyto)\n",
    "        2    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(ndim)\n",
    "        1    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(prod)\n",
    "        2    0.000    0.000    0.000    0.000 <__array_function__ internals>:2(ravel)\n",
    "        2    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:1002(_gcd_import)\n",
    "  610/353    0.001    0.000    0.144    0.000 <frozen importlib._bootstrap>:1017(_handle_fromlist)\n",
    "     1208    0.002    0.000    0.002    0.000 <frozen importlib._bootstrap>:103(release)\n",
    "      527    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:143(__init__)\n",
    "      527    0.000    0.000    0.004    0.000 <frozen importlib._bootstrap>:147(__enter__)\n",
    "      527    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap>:151(__exit__)\n",
    "     1208    0.002    0.000    0.003    0.000 <frozen importlib._bootstrap>:157(_get_module_lock)\n",
    "      524    0.001    0.000    0.001    0.000 <frozen importlib._bootstrap>:176(cb)\n",
    "      681    0.001    0.000    0.003    0.000 <frozen importlib._bootstrap>:194(_lock_unlock_module)\n",
    "    681/1    0.000    0.000    0.310    0.310 <frozen importlib._bootstrap>:211(_call_with_frames_removed)\n",
    "     4196    0.001    0.000    0.001    0.000 <frozen importlib._bootstrap>:222(_verbose_message)\n",
    "       23    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:232(_requires_builtin_wrapper)\n",
    "      521    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:342(__init__)\n",
    "      406    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:35(_new_module)\n",
    "      880    0.001    0.000    0.005    0.000 <frozen importlib._bootstrap>:376(cached)\n",
    "      727    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap>:389(parent)\n",
    "      498    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:397(has_location)\n",
    "       24    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:406(spec_from_loader)\n",
    "      498    0.002    0.000    0.009    0.000 <frozen importlib._bootstrap>:477(_init_module_attrs)\n",
    "  498/495    0.001    0.000    0.032    0.000 <frozen importlib._bootstrap>:549(module_from_spec)\n",
    "      524    0.001    0.000    0.001    0.000 <frozen importlib._bootstrap>:58(__init__)\n",
    "    498/1    0.002    0.000    0.310    0.310 <frozen importlib._bootstrap>:650(_load_unlocked)\n",
    "      520    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:725(find_spec)\n",
    "       23    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap>:746(create_module)\n",
    "       23    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:754(exec_module)\n",
    "       23    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:771(is_package)\n",
    "     1208    0.002    0.000    0.002    0.000 <frozen importlib._bootstrap>:78(acquire)\n",
    "      497    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:800(find_spec)\n",
    "     1530    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap>:863(__enter__)\n",
    "     1530    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap>:867(__exit__)\n",
    "      520    0.003    0.000    0.032    0.000 <frozen importlib._bootstrap>:890(_find_spec)\n",
    "        2    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap>:937(_sanity_check)\n",
    "    527/1    0.002    0.000    0.311    0.311 <frozen importlib._bootstrap>:956(_find_and_load_unlocked)\n",
    "    527/1    0.002    0.000    0.311    0.311 <frozen importlib._bootstrap>:986(_find_and_load)\n",
    "      406    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:1004(__init__)\n",
    "      406    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:1029(get_filename)\n",
    "      406    0.002    0.000    0.011    0.000 <frozen importlib._bootstrap_external>:1034(get_data)\n",
    "      406    0.000    0.000    0.002    0.000 <frozen importlib._bootstrap_external>:1075(path_stats)\n",
    "       68    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:1153(__init__)\n",
    "       68    0.000    0.000    0.021    0.000 <frozen importlib._bootstrap_external>:1164(create_module)\n",
    "    68/39    0.000    0.000    0.058    0.001 <frozen importlib._bootstrap_external>:1172(exec_module)\n",
    "     3858    0.002    0.000    0.006    0.000 <frozen importlib._bootstrap_external>:121(_path_join)\n",
    "     3858    0.002    0.000    0.003    0.000 <frozen importlib._bootstrap_external>:123(<listcomp>)\n",
    "      812    0.001    0.000    0.002    0.000 <frozen importlib._bootstrap_external>:127(_path_split)\n",
    "     1624    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap_external>:129(<genexpr>)\n",
    "       53    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap_external>:1317(_path_hooks)\n",
    "      820    0.000    0.000    0.002    0.000 <frozen importlib._bootstrap_external>:1330(_path_importer_cache)\n",
    "     1896    0.001    0.000    0.007    0.000 <frozen importlib._bootstrap_external>:135(_path_stat)\n",
    "      497    0.002    0.000    0.026    0.000 <frozen importlib._bootstrap_external>:1367(_get_spec)\n",
    "      497    0.000    0.000    0.026    0.000 <frozen importlib._bootstrap_external>:1399(find_spec)\n",
    "      704    0.001    0.000    0.003    0.000 <frozen importlib._bootstrap_external>:145(_path_is_mode_type)\n",
    "       53    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:1459(__init__)\n",
    "      424    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:1465(<genexpr>)\n",
    "      474    0.001    0.000    0.003    0.000 <frozen importlib._bootstrap_external>:1493(_get_spec)\n",
    "      733    0.006    0.000    0.022    0.000 <frozen importlib._bootstrap_external>:1498(find_spec)\n",
    "      651    0.000    0.000    0.003    0.000 <frozen importlib._bootstrap_external>:154(_path_isfile)\n",
    "       53    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap_external>:1549(_fill_cache)\n",
    "       53    0.000    0.000    0.000    0.000 <frozen importlib._bootstrap_external>:159(_path_isdir)\n",
    "       53    0.000    0.000    0.001    0.000 <frozen importlib._bootstrap_external>:1590(path_hook_for_FileFinder)\n",
    "```"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "5e45fb99",
   "metadata": {},
   "source": [
    "You can get a more readable output using pyinstrument. To use pyinstrument, simply insert the piece of code you want to profile between `profiler.start` and `profile.end`:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "135d1d89",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Writing pyinstrument_example.py\n"
     ]
    }
   ],
   "source": [
    "%%writefile pyinstrument_example.py\n",
    "from pyinstrument import Profiler\n",
    "import pandas as pd\n",
    "import numpy as np\n",
    "\n",
    "df = pd.DataFrame({'nums': np.random.randint(0, 100, 10000)})\n",
    "def is_even(num: int) -> int:\n",
    "    return num % 2 == 0\n",
    "\n",
    "profiler = Profiler()\n",
    "profiler.start()\n",
    "\n",
    "df = df.assign(is_even=lambda df_: is_even(df_.nums))\n",
    "\n",
    "profiler.stop()\n",
    "profiler.print()"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "07efa963",
   "metadata": {},
   "source": [
    "On your terminal, type:\n",
    "```bash\n",
    "$ pyinstrument pyinstrument_example.py\n",
    "```\n",
    "... and you should see an output like below: "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "1d05e187",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-09-15T14:04:59.551271Z",
     "start_time": "2021-09-15T14:04:58.937663Z"
    },
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "\n",
      "  _     ._   __/__   _ _  _  _ _/_   Recorded: 09:04:59  Samples:  1\n",
      " /_//_/// /_\\ / //_// / //_'/ //     Duration: 0.001     CPU time: 0.001\n",
      "/   _/                      v4.0.3\n",
      "\n",
      "Program: pyinstrument_example.py\n",
      "\n",
      "\u001b[31m0.001\u001b[0m \u001b[48;5;24m\u001b[38;5;15m<module>\u001b[0m  \u001b[2mpyinstrument_example.py:1\u001b[0m\n",
      "└─ \u001b[31m0.001\u001b[0m assign\u001b[0m  \u001b[2mpandas/core/frame.py:4416\u001b[0m\n",
      "      [2 frames hidden]  \u001b[2mpandas\u001b[0m\n",
      "         \u001b[31m0.001\u001b[0m apply_if_callable\u001b[0m  \u001b[2mpandas/core/common.py:346\u001b[0m\n",
      "         └─ \u001b[31m0.001\u001b[0m \u001b[48;5;24m\u001b[38;5;15m<lambda>\u001b[0m  \u001b[2mpyinstrument_example.py:12\u001b[0m\n",
      "            └─ \u001b[31m0.001\u001b[0m \u001b[48;5;24m\u001b[38;5;15mis_even\u001b[0m  \u001b[2mpyinstrument_example.py:6\u001b[0m\n",
      "               └─ \u001b[31m0.001\u001b[0m new_method\u001b[0m  \u001b[2mpandas/core/ops/common.py:54\u001b[0m\n",
      "                     [9 frames hidden]  \u001b[2mpandas, <built-in>\u001b[0m\n",
      "                        \u001b[31m0.001\u001b[0m mod\u001b[0m  \u001b[2m<built-in>:0\u001b[0m\n",
      "\n",
      "\n",
      "\n",
      "  _     ._   __/__   _ _  _  _ _/_   Recorded: 09:04:59  Samples:  225\n",
      " /_//_/// /_\\ / //_// / //_'/ //     Duration: 0.265     CPU time: 1.897\n",
      "/   _/                      v4.0.3\n",
      "\n",
      "Program: pyinstrument_example.py\n",
      "\n",
      "\u001b[31m0.265\u001b[0m <module>\u001b[0m  \u001b[2m<string>:1\u001b[0m\n",
      "   [4 frames hidden]  \u001b[2m<string>, runpy\u001b[0m\n",
      "      \u001b[31m0.265\u001b[0m _run_code\u001b[0m  \u001b[2mrunpy.py:64\u001b[0m\n",
      "      └─ \u001b[31m0.265\u001b[0m \u001b[48;5;24m\u001b[38;5;15m<module>\u001b[0m  \u001b[2mpyinstrument_example.py:1\u001b[0m\n",
      "         └─ \u001b[31m0.261\u001b[0m <module>\u001b[0m  \u001b[2mpandas/__init__.py:3\u001b[0m\n",
      "               [650 frames hidden]  \u001b[2mpandas, pyarrow, <built-in>, textwrap...\u001b[0m\n",
      "\n",
      "To view this report with different options, run:\n",
      "    pyinstrument --load-prev 2021-09-15T09-04-59 [options]\n",
      "\n"
     ]
    }
   ],
   "source": [
    "!pyinstrument pyinstrument_example.py"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "d4841b65",
   "metadata": {},
   "source": [
    "[Link to pyinstrument](https://github.com/joerick/pyinstrument)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "9392f3b2",
   "metadata": {},
   "source": [
    "### Speed Up Your Python Code with Concurrency "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "id": "eba0493a",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2022-10-03T13:59:10.561479Z",
     "start_time": "2022-10-03T13:59:06.200907Z"
    },
    "tags": [
     "hide-cell"
    ]
   },
   "outputs": [],
   "source": [
    "!pip install -U prefect "
   ]
  },
  {
   "cell_type": "markdown",
   "id": "e74fa5b5",
   "metadata": {},
   "source": [
    "If you want to speed up the execution of functions that are not related to each other, you might consider running your code concurrently. Concurrency refers to a system that can do more than one thing simultaneously.\n",
    "\n",
    "For example, imagine a restaurant with one employee who is both the cook and waiter. While food cooks on the stove, the employee can take orders.\n",
    "\n",
    "![](../img/concurrent.png)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "9c9c8bcb",
   "metadata": {},
   "source": [
    "If you want to run your code concurrently with a few additional code, simply add the `@task` and `@flow` decorators from Prefect. \n",
    "\n",
    "Let's compare the execution time between running code sequentially and running code concurrently. "
   ]
  },
  {
   "cell_type": "markdown",
   "id": "eab37908",
   "metadata": {},
   "source": [
    "Running code sequentially:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "72ae072d",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2022-10-03T14:25:56.840518Z",
     "start_time": "2022-10-03T14:25:26.818771Z"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "#0\n",
      "#1\n",
      "#2\n",
      "#3\n",
      "#4\n",
      "CPU times: user 7.88 ms, sys: 6.35 ms, total: 14.2 ms\n",
      "Wall time: 30 s\n"
     ]
    }
   ],
   "source": [
    "%%time \n",
    "\n",
    "import time\n",
    "\n",
    "from random import randint, seed\n",
    "\n",
    "def shout(number):\n",
    "    seed(0)\n",
    "    time.sleep(randint(0, 10))\n",
    "    print(f\"#{number}\")\n",
    "\n",
    "\n",
    "def count_to(highest_number):\n",
    "    for number in range(highest_number):\n",
    "        shout(number)\n",
    "\n",
    "\n",
    "count_to(5)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "bbc8f5e2",
   "metadata": {},
   "source": [
    "Running code concurrently:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "53fbf3ea",
   "metadata": {
    "ExecuteTime": {
     "end_time": "2022-10-03T14:26:21.173915Z",
     "start_time": "2022-10-03T14:26:14.377609Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:15</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">862</span> | INFO    | prefect.engine - Created flow run <span style=\"color: #008000; text-decoration-color: #008000\">'olive-manul'</span> for flow <span style=\"color: #008000; text-decoration-color: #008000\">'count-to'</span> \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:15\u001b[0m.\u001b[1;36m862\u001b[0m | INFO    | prefect.engine - Created flow run \u001b[32m'olive-manul'\u001b[0m for flow \u001b[32m'count-to'\u001b[0m \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:16</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">706</span> | INFO    | prefect.flow_runs - Created task run <span style=\"color: #008000; text-decoration-color: #008000\">'shout-58a68b34-0'</span> for task    \n",
       "<span style=\"color: #008000; text-decoration-color: #008000\">'shout'</span>                                                                                      \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:16\u001b[0m.\u001b[1;36m706\u001b[0m | INFO    | prefect.flow_runs - Created task run \u001b[32m'shout-58a68b34-0'\u001b[0m for task    \n",
       "\u001b[32m'shout'\u001b[0m                                                                                      \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:16</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">713</span> | INFO    | prefect.flow_runs - Submitted task run <span style=\"color: #008000; text-decoration-color: #008000\">'shout-58a68b34-0'</span> for       \n",
       "execution.                                                                                   \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:16\u001b[0m.\u001b[1;36m713\u001b[0m | INFO    | prefect.flow_runs - Submitted task run \u001b[32m'shout-58a68b34-0'\u001b[0m for       \n",
       "execution.                                                                                   \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:16</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">776</span> | INFO    | prefect.flow_runs - Created task run <span style=\"color: #008000; text-decoration-color: #008000\">'shout-58a68b34-1'</span> for task    \n",
       "<span style=\"color: #008000; text-decoration-color: #008000\">'shout'</span>                                                                                      \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:16\u001b[0m.\u001b[1;36m776\u001b[0m | INFO    | prefect.flow_runs - Created task run \u001b[32m'shout-58a68b34-1'\u001b[0m for task    \n",
       "\u001b[32m'shout'\u001b[0m                                                                                      \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:16</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">781</span> | INFO    | prefect.flow_runs - Submitted task run <span style=\"color: #008000; text-decoration-color: #008000\">'shout-58a68b34-1'</span> for       \n",
       "execution.                                                                                   \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:16\u001b[0m.\u001b[1;36m781\u001b[0m | INFO    | prefect.flow_runs - Submitted task run \u001b[32m'shout-58a68b34-1'\u001b[0m for       \n",
       "execution.                                                                                   \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:16</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">824</span> | INFO    | prefect.flow_runs - Created task run <span style=\"color: #008000; text-decoration-color: #008000\">'shout-58a68b34-4'</span> for task    \n",
       "<span style=\"color: #008000; text-decoration-color: #008000\">'shout'</span>                                                                                      \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:16\u001b[0m.\u001b[1;36m824\u001b[0m | INFO    | prefect.flow_runs - Created task run \u001b[32m'shout-58a68b34-4'\u001b[0m for task    \n",
       "\u001b[32m'shout'\u001b[0m                                                                                      \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:16</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">829</span> | INFO    | prefect.flow_runs - Submitted task run <span style=\"color: #008000; text-decoration-color: #008000\">'shout-58a68b34-4'</span> for       \n",
       "execution.                                                                                   \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:16\u001b[0m.\u001b[1;36m829\u001b[0m | INFO    | prefect.flow_runs - Submitted task run \u001b[32m'shout-58a68b34-4'\u001b[0m for       \n",
       "execution.                                                                                   \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:16</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">837</span> | INFO    | prefect.flow_runs - Created task run <span style=\"color: #008000; text-decoration-color: #008000\">'shout-58a68b34-3'</span> for task    \n",
       "<span style=\"color: #008000; text-decoration-color: #008000\">'shout'</span>                                                                                      \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:16\u001b[0m.\u001b[1;36m837\u001b[0m | INFO    | prefect.flow_runs - Created task run \u001b[32m'shout-58a68b34-3'\u001b[0m for task    \n",
       "\u001b[32m'shout'\u001b[0m                                                                                      \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:16</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">840</span> | INFO    | prefect.flow_runs - Submitted task run <span style=\"color: #008000; text-decoration-color: #008000\">'shout-58a68b34-3'</span> for       \n",
       "execution.                                                                                   \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:16\u001b[0m.\u001b[1;36m840\u001b[0m | INFO    | prefect.flow_runs - Submitted task run \u001b[32m'shout-58a68b34-3'\u001b[0m for       \n",
       "execution.                                                                                   \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:16</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">848</span> | INFO    | prefect.flow_runs - Created task run <span style=\"color: #008000; text-decoration-color: #008000\">'shout-58a68b34-2'</span> for task    \n",
       "<span style=\"color: #008000; text-decoration-color: #008000\">'shout'</span>                                                                                      \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:16\u001b[0m.\u001b[1;36m848\u001b[0m | INFO    | prefect.flow_runs - Created task run \u001b[32m'shout-58a68b34-2'\u001b[0m for task    \n",
       "\u001b[32m'shout'\u001b[0m                                                                                      \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:16</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">850</span> | INFO    | prefect.flow_runs - Submitted task run <span style=\"color: #008000; text-decoration-color: #008000\">'shout-58a68b34-2'</span> for       \n",
       "execution.                                                                                   \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:16\u001b[0m.\u001b[1;36m850\u001b[0m | INFO    | prefect.flow_runs - Submitted task run \u001b[32m'shout-58a68b34-2'\u001b[0m for       \n",
       "execution.                                                                                   \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "#0\n",
      "#1\n",
      "#2\n",
      "#4\n",
      "#3\n"
     ]
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:20</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">138</span> | INFO    | prefect.task_runs - Finished in state <span style=\"color: #800080; text-decoration-color: #800080; font-weight: bold\">Completed</span><span style=\"font-weight: bold\">()</span>                   \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:20\u001b[0m.\u001b[1;36m138\u001b[0m | INFO    | prefect.task_runs - Finished in state \u001b[1;35mCompleted\u001b[0m\u001b[1m(\u001b[0m\u001b[1m)\u001b[0m                   \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:20</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">147</span> | INFO    | prefect.task_runs - Finished in state <span style=\"color: #800080; text-decoration-color: #800080; font-weight: bold\">Completed</span><span style=\"font-weight: bold\">()</span>                   \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:20\u001b[0m.\u001b[1;36m147\u001b[0m | INFO    | prefect.task_runs - Finished in state \u001b[1;35mCompleted\u001b[0m\u001b[1m(\u001b[0m\u001b[1m)\u001b[0m                   \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:20</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">154</span> | INFO    | prefect.task_runs - Finished in state <span style=\"color: #800080; text-decoration-color: #800080; font-weight: bold\">Completed</span><span style=\"font-weight: bold\">()</span>                   \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:20\u001b[0m.\u001b[1;36m154\u001b[0m | INFO    | prefect.task_runs - Finished in state \u001b[1;35mCompleted\u001b[0m\u001b[1m(\u001b[0m\u001b[1m)\u001b[0m                   \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:21</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">043</span> | INFO    | prefect.task_runs - Finished in state <span style=\"color: #800080; text-decoration-color: #800080; font-weight: bold\">Completed</span><span style=\"font-weight: bold\">()</span>                   \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:21\u001b[0m.\u001b[1;36m043\u001b[0m | INFO    | prefect.task_runs - Finished in state \u001b[1;35mCompleted\u001b[0m\u001b[1m(\u001b[0m\u001b[1m)\u001b[0m                   \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:21</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">062</span> | INFO    | prefect.task_runs - Finished in state <span style=\"color: #800080; text-decoration-color: #800080; font-weight: bold\">Completed</span><span style=\"font-weight: bold\">()</span>                   \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:21\u001b[0m.\u001b[1;36m062\u001b[0m | INFO    | prefect.task_runs - Finished in state \u001b[1;35mCompleted\u001b[0m\u001b[1m(\u001b[0m\u001b[1m)\u001b[0m                   \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<pre style=\"white-space:pre;overflow-x:auto;line-height:normal;font-family:Menlo,'DejaVu Sans Mono',consolas,'Courier New',monospace\"><span style=\"color: #00ff00; text-decoration-color: #00ff00; font-weight: bold\">09:26:21</span>.<span style=\"color: #008080; text-decoration-color: #008080; font-weight: bold\">157</span> | INFO    | prefect.flow_runs - Finished in state <span style=\"color: #800080; text-decoration-color: #800080; font-weight: bold\">Completed</span><span style=\"font-weight: bold\">(</span><span style=\"color: #008000; text-decoration-color: #008000\">'All states </span>        \n",
       "<span style=\"color: #008000; text-decoration-color: #008000\">completed.'</span><span style=\"font-weight: bold\">)</span>                                                                                 \n",
       "</pre>\n"
      ],
      "text/plain": [
       "\u001b[1;92m09:26:21\u001b[0m.\u001b[1;36m157\u001b[0m | INFO    | prefect.flow_runs - Finished in state \u001b[1;35mCompleted\u001b[0m\u001b[1m(\u001b[0m\u001b[32m'All states \u001b[0m        \n",
       "\u001b[32mcompleted.'\u001b[0m\u001b[1m)\u001b[0m                                                                                 \n"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "CPU times: user 1.18 s, sys: 178 ms, total: 1.36 s\n",
      "Wall time: 6.78 s\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "[Completed(message=None, type=COMPLETED, result=None),\n",
       " Completed(message=None, type=COMPLETED, result=None),\n",
       " Completed(message=None, type=COMPLETED, result=None),\n",
       " Completed(message=None, type=COMPLETED, result=None),\n",
       " Completed(message=None, type=COMPLETED, result=None)]"
      ]
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "%%time \n",
    "\n",
    "from prefect import flow, task\n",
    "\n",
    "@task\n",
    "def shout(number):\n",
    "    seed(0)\n",
    "    time.sleep(randint(0, 5))\n",
    "    print(f\"#{number}\")\n",
    "\n",
    "\n",
    "@flow\n",
    "def count_to(highest_number):\n",
    "    for number in range(highest_number):\n",
    "        shout.submit(number)\n",
    "\n",
    "\n",
    "count_to(5)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "ac88c859",
   "metadata": {},
   "source": [
    "We can see that it is faster to run code concurrently than sequentially."
   ]
  },
  {
   "cell_type": "markdown",
   "id": "56bf0940",
   "metadata": {},
   "source": [
    "[Link to Prefect](https://github.com/PrefectHQ/prefect)"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "a805c26f",
   "metadata": {},
   "source": [
    "### Covalent: Pythonic Tool to Iterate Quickly on Large ML Models "
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "1c949a23",
   "metadata": {},
   "source": [
    "Iterating quickly on large ML models in a local environment can be a daunting task for any ML project. Using advanced computing hardware can facilitate this process, but it can be costly, especially when it's only necessary for a specific portion of the code.\n",
    "\n",
    "Covalent makes it easy to:\n",
    "- Assign resource-intensive functions to advanced hardware.\n",
    "- Test these functions on local servers before deploying them to expensive hardware."
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "751e49c9",
   "metadata": {},
   "source": [
    "![](../img/covalent.gif)"
   ]
  },
  {
   "attachments": {},
   "cell_type": "markdown",
   "id": "e59641d2",
   "metadata": {},
   "source": [
    "[Link to Covalent](https://github.com/AgnostiqHQ/covalent)."
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Tags",
  "hide_input": false,
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.11.6"
  },
  "toc": {
   "base_numbering": 1,
   "nav_menu": {},
   "number_sections": true,
   "sideBar": true,
   "skip_h1_title": false,
   "title_cell": "Table of Contents",
   "title_sidebar": "Contents",
   "toc_cell": false,
   "toc_position": {},
   "toc_section_display": true,
   "toc_window_display": false
  },
  "vscode": {
   "interpreter": {
    "hash": "aee8b7b246df8f9039afb4144a1f6fd8d2ca17a180786b69acc140d282b71a49"
   }
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
